@@ -1,15 +1,14 @@
-import {Autoscan} from "../../../web/js/gerbera-autoscan.module";
-import {GerberaApp} from "../../../web/js/gerbera-app.module";
-import {Tree} from '../../../web/js/gerbera-tree.module';
-import {Items} from "../../../web/js/gerbera-items.module";
-import {Updates} from "../../../web/js/gerbera-updates.module";
-import {Trail} from "../../../web/js/gerbera-trail.module";
+import { Autoscan } from "../../../web/js/gerbera-autoscan.module";
+import { GerberaApp } from "../../../web/js/gerbera-app.module";
+import { Tree } from '../../../web/js/gerbera-tree.module';
+import { Items } from "../../../web/js/gerbera-items.module";
+import { Updates } from "../../../web/js/gerbera-updates.module";
+import { Trail } from "../../../web/js/gerbera-trail.module";
 import treeResponse from './fixtures/parent_id-0-select_it-0';
 import childTreeResponse from './fixtures/parent_id-7443-select_it-0';
 import trailData from './fixtures/trail-data';
 import containerAsTree from './fixtures/container-data-astree';
 
-
 describe('Gerbera Tree', () => {
   let tree, lsSpy;
 
@@ -21,7 +20,7 @@ describe('Gerbera Tree', () => {
     fixture.load('index.html');
     tree = $('#tree');
     lsSpy = spyOn(window.localStorage, 'getItem').and.callFake((name) => {
-        return;
+      return;
     });
     GerberaApp.setType('db');
     GerberaApp.setCurrentItem([]);
@@ -36,11 +35,12 @@ describe('Gerbera Tree', () => {
     });
   });
   describe('loadTree()', () => {
-    let response, trailConfig, trail;
+    let trailConfig, trail;
 
     beforeEach(() => {
       trailConfig = {};
       trail = $('#trail');
+      Tree.viewFactory('db', 0);
     });
 
     it('renders the tree with parent and children', () => {
@@ -68,7 +68,11 @@ describe('Gerbera Tree', () => {
       expect(trail.trail('length')).toBe(1);
     });
   });
-  describe('transformContainers', () => {
+  describe('transformContainers()', () => {
+    beforeEach(() => {
+      Tree.viewFactory('db', 0);
+    });
+
     let result;
 
     it('transforms containers response suitable for treeview load', () => {
@@ -177,6 +181,7 @@ describe('Gerbera Tree', () => {
 
     beforeEach(() => {
       ajaxSpy = spyOn($, 'ajax');
+      Tree.viewFactory('db', 0);
     });
 
     afterEach(() => {
@@ -198,7 +203,21 @@ describe('Gerbera Tree', () => {
 
       expect(Items.treeItemSelected).toHaveBeenCalled();
       expect(Items.treeItemSelected.calls.mostRecent().args[0]).toEqual(
-        {title: 'Photos', badge: [2], nodes: [], gerbera: {id: 2779, childCount: 2, autoScanMode: 'none', autoScanType: 'none', image: null}}
+        {
+          title: 'Photos',
+          badge: [2],
+          nodes: [],
+          gerbera: {
+            id: 2779,
+            childCount: 2,
+            autoScanMode: 'none',
+            autoScanType: 'none',
+            image: null,
+            path: "/my/Directory/",
+            upnpShortcut: null,
+            upnpClass: "upnp.class"
+          }
+        }
       );
     });
 
@@ -217,7 +236,21 @@ describe('Gerbera Tree', () => {
 
       expect(Items.treeItemSelected).toHaveBeenCalled();
       expect(Items.treeItemSelected.calls.mostRecent().args[0]).toEqual(
-        {title: 'Photos', badge: [2], nodes: [], gerbera: {id: 2779, childCount: 2, autoScanMode: 'none', autoScanType: 'none', image: null}}
+        {
+          title: 'Photos',
+          badge: [2],
+          nodes: [],
+          gerbera: {
+            id: 2779,
+            childCount: 2,
+            autoScanMode: 'none',
+            autoScanType: 'none',
+            image: null,
+            path: "/my/Directory/",
+            upnpShortcut: null,
+            upnpClass: "upnp.class"
+          }
+        }
       );
     });
 
@@ -242,6 +275,7 @@ describe('Gerbera Tree', () => {
 
     beforeEach(() => {
       ajaxSpy = spyOn($, 'ajax');
+      Tree.viewFactory('db', 0);
     });
 
     afterEach(() => {
@@ -272,6 +306,7 @@ describe('Gerbera Tree', () => {
 
     beforeEach(() => {
       ajaxSpy = spyOn($, 'ajax');
+      Tree.viewFactory('db', 0);
     });
 
     afterEach(() => {
@@ -298,6 +333,7 @@ describe('Gerbera Tree', () => {
 
     beforeEach(() => {
       ajaxSpy = spyOn($, 'ajax');
+      Tree.viewFactory('db', 0);
     });
 
     afterEach(() => {
@@ -322,6 +358,7 @@ describe('Gerbera Tree', () => {
 
     beforeEach(() => {
       ajaxSpy = spyOn($, 'ajax');
+      Tree.viewFactory('db', 0);
     });
 
     afterEach(() => {
@@ -343,6 +380,10 @@ describe('Gerbera Tree', () => {
     });
   });
   describe('getTreeElementById()', () => {
+    beforeEach(() => {
+      Tree.viewFactory('db', 0);
+    });
+
     it('finds the HTML element given the gerbera id', () => {
       Tree.loadTree(treeResponse);
 
@@ -353,7 +394,16 @@ describe('Gerbera Tree', () => {
         title: 'Audio',
         badge: [6],
         nodes: [],
-        gerbera: { id: 8, childCount: 6, autoScanMode: 'none', autoScanType: 'none', image: null }
+        gerbera: {
+          id: 8,
+          childCount: 6,
+          autoScanMode: 'none',
+          autoScanType: 'none',
+          image: null,
+          path: null,
+          upnpShortcut: null,
+          upnpClass: null
+        }
       });
     });
   });
