@@ -15,7 +15,7 @@ describe('The jQuery Configgrid', () => {
     fixture.cleanup();
   });
 
-  it('creates a tree base on config and values', () => {
+  it('creates a tree based on config and values', () => {
     dataGrid.config({
       setup: configMetaJson.config,
       values: configValueJson.values,
@@ -29,8 +29,9 @@ describe('The jQuery Configgrid', () => {
       itemType: 'config'
     });
 
-    expect(dataGrid.find('ul').length).toBe(63);
+    expect(dataGrid.find('ul').length).toBe(67);
+    expect(dataGrid.find('li.grb-config').length).toBe(116);
     expect(dataGrid.find('li.grb-config').get(8).innerText).toContain('Model Number');
-    expect(dataGrid.find('#item__server_modelNumber').find('input').get(0).value).toContain('2.2.0');
+    expect(dataGrid.find('#grb_line__server_modelNumber').find('input').get(0).value).toContain('2.2.0');
   });
 });
