@@ -1,4 +1,4 @@
-const {By, until} = require('selenium-webdriver');
+const { By, until } = require('selenium-webdriver');
 const fs = require('fs');
 
 module.exports = function (driver) {
@@ -10,6 +10,10 @@ module.exports = function (driver) {
     return await driver.findElement(By.id('nav-fs'));
   };
 
+  this.getSearchMenu = async () => {
+    return await driver.findElement(By.id('nav-search'));
+  };
+
   this.getClientsMenu = async () => {
     return await driver.findElement(By.id('nav-clients'));
   };
@@ -30,18 +34,18 @@ module.exports = function (driver) {
     if (menuId === 'nav-home' || menuId === 'nav-clients' || menuId == 'nav-config') {
       return await driver.findElement(By.id(menuId)).click()
     } else {
-      const tree = await driver.findElement(By.id('tree'));
       await driver.findElement(By.id(menuId)).click();
+      const tree = await driver.findElement(By.id('tree'));
       return await driver.wait(until.elementIsVisible(tree), 5000)
     }
   };
 
   this.clickMenuIcon = async (menuId) => {
     const tree = await driver.findElement(By.id('tree'));
-    if (menuId === 'nav-home' || menuId === 'nav-clients'|| menuId == 'nav-config') {
-      return await driver.findElement(By.css('#'+ menuId + ' i')).click();
+    if (menuId === 'nav-home' || menuId === 'nav-clients' || menuId == 'nav-config') {
+      return await driver.findElement(By.css('#' + menuId + ' i')).click();
     } else {
-      await driver.findElement(By.css('#'+ menuId + ' i')).click();
+      await driver.findElement(By.css('#' + menuId + ' i')).click();
       return await driver.wait(until.elementIsVisible(tree), 5000);
     }
   };
@@ -54,7 +58,7 @@ module.exports = function (driver) {
   };
   this.treeItemChildItems = async (text) => {
     const items = await driver.findElements(By.xpath('//li[.//span[contains(text(),\'' + text + '\')]]'));
-      // the xpath finds both <database> and <Video>  TODO: needs work
+    // the xpath finds both <database> and <Video>  TODO: needs work
     return await items[1].findElements(By.css('li.list-group-item'));
   };
   this.showConfig = async (text) => {
@@ -119,7 +123,7 @@ module.exports = function (driver) {
     return await driver.findElement(By.id(fieldName));
   };
 
-  this.editorOverlayFieldDisplayed = async(fieldName) => {
+  this.editorOverlayFieldDisplayed = async (fieldName) => {
     return await driver.findElement(By.id(fieldName)).isDisplayed();
   };
 
@@ -163,7 +167,7 @@ module.exports = function (driver) {
   this.hasDeleteIcon = async (grbItem) => {
     try {
       return await grbItem.findElement(By.css('.grb-item-delete')).isDisplayed();
-    } catch(e) {
+    } catch (e) {
       return false;
     }
   };
@@ -247,7 +251,7 @@ module.exports = function (driver) {
   };
 
   this.setAutoscanMode = async (mode) => {
-    return await driver.findElement(By.id('autoscanMode'+ mode)).click();
+    return await driver.findElement(By.id('autoscanMode' + mode)).click();
   };
 
   this.autoscanOverlayDisplayed = async () => {
@@ -311,8 +315,9 @@ module.exports = function (driver) {
   };
 
   this.getToastMessage = async () => {
-    await driver.wait(until.elementIsVisible(driver.findElement(By.id('toast'))), 5000);
-    return await driver.findElement(By.css('#grb-toast-msg')).getText();
+    let toastMsg = await driver.findElement(By.id('grb-toast-msg'));
+    await driver.wait(until.elementIsVisible(toastMsg), 5000);
+    return await toastMsg.getText();
   };
 
   this.getToastElement = async () => {
@@ -325,11 +330,6 @@ module.exports = function (driver) {
     return await driver.executeScript('return $(\'#toast\').width()');
   };
 
-  this.waitForToastClose = async () => {
-    await driver.wait(until.elementIsNotVisible(driver.findElement(By.id('toast'))), 6000);
-    return await driver.findElement(By.css('#grb-toast-msg')).isDisplayed();
-  };
-
   this.closeToast = async () => {
     await driver.wait(until.elementIsNotVisible(driver.findElement(By.id('editModal'))), 5000);
     await driver.findElement(By.css('#toast button.close')).click();
@@ -348,6 +348,15 @@ module.exports = function (driver) {
     await driver.sleep(500); // wait a bit
   };
 
+  this.setTextValue = async (key, value) => {
+    var field = await driver.findElement(By.id(key));
+    if (value && field) {
+      await field.clear();
+      await field.sendKeys(value);
+    }
+    return field;
+  };
+
   this.clients = async () => {
     await driver.wait(until.elementLocated(By.id('clientgrid')), 1000);
     return await driver.findElements(By.className('grb-client'));
@@ -365,7 +374,7 @@ module.exports = function (driver) {
   };
 
   this.mockTaskMessage = async (msg) => {
-    return await driver.executeScript('return $(\'#toast\').toast(\'showTask\', {message: "'+ msg +'", type: "info", icon: "fa-refresh fa-spin fa-fw"});')
+    return await driver.executeScript('return $(\'#toast\').toast(\'showTask\', {message: "' + msg + '", type: "info", icon: "fa-refresh fa-spin fa-fw"});')
   };
 
   this.getVersion = async () => {
