@@ -4,7 +4,7 @@ const TOTAL_ITERATIONS = 50;
 
 for(var i = 0; i < TOTAL_ITERATIONS; i++) {
   console.log('\nRunning Test Scenario # ' + i +'\n');
-  execSync('npm run test', {stdio: 'inherit'});
-  execSync('npm run test:e2e', {stdio: 'inherit'});
+  execSync('bun run test', {stdio: 'inherit'});
+  execSync('bun run test:e2e', {stdio: 'inherit'});
 }
 
