@@ -3,7 +3,7 @@
 #
 # install-wavpack.sh - this file is part of Gerbera.
 #
-# Copyright (C) 2021-2024 Gerbera Contributors
+# Copyright (C) 2021-2025 Gerbera Contributors
 #
 # Gerbera is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License version 2
@@ -20,11 +20,12 @@
 # $Id$
 set -Eeuo pipefail
 
-. $(dirname "${BASH_SOURCE[0]}")/versions.sh
+main_dir=$(dirname "${BASH_SOURCE[0]}")
+main_dir=$(realpath "${main_dir}")/
+. ${main_dir}/versions.sh
 
 VERSION="${WAVPACK-5.4.0}"
 
-#script_dir=$(cd "$(dirname "${BASH_SOURCE[0]}")" &>/dev/null && pwd -P)
 script_dir=`pwd -P`
 src_dir="${script_dir}/wavpack-${VERSION}"
 tgz_file="${script_dir}/wavpack-${VERSION}.tar.xz"
@@ -41,6 +42,7 @@ downloadSource https://github.com/dbry/WavPack/releases/download/${VERSION}/wavp
 #    https://github.com/dbry/WavPack/releases/download/${VERSION}/wavpack-${VERSION}.tar.xz
 
 cmake .. -DBUILD_SHARED_LIBS=${BUILD_SHARED}
+
 ../configure \
     --disable-asm \
     --enable-man \
