@@ -3,7 +3,7 @@
 
   metadata.js - this file is part of Gerbera.
 
-  Copyright (C) 2022-2024 Gerbera Contributors
+  Copyright (C) 2022-2025 Gerbera Contributors
 
   Gerbera is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License version 2
@@ -26,8 +26,9 @@ function importMetadata(meta, cont, rootPath, autoscanId, containerType) {
     var result = [];
     switch (arr[arr.length-1].toLowerCase()) {
         case "nfo":
-            result = parseNfo(meta, rootPath);
+            parseNfo(meta, rootPath);
             updateCdsObject(meta);
+            result.push(meta.id);
             break;
     }
     return result;
