@@ -11,7 +11,7 @@
                             Sergey 'Jin' Bostandzhyan <jin@mediatomb.cc>,
                             Leonhard Wimmer <leo@mediatomb.cc>
 
-    Copyright (C) 2016-2024 Gerbera Contributors
+    Copyright (C) 2016-2025 Gerbera Contributors
 
     MediaTomb is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License version 2
@@ -142,6 +142,7 @@ public:
     /// \brief Retrieve class
     std::string getClass() const { return upnpClass; }
     bool isSubClass(const std::string& cls) const;
+    ObjectType getMediaType(const std::string& contentType = "") const;
 
     /// \brief Set the physical location of the media (usually an absolute path)
     void setLocation(const fs::path& location) { this->location = location; }
@@ -218,6 +219,18 @@ public:
         auto it = std::find_if(metaData.begin(), metaData.end(), [=](auto&& md) { return md.first == field; });
         return it != metaData.end() ? it->second : std::string();
     }
+    /// \brief Query multivalue metadata.
+    std::vector<std::string> getMetaGroup(const std::string& field) const
+    {
+        std::vector<std::string> metaGroup;
+        for (auto&& [mkey, mvalue] : metaData) {
+            if (mkey != field)
+                continue;
+            metaGroup.push_back(mvalue);
+        }
+        return metaGroup;
+    }
+    /// \brief Query multivalue metadata groups.
     std::map<std::string, std::vector<std::string>> getMetaGroups() const
     {
         std::map<std::string, std::vector<std::string>> metaGroups;
@@ -243,6 +256,8 @@ public:
     /// \brief Add a single metadata value.
     void addMetaData(const MetadataFields key, const std::string& value)
     {
+        if (mt_single.at(key))
+            removeMetaData(key);
         metaData.emplace_back(MetaEnumMapper::getMetaFieldName(key), value);
     }
     /// \brief Add a single metadata value.
