@@ -4,7 +4,7 @@
 
     config_generator.cc - this file is part of Gerbera.
 
-    Copyright (C) 2016-2024 Gerbera Contributors
+    Copyright (C) 2016-2025 Gerbera Contributors
 
     Gerbera is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License version 2
@@ -26,6 +26,7 @@
 
 #include "config_generator.h"
 
+#include <numeric>
 #include <sstream>
 
 #include "config/config_definition.h"
@@ -43,6 +44,8 @@
 #define XML_XMLNS_XSI "http://www.w3.org/2001/XMLSchema-instance"
 #define XML_XMLNS "http://mediatomb.cc/config/"
 
+using GeneratorSectionsIterator = EnumIterator<GeneratorSections, GeneratorSections::Server, GeneratorSections::All>;
+
 std::shared_ptr<pugi::xml_node> ConfigGenerator::init()
 {
     if (generated.find("") == generated.end()) {
@@ -52,13 +55,74 @@ std::shared_ptr<pugi::xml_node> ConfigGenerator::init()
     return generated[""];
 }
 
+std::string ConfigGenerator::printSections(int section)
+{
+    std::vector<std::string> myFlags;
+
+    for (auto [bit, label] : sections) {
+        if (section & (1 << to_underlying(bit))) {
+            myFlags.emplace_back(label.data());
+            section &= ~(1 << to_underlying(bit));
+        }
+    }
+
+    if (section) {
+        myFlags.push_back(fmt::format("{:#04x}", section));
+    }
+
+    return fmt::format("{}", fmt::join(myFlags, " | "));
+}
+
+int ConfigGenerator::makeSections(const std::string& optValue)
+{
+    std::vector<std::string> flagsVector = splitString(optValue, '|', false);
+    return std::accumulate(flagsVector.begin(), flagsVector.end(), 0, [](auto flg, auto&& i) { return flg | ConfigGenerator::remapGeneratorSections(trimString(i)); });
+}
+
+std::map<GeneratorSections, std::string_view> ConfigGenerator::sections = {
+    { GeneratorSections::Server, "Server" },
+    { GeneratorSections::Ui, "Ui" },
+    { GeneratorSections::ExtendedRuntime, "ExtendedRuntime" },
+    { GeneratorSections::DynamicContainer, "DynamicContainer" },
+    { GeneratorSections::Database, "Database" },
+    { GeneratorSections::Import, "Import" },
+    { GeneratorSections::Mappings, "Mappings" },
+    { GeneratorSections::Boxlayout, "Boxlayout" },
+    { GeneratorSections::Transcoding, "Transcoding" },
+    { GeneratorSections::OnlineContent, "OnlineContent" },
+
+    { GeneratorSections::All, "All" },
+};
+
+int ConfigGenerator::remapGeneratorSections(const std::string& arg)
+{
+    for (auto&& bit : GeneratorSectionsIterator()) {
+        if (toLower(ConfigGenerator::sections[bit].data()) == toLower(arg)) {
+            return 1 << to_underlying(bit);
+        }
+    }
+
+    if (toLower(ConfigGenerator::sections[GeneratorSections::All].data()) == toLower(arg)) {
+        int result = 0;
+        for (auto&& bit : GeneratorSectionsIterator())
+            result |= 1 << to_underlying(bit);
+        return result;
+    }
+    return stoiString(arg, 0, 0);
+}
+
+bool ConfigGenerator::isGenerated(GeneratorSections section)
+{
+    return this->generateSections == 0 || (this->generateSections & (1 << to_underlying(section)));
+}
+
 std::shared_ptr<pugi::xml_node> ConfigGenerator::getNode(const std::string& tag) const
 {
     log_debug("reading '{}' -> {}", tag, generated.find(tag) == generated.end());
     return generated.at(tag);
 }
 
-std::shared_ptr<pugi::xml_node> ConfigGenerator::setValue(const std::string& tag, const std::string& value, bool makeLastChild)
+std::shared_ptr<pugi::xml_node> ConfigGenerator::setValue(const std::string& tag, const std::shared_ptr<ConfigSetup>& cs, const std::string& value, bool makeLastChild)
 {
     auto split = splitString(tag, '/');
     std::shared_ptr<pugi::xml_node> result;
@@ -89,13 +153,15 @@ std::shared_ptr<pugi::xml_node> ConfigGenerator::setValue(const std::string& tag
                 parent = nodeKey;
             }
         }
-        if (tag.back() != '/') { // create entries without content
-            if (attribute.empty()) {
-                log_debug("setting value '{}' to {}", value, nodeKey);
-                generated[nodeKey]->append_child(pugi::node_pcdata).set_value(value.c_str());
-            } else {
-                log_debug("setting value '{}' to {}:{}", value, parent, attribute);
-                generated[parent]->append_attribute(attribute.c_str()) = value.c_str();
+        if (!cs || !cs->createNodeFromDefaults(generated[parent])) {
+            if (tag.back() != '/') { // create entries without content
+                if (attribute.empty()) {
+                    log_debug("setting value '{}' to {}", value, nodeKey);
+                    generated[nodeKey]->append_child(pugi::node_pcdata).set_value(value.c_str());
+                } else {
+                    log_debug("setting value '{}' to {}:{}", value, parent, attribute);
+                    generated[parent]->append_attribute(attribute.c_str()) = value.c_str();
+                }
             }
         }
     }
@@ -105,7 +171,7 @@ std::shared_ptr<pugi::xml_node> ConfigGenerator::setValue(const std::string& tag
 std::shared_ptr<pugi::xml_node> ConfigGenerator::setValue(ConfigVal option, const std::string& value)
 {
     auto cs = ConfigDefinition::findConfigSetup(option);
-    return setValue(cs->xpath, value.empty() ? cs->getDefaultValue() : value);
+    return setValue(cs->xpath, cs, value.empty() ? cs->getDefaultValue() : value);
 }
 
 std::shared_ptr<pugi::xml_node> ConfigGenerator::setValue(const std::shared_ptr<pugi::xml_node>& parent, ConfigVal option, const std::string& value)
@@ -123,7 +189,7 @@ std::shared_ptr<pugi::xml_node> ConfigGenerator::setValue(const std::shared_ptr<
 std::shared_ptr<pugi::xml_node> ConfigGenerator::setValue(ConfigVal option, ConfigVal attr, const std::string& value)
 {
     auto cs = ConfigDefinition::findConfigSetup(option);
-    return setValue(fmt::format("{}/{}", cs->xpath, ConfigDefinition::mapConfigOption(attr)), value);
+    return setValue(fmt::format("{}/{}", cs->xpath, ConfigDefinition::mapConfigOption(attr)), {}, value);
 }
 
 std::shared_ptr<pugi::xml_node> ConfigGenerator::setValue(ConfigVal option, const std::string& key, const std::string& value)
@@ -133,9 +199,9 @@ std::shared_ptr<pugi::xml_node> ConfigGenerator::setValue(ConfigVal option, cons
         return nullptr;
 
     auto nodeKey = ConfigDefinition::mapConfigOption(cs->nodeOption);
-    setValue(fmt::format("{}/{}/", cs->xpath, nodeKey), "", true);
-    setValue(fmt::format("{}/{}/{}", cs->xpath, nodeKey, ConfigDefinition::ensureAttribute(cs->keyOption)), key);
-    setValue(fmt::format("{}/{}/{}", cs->xpath, nodeKey, ConfigDefinition::ensureAttribute(cs->valOption)), value);
+    setValue(fmt::format("{}/{}/", cs->xpath, nodeKey), {}, "", true);
+    setValue(fmt::format("{}/{}/{}", cs->xpath, nodeKey, ConfigDefinition::ensureAttribute(cs->keyOption)), {}, key);
+    setValue(fmt::format("{}/{}/{}", cs->xpath, nodeKey, ConfigDefinition::ensureAttribute(cs->valOption)), {}, value);
     return generated[cs->xpath];
 }
 
@@ -147,9 +213,9 @@ std::shared_ptr<pugi::xml_node> ConfigGenerator::setDictionary(ConfigVal option)
 
     auto nodeKey = ConfigDefinition::mapConfigOption(cs->nodeOption);
     for (auto&& [key, value] : cs->getXmlContent({})) {
-        setValue(fmt::format("{}/{}/", cs->xpath, nodeKey), "", true);
-        setValue(fmt::format("{}/{}/{}", cs->xpath, nodeKey, ConfigDefinition::ensureAttribute(cs->keyOption)), key);
-        setValue(fmt::format("{}/{}/{}", cs->xpath, nodeKey, ConfigDefinition::ensureAttribute(cs->valOption)), value);
+        setValue(fmt::format("{}/{}/", cs->xpath, nodeKey), {}, "", true);
+        setValue(fmt::format("{}/{}/{}", cs->xpath, nodeKey, ConfigDefinition::ensureAttribute(cs->keyOption)), {}, key);
+        setValue(fmt::format("{}/{}/{}", cs->xpath, nodeKey, ConfigDefinition::ensureAttribute(cs->valOption)), {}, value);
     }
     return generated[cs->xpath];
 }
@@ -162,9 +228,9 @@ std::shared_ptr<pugi::xml_node> ConfigGenerator::setVector(ConfigVal option)
 
     auto nodeKey = ConfigDefinition::mapConfigOption(cs->nodeOption);
     for (auto&& value : cs->getXmlContent({})) {
-        setValue(fmt::format("{}/{}/", cs->xpath, nodeKey), "", true);
+        setValue(fmt::format("{}/{}/", cs->xpath, nodeKey), {}, "", true);
         for (auto&& [key, val] : value)
-            setValue(fmt::format("{}/{}/attribute::{}", cs->xpath, nodeKey, key), val);
+            setValue(fmt::format("{}/{}/attribute::{}", cs->xpath, nodeKey, key), {}, val);
     }
     return generated[cs->xpath];
 }
@@ -172,7 +238,7 @@ std::shared_ptr<pugi::xml_node> ConfigGenerator::setVector(ConfigVal option)
 std::shared_ptr<pugi::xml_node> ConfigGenerator::setValue(ConfigVal option, ConfigVal dict, ConfigVal attr, const std::string& value)
 {
     auto cs = ConfigDefinition::findConfigSetup(option);
-    return setValue(fmt::format("{}/{}/{}", cs->xpath, ConfigDefinition::mapConfigOption(dict), ConfigDefinition::ensureAttribute(attr)), value);
+    return setValue(fmt::format("{}/{}/{}", cs->xpath, ConfigDefinition::mapConfigOption(dict), ConfigDefinition::ensureAttribute(attr)), {}, value);
 }
 
 std::string ConfigGenerator::generate(const fs::path& userHome, const fs::path& configDir, const fs::path& dataDir, const fs::path& magicFile)
@@ -211,10 +277,10 @@ void ConfigGenerator::generateOptions(const std::vector<std::pair<ConfigVal, boo
     }
 }
 
-void ConfigGenerator::generateServer(const fs::path& userHome, const fs::path& configDir, const fs::path& dataDir)
+void ConfigGenerator::generateServerOptions(std::shared_ptr<pugi::xml_node>& server, const fs::path& userHome, const fs::path& configDir, const fs::path& dataDir)
 {
-    auto server = setValue("/server/");
-    generateUi();
+    if (!isGenerated(GeneratorSections::Server))
+        return;
 
     auto options = std::vector<std::pair<ConfigVal, bool>> {
         { ConfigVal::SERVER_NAME, true },
@@ -256,6 +322,9 @@ void ConfigGenerator::generateServer(const fs::path& userHome, const fs::path& c
         { ConfigVal::UPNP_GENRE_NAMESPACES, false },
         { ConfigVal::UPNP_PLAYLIST_NAMESPACES, false },
         { ConfigVal::UPNP_TITLE_NAMESPACES, false },
+        { ConfigVal::UPNP_RESOURCE_PROPERTY_DEFAULTS, false },
+        { ConfigVal::UPNP_OBJECT_PROPERTY_DEFAULTS, false },
+        { ConfigVal::UPNP_CONTAINER_PROPERTY_DEFAULTS, false },
         { ConfigVal::UPNP_CAPTION_COUNT, false },
 #ifdef GRBDEBUG
         { ConfigVal::SERVER_LOG_DEBUG_MODE, false },
@@ -287,7 +356,13 @@ void ConfigGenerator::generateServer(const fs::path& userHome, const fs::path& c
         ALIVE_INTERVAL_MIN)
                             .c_str());
     setValue(ConfigVal::SERVER_ALIVE_INTERVAL);
+}
 
+void ConfigGenerator::generateServer(const fs::path& userHome, const fs::path& configDir, const fs::path& dataDir)
+{
+    auto server = setValue("/server/");
+    generateUi();
+    generateServerOptions(server, userHome, configDir, dataDir);
     generateDatabase(dataDir);
     generateDynamics();
     generateExtendedRuntime();
@@ -295,6 +370,9 @@ void ConfigGenerator::generateServer(const fs::path& userHome, const fs::path& c
 
 void ConfigGenerator::generateUi()
 {
+    if (!isGenerated(GeneratorSections::Ui))
+        return;
+
     auto options = std::vector<std::pair<ConfigVal, bool>> {
         { ConfigVal::SERVER_UI_ENABLED, true },
         { ConfigVal::SERVER_UI_SHOW_TOOLTIPS, true },
@@ -315,6 +393,9 @@ void ConfigGenerator::generateUi()
 
 void ConfigGenerator::generateDynamics()
 {
+    if (!isGenerated(GeneratorSections::DynamicContainer))
+        return;
+
     auto options = std::vector<std::pair<ConfigVal, bool>> {
         { ConfigVal::SERVER_DYNAMIC_CONTENT_LIST_ENABLED, true },
     };
@@ -325,21 +406,31 @@ void ConfigGenerator::generateDynamics()
     auto&& containersTag = ConfigDefinition::mapConfigOption(ConfigVal::SERVER_DYNAMIC_CONTENT_LIST);
     auto&& containerTag = ConfigDefinition::mapConfigOption(ConfigVal::A_DYNAMIC_CONTAINER);
 
-    auto container = setValue(fmt::format("{}/{}/", containersTag, containerTag), "", true);
+    auto container = setValue(fmt::format("{}/{}/", containersTag, containerTag), {}, "", true);
     setValue(container, ConfigVal::A_DYNAMIC_CONTAINER_LOCATION, "/LastAdded");
     setValue(container, ConfigVal::A_DYNAMIC_CONTAINER_TITLE, "Recently Added");
     setValue(container, ConfigVal::A_DYNAMIC_CONTAINER_SORT, "-last_updated");
     setValue(container, ConfigVal::A_DYNAMIC_CONTAINER_FILTER, R"(upnp:class derivedfrom "object.item" and last_updated > "@last7")");
 
-    container = setValue(fmt::format("{}/{}/", containersTag, containerTag), "", true);
+    container = setValue(fmt::format("{}/{}/", containersTag, containerTag), {}, "", true);
     setValue(container, ConfigVal::A_DYNAMIC_CONTAINER_LOCATION, "/LastModified");
     setValue(container, ConfigVal::A_DYNAMIC_CONTAINER_TITLE, "Recently Modified");
     setValue(container, ConfigVal::A_DYNAMIC_CONTAINER_SORT, "-last_modified");
     setValue(container, ConfigVal::A_DYNAMIC_CONTAINER_FILTER, R"(upnp:class derivedfrom "object.item" and last_modified > "@last7")");
+
+    container = setValue(fmt::format("{}/{}/", containersTag, containerTag), {}, "", true);
+    setValue(container, ConfigVal::A_DYNAMIC_CONTAINER_LOCATION, "/LastPlayed");
+    setValue(container, ConfigVal::A_DYNAMIC_CONTAINER_TITLE, "Music Recently Played");
+    setValue(container, ConfigVal::A_DYNAMIC_CONTAINER_SORT, "-upnp:lastPlaybackTime");
+    setValue(container, ConfigVal::A_DYNAMIC_CONTAINER_UPNP_SHORTCUT, "MUSIC_LAST_PLAYED");
+    setValue(container, ConfigVal::A_DYNAMIC_CONTAINER_FILTER, R"(upnp:class derivedfrom "object.item.audioItem" and upnp:lastPlaybackTime > "@last7")");
 }
 
 void ConfigGenerator::generateDatabase(const fs::path& prefixDir)
 {
+    if (!isGenerated(GeneratorSections::Database))
+        return;
+
     auto options = std::vector<std::pair<ConfigVal, bool>> {
         { ConfigVal::SERVER_STORAGE_SQLITE_ENABLED, true },
         { ConfigVal::SERVER_STORAGE_SQLITE_DATABASE_FILE, true },
@@ -386,27 +477,29 @@ void ConfigGenerator::generateDatabase(const fs::path& prefixDir)
 
 void ConfigGenerator::generateExtendedRuntime()
 {
-    auto options = std::vector<std::pair<ConfigVal, bool>>
-    {
-#if defined(HAVE_FFMPEG) && defined(HAVE_FFMPEGTHUMBNAILER)
+    if (!isGenerated(GeneratorSections::ExtendedRuntime))
+        return;
+
+    auto options = std::vector<std::pair<ConfigVal, bool>> {
+#ifdef HAVE_FFMPEGTHUMBNAILER
         { ConfigVal::SERVER_EXTOPTS_FFMPEGTHUMBNAILER_ENABLED, true }, // clang does require additional indentation
-            { ConfigVal::SERVER_EXTOPTS_FFMPEGTHUMBNAILER_THUMBSIZE, true },
-            { ConfigVal::SERVER_EXTOPTS_FFMPEGTHUMBNAILER_SEEK_PERCENTAGE, true },
-            { ConfigVal::SERVER_EXTOPTS_FFMPEGTHUMBNAILER_FILMSTRIP_OVERLAY, true },
-            { ConfigVal::SERVER_EXTOPTS_FFMPEGTHUMBNAILER_IMAGE_QUALITY, true },
-            { ConfigVal::SERVER_EXTOPTS_FFMPEGTHUMBNAILER_VIDEO_ENABLED, false },
-            { ConfigVal::SERVER_EXTOPTS_FFMPEGTHUMBNAILER_IMAGE_ENABLED, false },
-            { ConfigVal::SERVER_EXTOPTS_FFMPEGTHUMBNAILER_CACHE_DIR_ENABLED, false },
-            { ConfigVal::SERVER_EXTOPTS_FFMPEGTHUMBNAILER_CACHE_DIR, false },
+        { ConfigVal::SERVER_EXTOPTS_FFMPEGTHUMBNAILER_THUMBSIZE, true },
+        { ConfigVal::SERVER_EXTOPTS_FFMPEGTHUMBNAILER_SEEK_PERCENTAGE, true },
+        { ConfigVal::SERVER_EXTOPTS_FFMPEGTHUMBNAILER_FILMSTRIP_OVERLAY, true },
+        { ConfigVal::SERVER_EXTOPTS_FFMPEGTHUMBNAILER_IMAGE_QUALITY, true },
+        { ConfigVal::SERVER_EXTOPTS_FFMPEGTHUMBNAILER_VIDEO_ENABLED, false },
+        { ConfigVal::SERVER_EXTOPTS_FFMPEGTHUMBNAILER_IMAGE_ENABLED, false },
+        { ConfigVal::SERVER_EXTOPTS_FFMPEGTHUMBNAILER_CACHE_DIR_ENABLED, false },
+        { ConfigVal::SERVER_EXTOPTS_FFMPEGTHUMBNAILER_CACHE_DIR, false },
 #endif
-            { ConfigVal::SERVER_EXTOPTS_MARK_PLAYED_ITEMS_ENABLED, true },
-            { ConfigVal::SERVER_EXTOPTS_MARK_PLAYED_ITEMS_SUPPRESS_CDS_UPDATES, true },
-            { ConfigVal::SERVER_EXTOPTS_MARK_PLAYED_ITEMS_STRING_MODE_PREPEND, true },
-            { ConfigVal::SERVER_EXTOPTS_MARK_PLAYED_ITEMS_STRING, true },
+        { ConfigVal::SERVER_EXTOPTS_MARK_PLAYED_ITEMS_ENABLED, true },
+        { ConfigVal::SERVER_EXTOPTS_MARK_PLAYED_ITEMS_SUPPRESS_CDS_UPDATES, true },
+        { ConfigVal::SERVER_EXTOPTS_MARK_PLAYED_ITEMS_STRING_MODE_PREPEND, true },
+        { ConfigVal::SERVER_EXTOPTS_MARK_PLAYED_ITEMS_STRING, true },
 #ifdef HAVE_LASTFMLIB
-            { ConfigVal::SERVER_EXTOPTS_LASTFM_ENABLED, false },
-            { ConfigVal::SERVER_EXTOPTS_LASTFM_USERNAME, false },
-            { ConfigVal::SERVER_EXTOPTS_LASTFM_PASSWORD, false },
+        { ConfigVal::SERVER_EXTOPTS_LASTFM_ENABLED, false },
+        { ConfigVal::SERVER_EXTOPTS_LASTFM_USERNAME, false },
+        { ConfigVal::SERVER_EXTOPTS_LASTFM_PASSWORD, false },
 #endif
     };
     generateOptions(options);
@@ -414,8 +507,11 @@ void ConfigGenerator::generateExtendedRuntime()
     setValue(ConfigVal::SERVER_EXTOPTS_MARK_PLAYED_ITEMS_CONTENT_LIST, ConfigVal::A_SERVER_EXTOPTS_MARK_PLAYED_ITEMS_CONTENT, DEFAULT_MARK_PLAYED_CONTENT_VIDEO);
 }
 
-void ConfigGenerator::generateImport(const fs::path& prefixDir, const fs::path& configDir, const fs::path& magicFile)
+void ConfigGenerator::generateImportOptions(const fs::path& prefixDir, const fs::path& configDir, const fs::path& magicFile)
 {
+    if (!isGenerated(GeneratorSections::Import))
+        return;
+
     // Simple Import options
     auto options = std::vector<std::pair<ConfigVal, bool>> {
 #ifdef HAVE_MAGIC
@@ -438,7 +534,9 @@ void ConfigGenerator::generateImport(const fs::path& prefixDir, const fs::path&
         { ConfigVal::IMPORT_SCRIPTING_IMPORT_FUNCTION_AUDIOFILE, true },
         { ConfigVal::IMPORT_SCRIPTING_IMPORT_FUNCTION_VIDEOFILE, true },
         { ConfigVal::IMPORT_SCRIPTING_IMPORT_FUNCTION_IMAGEFILE, true },
+#ifdef ONLINESERVICES
         { ConfigVal::IMPORT_SCRIPTING_IMPORT_FUNCTION_TRAILER, true },
+#endif
         { ConfigVal::IMPORT_SCRIPTING_CUSTOM_FOLDER, false },
         { ConfigVal::IMPORT_SCRIPTING_PLAYLIST_LINK_OBJECTS, false },
         { ConfigVal::IMPORT_SCRIPTING_STRUCTURED_LAYOUT_SKIPCHARS, false },
@@ -521,12 +619,12 @@ void ConfigGenerator::generateImport(const fs::path& prefixDir, const fs::path&
         auto&& directoryTag = ConfigDefinition::mapConfigOption(ConfigVal::A_AUTOSCAN_DIRECTORY);
 #ifdef HAVE_INOTIFY
         auto&& autoscanTag = ConfigDefinition::mapConfigOption(ConfigVal::IMPORT_AUTOSCAN_INOTIFY_LIST);
-        auto as = setValue(fmt::format("{}/{}/", autoscanTag, directoryTag), "", true);
+        auto as = setValue(fmt::format("{}/{}/", autoscanTag, directoryTag), {}, "", true);
         setValue(as, ConfigVal::A_AUTOSCAN_DIRECTORY_LOCATION, "/media");
         setValue(as, ConfigVal::A_AUTOSCAN_DIRECTORY_MODE, "inotify");
 #else
         auto&& autoscanTag = ConfigDefinition::mapConfigOption(ConfigVal::IMPORT_AUTOSCAN_TIMED_LIST);
-        auto as = setValue(fmt::format("{}/{}/", autoscanTag, directoryTag), "", true);
+        auto as = setValue(fmt::format("{}/{}/", autoscanTag, directoryTag), {}, "", true);
         setValue(as, ConfigVal::A_AUTOSCAN_DIRECTORY_LOCATION, "/media");
         setValue(as, ConfigVal::A_AUTOSCAN_DIRECTORY_MODE, "timed");
         setValue(as, ConfigVal::A_AUTOSCAN_DIRECTORY_INTERVAL, "1000");
@@ -563,7 +661,11 @@ void ConfigGenerator::generateImport(const fs::path& prefixDir, const fs::path&
 #endif
     }
     generateOptions(options);
+}
 
+void ConfigGenerator::generateImport(const fs::path& prefixDir, const fs::path& configDir, const fs::path& magicFile)
+{
+    generateImportOptions(prefixDir, configDir, magicFile);
     generateMappings();
     generateBoxlayout(ConfigVal::BOXLAYOUT_BOX);
 #ifdef ONLINE_SERVICES
@@ -573,6 +675,9 @@ void ConfigGenerator::generateImport(const fs::path& prefixDir, const fs::path&
 
 void ConfigGenerator::generateMappings()
 {
+    if (!isGenerated(GeneratorSections::Mappings))
+        return;
+
     auto ext2mt = setValue(ConfigVal::IMPORT_MAPPINGS_IGNORE_UNKNOWN_EXTENSIONS);
     setDictionary(ConfigVal::IMPORT_MAPPINGS_EXTENSION_TO_MIMETYPE_LIST);
 
@@ -596,15 +701,20 @@ void ConfigGenerator::generateMappings()
 
 void ConfigGenerator::generateBoxlayout(ConfigVal option)
 {
+    if (!isGenerated(GeneratorSections::Boxlayout))
+        return;
+
     auto cs = ConfigDefinition::findConfigSetup<ConfigBoxLayoutSetup>(option);
 
     const auto boxTag = ConfigDefinition::mapConfigOption(option);
 
     for (auto&& bl : cs->getDefault()) {
-        auto box = setValue(fmt::format("{}/", boxTag), "", true);
+        auto box = setValue(fmt::format("{}/", boxTag), {}, "", true);
         setValue(box, ConfigVal::A_BOXLAYOUT_BOX_KEY, bl.getKey());
         setValue(box, ConfigVal::A_BOXLAYOUT_BOX_TITLE, bl.getTitle());
         setValue(box, ConfigVal::A_BOXLAYOUT_BOX_CLASS, bl.getClass());
+        if (!bl.getUpnpShortcut().empty())
+            setValue(box, ConfigVal::A_BOXLAYOUT_BOX_UPNP_SHORTCUT, bl.getUpnpShortcut());
         if (bl.getSize() != 1)
             setValue(box, ConfigVal::A_BOXLAYOUT_BOX_SIZE, fmt::to_string(bl.getSize()));
         if (!bl.getEnabled())
@@ -614,24 +724,22 @@ void ConfigGenerator::generateBoxlayout(ConfigVal option)
 
 void ConfigGenerator::generateOnlineContent()
 {
-    auto options = std::vector<std::pair<ConfigVal, bool>> {
-#ifdef ATRAILERS
-        { ConfigVal::ONLINE_CONTENT_ATRAILERS_ENABLED, true },
-        { ConfigVal::ONLINE_CONTENT_ATRAILERS_REFRESH, true },
-        { ConfigVal::ONLINE_CONTENT_ATRAILERS_UPDATE_AT_START, true },
-        { ConfigVal::ONLINE_CONTENT_ATRAILERS_RESOLUTION, true },
-        { ConfigVal::ONLINE_CONTENT_ATRAILERS_PURGE_AFTER, false },
-#endif
-    };
+    if (!isGenerated(GeneratorSections::OnlineContent))
+        return;
+
+    auto options = std::vector<std::pair<ConfigVal, bool>> {};
     generateOptions(options);
 
-#ifndef ATRAILERS
+#ifdef ONLINE_SERVICES
     setValue("/import/online-content/");
 #endif
 }
 
 void ConfigGenerator::generateTranscoding()
 {
+    if (!isGenerated(GeneratorSections::Transcoding))
+        return;
+
     auto options = std::vector<std::pair<ConfigVal, bool>> {
         { ConfigVal::TRANSCODING_TRANSCODING_ENABLED, true },
         { ConfigVal::TRANSCODING_MIMETYPE_PROF_MAP_ALLOW_UNUSED, false },
@@ -646,7 +754,7 @@ void ConfigGenerator::generateTranscoding()
 
     const auto profileTag = ConfigDefinition::mapConfigOption(ConfigVal::A_TRANSCODING_PROFILES_PROFLE);
 
-    auto oggmp3 = setValue(fmt::format("{}/", profileTag), "", true);
+    auto oggmp3 = setValue(fmt::format("{}/", profileTag), {}, "", true);
     setValue(oggmp3, ConfigVal::A_TRANSCODING_PROFILES_PROFLE_NAME, "ogg2mp3");
     setValue(oggmp3, ConfigVal::A_TRANSCODING_PROFILES_PROFLE_ENABLED, NO);
     setValue(oggmp3, ConfigVal::A_TRANSCODING_PROFILES_PROFLE_TYPE, "external");
@@ -655,16 +763,16 @@ void ConfigGenerator::generateTranscoding()
     setValue(oggmp3, ConfigVal::A_TRANSCODING_PROFILES_PROFLE_FIRST, YES);
     setValue(oggmp3, ConfigVal::A_TRANSCODING_PROFILES_PROFLE_ACCOGG, NO);
 
-    auto agent = setValue(fmt::format("{}/{}/", profileTag, ConfigDefinition::mapConfigOption(ConfigVal::A_TRANSCODING_PROFILES_PROFLE_AGENT)), "", true);
+    auto agent = setValue(fmt::format("{}/{}/", profileTag, ConfigDefinition::mapConfigOption(ConfigVal::A_TRANSCODING_PROFILES_PROFLE_AGENT)), {}, "", true);
     setValue(agent, ConfigVal::A_TRANSCODING_PROFILES_PROFLE_AGENT_COMMAND, "ffmpeg");
     setValue(agent, ConfigVal::A_TRANSCODING_PROFILES_PROFLE_AGENT_ARGS, "-y -i %in -f mp3 %out");
 
-    auto buffer = setValue(fmt::format("{}/{}/", profileTag, ConfigDefinition::mapConfigOption(ConfigVal::A_TRANSCODING_PROFILES_PROFLE_BUFFER)), "", true);
+    auto buffer = setValue(fmt::format("{}/{}/", profileTag, ConfigDefinition::mapConfigOption(ConfigVal::A_TRANSCODING_PROFILES_PROFLE_BUFFER)), {}, "", true);
     setValue(buffer, ConfigVal::A_TRANSCODING_PROFILES_PROFLE_BUFFER_SIZE, fmt::to_string(DEFAULT_AUDIO_BUFFER_SIZE));
     setValue(buffer, ConfigVal::A_TRANSCODING_PROFILES_PROFLE_BUFFER_CHUNK, fmt::to_string(DEFAULT_AUDIO_CHUNK_SIZE));
     setValue(buffer, ConfigVal::A_TRANSCODING_PROFILES_PROFLE_BUFFER_FILL, fmt::to_string(DEFAULT_AUDIO_FILL_SIZE));
 
-    auto vlcmpeg = setValue(fmt::format("{}/", profileTag), "", true);
+    auto vlcmpeg = setValue(fmt::format("{}/", profileTag), {}, "", true);
     setValue(vlcmpeg, ConfigVal::A_TRANSCODING_PROFILES_PROFLE_NAME, "vlcmpeg");
     setValue(vlcmpeg, ConfigVal::A_TRANSCODING_PROFILES_PROFLE_ENABLED, NO);
     setValue(vlcmpeg, ConfigVal::A_TRANSCODING_PROFILES_PROFLE_TYPE, "external");
@@ -673,11 +781,11 @@ void ConfigGenerator::generateTranscoding()
     setValue(vlcmpeg, ConfigVal::A_TRANSCODING_PROFILES_PROFLE_FIRST, YES);
     setValue(vlcmpeg, ConfigVal::A_TRANSCODING_PROFILES_PROFLE_ACCOGG, YES);
 
-    agent = setValue(fmt::format("{}/{}/", profileTag, ConfigDefinition::mapConfigOption(ConfigVal::A_TRANSCODING_PROFILES_PROFLE_AGENT)), "", true);
+    agent = setValue(fmt::format("{}/{}/", profileTag, ConfigDefinition::mapConfigOption(ConfigVal::A_TRANSCODING_PROFILES_PROFLE_AGENT)), {}, "", true);
     setValue(agent, ConfigVal::A_TRANSCODING_PROFILES_PROFLE_AGENT_COMMAND, "vlc");
     setValue(agent, ConfigVal::A_TRANSCODING_PROFILES_PROFLE_AGENT_ARGS, "-I dummy %in --sout #transcode{venc=ffmpeg,vcodec=mp2v,vb=4096,fps=25,aenc=ffmpeg,acodec=mpga,ab=192,samplerate=44100,channels=2}:standard{access=file,mux=ps,dst=%out} vlc://quit");
 
-    buffer = setValue(fmt::format("{}/{}/", profileTag, ConfigDefinition::mapConfigOption(ConfigVal::A_TRANSCODING_PROFILES_PROFLE_BUFFER)), "", true);
+    buffer = setValue(fmt::format("{}/{}/", profileTag, ConfigDefinition::mapConfigOption(ConfigVal::A_TRANSCODING_PROFILES_PROFLE_BUFFER)), {}, "", true);
     setValue(buffer, ConfigVal::A_TRANSCODING_PROFILES_PROFLE_BUFFER_SIZE, fmt::to_string(DEFAULT_VIDEO_BUFFER_SIZE));
     setValue(buffer, ConfigVal::A_TRANSCODING_PROFILES_PROFLE_BUFFER_CHUNK, fmt::to_string(DEFAULT_VIDEO_CHUNK_SIZE));
     setValue(buffer, ConfigVal::A_TRANSCODING_PROFILES_PROFLE_BUFFER_FILL, fmt::to_string(DEFAULT_VIDEO_FILL_SIZE));
