@@ -11,7 +11,7 @@
                             Sergey 'Jin' Bostandzhyan <jin@mediatomb.cc>,
                             Leonhard Wimmer <leo@mediatomb.cc>
 
-    Copyright (C) 2016-2024 Gerbera Contributors
+    Copyright (C) 2016-2025 Gerbera Contributors
 
     MediaTomb is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License version 2
@@ -35,8 +35,10 @@
 #include "config_manager.h" // API
 
 #include "config/result/autoscan.h"
+#include "config/result/box_layout.h"
 #include "config/result/client_config.h"
 #include "config/result/transcoding.h"
+#include "config/setup/config_setup_boxlayout.h"
 #include "config/setup/config_setup_path.h"
 #include "config_definition.h"
 #include "config_option_enum.h"
@@ -68,12 +70,12 @@ ConfigManager::ConfigManager(fs::path filename,
         fs::path home = userHome / configDir;
         this->filename = home / DEFAULT_CONFIG_NAME;
     }
-
+    this->filename = fs::weakly_canonical(this->filename);
     std::error_code ec;
     if (!isRegularFile(this->filename, ec)) {
         std::ostringstream expErrMsg;
         expErrMsg << "\nThe server configuration file could not be found: ";
-        expErrMsg << this->filename << "\n";
+        expErrMsg << this->filename.string() << "\n";
         expErrMsg << "Gerbera could not find a default configuration file.\n";
         expErrMsg << "Try specifying an alternative configuration file on the command line.\n";
         expErrMsg << "For a list of options run: gerbera -h\n";
@@ -106,7 +108,7 @@ void ConfigManager::load(const fs::path& userHome)
     std::map<std::string, std::string> args;
     auto self = getSelf();
 
-    log_info("Loading configuration from: {}", filename.c_str());
+    log_info("Loading configuration from: {}", filename.string());
     pugi::xml_parse_result result = xmlDoc->load_file(filename.c_str());
     if (result.status != pugi::xml_parse_status::status_ok) {
         throw ConfigParseException(result.description());
@@ -294,7 +296,7 @@ void ConfigManager::load(const fs::path& userHome)
     setOption(root, ConfigVal::IMPORT_LIBOPTS_ENTRY_LEGACY_SEP, &args);
     args.clear();
 
-#if defined(HAVE_FFMPEG) && defined(HAVE_FFMPEGTHUMBNAILER)
+#ifdef HAVE_FFMPEGTHUMBNAILER
     auto ffmpEn = setOption(root, ConfigVal::SERVER_EXTOPTS_FFMPEGTHUMBNAILER_ENABLED)->getBoolOption();
     if (ffmpEn) {
         setOption(root, ConfigVal::SERVER_EXTOPTS_FFMPEGTHUMBNAILER_THUMBSIZE);
@@ -306,7 +308,7 @@ void ConfigManager::load(const fs::path& userHome)
     }
 #endif
 
-#if defined(HAVE_LASTFMLIB)
+#ifdef HAVE_LASTFMLIB
     auto lfmEn = setOption(root, ConfigVal::SERVER_EXTOPTS_LASTFM_ENABLED)->getBoolOption();
     if (lfmEn) {
         setOption(root, ConfigVal::SERVER_EXTOPTS_LASTFM_USERNAME);
@@ -314,14 +316,6 @@ void ConfigManager::load(const fs::path& userHome)
     }
 #endif
 
-    // read online content options
-#ifdef ATRAILERS
-    auto atrailersRefresh = setOption(root, ConfigVal::ONLINE_CONTENT_ATRAILERS_REFRESH)->getIntOption();
-
-    co = ConfigDefinition::findConfigSetup(ConfigVal::ONLINE_CONTENT_ATRAILERS_PURGE_AFTER);
-    co->makeOption(fmt::to_string(atrailersRefresh), self);
-#endif
-
     // read options that do not have special requirement and that are not yet loaded
     for (auto&& optionKey : ConfigOptionIterator()) {
         if (!options.at(to_underlying(optionKey)) && !ConfigDefinition::isDependent(optionKey)) {
@@ -412,6 +406,9 @@ bool ConfigManager::validate()
                                 "however you specified \"js\" to be used for the "
                                 "virtual-layout.");
 #endif
+    auto co = ConfigDefinition::findConfigSetup<ConfigBoxLayoutSetup>(ConfigVal::BOXLAYOUT_BOX);
+    if (!co->validate(getSelf(), getBoxLayoutListOption(ConfigVal::BOXLAYOUT_BOX)))
+        throw_std_runtime_error("Validation of {} failed", co->xpath);
 
     log_info("Configuration check succeeded.");
     return true;
@@ -434,11 +431,12 @@ void ConfigManager::updateConfigFromDatabase(const std::shared_ptr<Database>& da
                     cs->makeOption(cfgValue.value, self);
                 } else {
                     std::string parValue = cfgValue.value;
-                    if (cfgValue.status == STATUS_CHANGED || cfgValue.status == STATUS_UNCHANGED) {
+                    auto statusList = splitString(cfgValue.status, ',');
+                    if (statusList.back() == STATUS_CHANGED || statusList.back() == STATUS_UNCHANGED) {
                         if (!cs->updateDetail(cfgValue.item, parValue, self)) {
                             log_error("unhandled {} option {} != {}", cfgValue.status, cfgValue.item, cs->xpath);
                         }
-                    } else if (cfgValue.status == STATUS_REMOVED || cfgValue.status == STATUS_ADDED || cfgValue.status == STATUS_MANUAL) {
+                    } else if (statusList.back() == STATUS_REMOVED || statusList.back() == STATUS_ADDED || statusList.back() == STATUS_MANUAL) {
                         std::map<std::string, std::string> arguments { { "status", cfgValue.status } };
                         if (!cs->updateDetail(cfgValue.item, parValue, self, &arguments)) {
                             log_error("unhandled {} option {} != {}", cfgValue.status, cfgValue.item, cs->xpath);
@@ -485,7 +483,8 @@ std::string ConfigManager::getOption(ConfigVal option) const
 {
     auto optionValue = options.at(to_underlying(option));
     if (!optionValue) {
-        throw_std_runtime_error("option {} not set", option);
+        auto cs = ConfigDefinition::findConfigSetup(option);
+        throw_std_runtime_error("string option {}='{}' not set", option, cs->getItemPathRoot());
     }
     return optionValue->getOption();
 }
@@ -494,7 +493,8 @@ IntOptionType ConfigManager::getIntOption(ConfigVal option) const
 {
     auto optionValue = options.at(to_underlying(option));
     if (!optionValue) {
-        throw_std_runtime_error("option {} not set", option);
+        auto cs = ConfigDefinition::findConfigSetup(option);
+        throw_std_runtime_error("int option {}='{}' not set", option, cs->getItemPathRoot());
     }
     return optionValue->getIntOption();
 }
@@ -503,7 +503,8 @@ UIntOptionType ConfigManager::getUIntOption(ConfigVal option) const
 {
     auto optionValue = options.at(to_underlying(option));
     if (!optionValue) {
-        throw_std_runtime_error("option {} not set", option);
+        auto cs = ConfigDefinition::findConfigSetup(option);
+        throw_std_runtime_error("uint option {}='{}' not set", option, cs->getItemPathRoot());
     }
     return optionValue->getUIntOption();
 }
@@ -512,7 +513,8 @@ LongOptionType ConfigManager::getLongOption(ConfigVal option) const
 {
     auto optionValue = options.at(to_underlying(option));
     if (!optionValue) {
-        throw_std_runtime_error("option {} not set", option);
+        auto cs = ConfigDefinition::findConfigSetup(option);
+        throw_std_runtime_error("long option {}='{}' not set", option, cs->getItemPathRoot());
     }
     return optionValue->getLongOption();
 }
@@ -521,7 +523,8 @@ std::shared_ptr<ConfigOption> ConfigManager::getConfigOption(ConfigVal option) c
 {
     auto optionValue = options.at(to_underlying(option));
     if (!optionValue) {
-        throw_std_runtime_error("option {} not set", option);
+        auto cs = ConfigDefinition::findConfigSetup(option);
+        throw_std_runtime_error("option {}='{}'not set", option, cs->getItemPathRoot());
     }
     return optionValue;
 }
@@ -530,7 +533,8 @@ bool ConfigManager::getBoolOption(ConfigVal option) const
 {
     auto optionValue = options.at(to_underlying(option));
     if (!optionValue) {
-        throw_std_runtime_error("option {} not set", option);
+        auto cs = ConfigDefinition::findConfigSetup(option);
+        throw_std_runtime_error("bool option {}='{}' not set", option, cs->getItemPathRoot());
     }
     return optionValue->getBoolOption();
 }
@@ -539,7 +543,8 @@ std::map<std::string, std::string> ConfigManager::getDictionaryOption(ConfigVal
 {
     auto optionValue = options.at(to_underlying(option));
     if (!optionValue) {
-        throw_std_runtime_error("option {} not set", option);
+        auto cs = ConfigDefinition::findConfigSetup(option);
+        throw_std_runtime_error("dictionary option {}='{}' not set", option, cs->getItemPathRoot());
     }
     return optionValue->getDictionaryOption();
 }
@@ -548,7 +553,8 @@ std::vector<std::vector<std::pair<std::string, std::string>>> ConfigManager::get
 {
     auto optionValue = options.at(to_underlying(option));
     if (!optionValue) {
-        throw_std_runtime_error("option {} not set", option);
+        auto cs = ConfigDefinition::findConfigSetup(option);
+        throw_std_runtime_error("vector option {}='{}' not set", option, cs->getItemPathRoot());
     }
     return optionValue->getVectorOption();
 }
@@ -557,7 +563,8 @@ std::vector<std::string> ConfigManager::getArrayOption(ConfigVal option) const
 {
     auto optionValue = options.at(to_underlying(option));
     if (!optionValue) {
-        throw_std_runtime_error("option {} not set", option);
+        auto cs = ConfigDefinition::findConfigSetup(option);
+        throw_std_runtime_error("array option {}='{}' not set", option, cs->getItemPathRoot());
     }
     return optionValue->getArrayOption();
 }
@@ -566,7 +573,8 @@ std::vector<std::shared_ptr<AutoscanDirectory>> ConfigManager::getAutoscanListOp
 {
     auto optionValue = options.at(to_underlying(option));
     if (!optionValue) {
-        throw_std_runtime_error("option {} not set", option);
+        auto cs = ConfigDefinition::findConfigSetup(option);
+        throw_std_runtime_error("autoscan option {}='{}' not set", option, cs->getItemPathRoot());
     }
     return optionValue->getAutoscanListOption();
 }
@@ -575,7 +583,8 @@ std::shared_ptr<BoxLayoutList> ConfigManager::getBoxLayoutListOption(ConfigVal o
 {
     auto optionValue = options.at(to_underlying(option));
     if (!optionValue) {
-        throw_std_runtime_error("option {} not set", option);
+        auto cs = ConfigDefinition::findConfigSetup(option);
+        throw_std_runtime_error("box layout option {}='{}' not set", option, cs->getItemPathRoot());
     }
     return optionValue->getBoxLayoutListOption();
 }
@@ -584,7 +593,8 @@ std::shared_ptr<ClientConfigList> ConfigManager::getClientConfigListOption(Confi
 {
     auto optionValue = options.at(to_underlying(option));
     if (!optionValue) {
-        throw_std_runtime_error("option {} not set", option);
+        auto cs = ConfigDefinition::findConfigSetup(option);
+        throw_std_runtime_error("client config option {}='{}' not set", option, cs->getItemPathRoot());
     }
     return optionValue->getClientConfigListOption();
 }
@@ -593,7 +603,8 @@ std::shared_ptr<DirectoryConfigList> ConfigManager::getDirectoryTweakOption(Conf
 {
     auto optionValue = options.at(to_underlying(option));
     if (!optionValue) {
-        throw_std_runtime_error("option {} not set", option);
+        auto cs = ConfigDefinition::findConfigSetup(option);
+        throw_std_runtime_error("directory tweak option {}='{}' not set", option, cs->getItemPathRoot());
     }
     return optionValue->getDirectoryTweakOption();
 }
@@ -602,7 +613,8 @@ std::shared_ptr<DynamicContentList> ConfigManager::getDynamicContentListOption(C
 {
     auto optionValue = options.at(to_underlying(option));
     if (!optionValue) {
-        throw_std_runtime_error("option {} not set", option);
+        auto cs = ConfigDefinition::findConfigSetup(option);
+        throw_std_runtime_error("dynamic folder option {}='{}' not set", option, cs->getItemPathRoot());
     }
     return optionValue->getDynamicContentListOption();
 }
@@ -611,7 +623,8 @@ std::shared_ptr<TranscodingProfileList> ConfigManager::getTranscodingProfileList
 {
     auto optionValue = options.at(to_underlying(option));
     if (!optionValue) {
-        throw_std_runtime_error("option {} not set", option);
+        auto cs = ConfigDefinition::findConfigSetup(option);
+        throw_std_runtime_error("transcoding option {}='{}' not set", option, cs->getItemPathRoot());
     }
     return optionValue->getTranscodingProfileListOption();
 }
