@@ -3,7 +3,7 @@ Gerbera - https://gerbera.io/
 
     grb_runtime.cc - this file is part of Gerbera.
 
-    Copyright (C) 2024 Gerbera Contributors
+    Copyright (C) 2024-2025 Gerbera Contributors
 
     Gerbera is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License version 2
@@ -37,9 +37,9 @@ Gerbera - https://gerbera.io/
 #ifndef _GNU_SOURCE
 #define _GNU_SOURCE
 #endif
+
 #include <grp.h>
 #include <pwd.h>
-
 #include <spdlog/sinks/basic_file_sink.h>
 #include <spdlog/sinks/rotating_file_sink.h>
 #include <spdlog/sinks/syslog_sink.h>
@@ -47,9 +47,6 @@ Gerbera - https://gerbera.io/
 #include <sys/types.h>
 #include <unistd.h>
 
-static constexpr auto gitBranch = std::string_view(GIT_BRANCH);
-static constexpr auto gitCommitHash = std::string_view(GIT_COMMIT_HASH);
-
 GerberaRuntime::GerberaRuntime()
     : confDir(DEFAULT_CONFIG_HOME)
 {
@@ -191,7 +188,7 @@ bool GerberaRuntime::setRotatelog(const std::string& arg)
     if (!fs::directory_entry(logfile->parent_path()).exists()) {
         log_warning("Log dir {} missing", logfile->parent_path().c_str());
     }
-    auto rotateLogger = spdlog::rotating_logger_st("rotate_logger", *logfile, max_size, max_files);
+    auto rotateLogger = spdlog::rotating_logger_mt("rotate_logger", *logfile, max_size, max_files);
     if (!defaultLogger)
         defaultLogger = spdlog::default_logger();
     spdlog::set_default_logger(rotateLogger);
@@ -207,7 +204,7 @@ bool GerberaRuntime::setSyslog(const std::string& arg)
     if (logLevel == 0) {
         log_warning("Unknown Log facility {}, using USER", logLevelStr.value_or(""));
     }
-    auto sysLogger = spdlog::syslog_logger_st("syslog_logger", ProgramName, LOG_PID, logLevel, true);
+    auto sysLogger = spdlog::syslog_logger_mt("syslog_logger", ProgramName, LOG_PID, logLevel, true);
     if (!defaultLogger)
         defaultLogger = spdlog::default_logger();
     spdlog::set_default_logger(sysLogger);
@@ -411,38 +408,10 @@ bool GerberaRuntime::addFile(const std::string& arg)
     return true;
 }
 
-bool GerberaRuntime::printCompileInfo(const std::string& arg)
-{
-    printCopyright(arg);
-    fmt::print(
-        "Compile info\n"
-        "-------------\n"
-        "{}\n\n",
-        COMPILE_INFO);
-    if (!gitBranch.empty()) {
-        fmt::print(
-            "Git info:\n"
-            "-------------\n"
-            "Git Branch: {}\n",
-            gitBranch);
-    }
-    if (!gitCommitHash.empty()) {
-        fmt::print("Git Commit: {}\n", gitCommitHash);
-    }
-
-    return true;
-}
-
-bool GerberaRuntime::createExampleConfig(const std::string& arg)
-{
-    exampleConfigSet = true;
-    return true;
-}
-
 bool GerberaRuntime::printCopyright(const std::string& arg)
 {
     fmt::print("\nGerbera UPnP Server {}\n"
-               "Copyright 2016-2024 Gerbera Contributors.\n"
+               "Copyright 2016-2025 Gerbera Contributors.\n"
                "Licence GPLv2: GNU GPL version 2.\n"
                "This is free software: you are free to change and redistribute it.\n\n",
         GERBERA_VERSION);
@@ -450,9 +419,21 @@ bool GerberaRuntime::printCopyright(const std::string& arg)
     return true;
 }
 
+bool GerberaRuntime::createExampleConfig(const std::string& arg)
+{
+    exampleConfigSet = true;
+    std::optional<std::string> sectionString = (*results)[arg].as<std::string>();
+
+    sections = ConfigGenerator::makeSections(sectionString.value_or("All"));
+    return true;
+}
+
 bool GerberaRuntime::createConfig(const std::string& arg)
 {
     createConfigSet = true;
+    std::optional<std::string> sectionString = (*results)[arg].as<std::string>();
+
+    sections = ConfigGenerator::makeSections(sectionString.value_or("All"));
     return true;
 }
 
@@ -499,7 +480,7 @@ bool GerberaRuntime::checkDirs()
 
 bool GerberaRuntime::printConfig()
 {
-    ConfigGenerator configGenerator(exampleConfigSet);
+    ConfigGenerator configGenerator(exampleConfigSet, sections);
     if (!configDirSet) {
         confDir = "";
     }
@@ -512,7 +493,7 @@ bool GerberaRuntime::printConfig()
 void GerberaRuntime::logCopyright()
 {
     log_info("Gerbera UPnP Server {} - {}", GERBERA_VERSION, DESC_MANUFACTURER_URL);
-    log_info("Copyright 2016-2024 Gerbera Contributors.");
+    log_info("Copyright 2016-2025 Gerbera Contributors.");
     log_info("Gerbera is free software, covered by the GNU General Public License version 2");
 }
 
@@ -618,7 +599,7 @@ void GerberaRuntime::handleServerOptions(const std::shared_ptr<Server>& server)
 
     this->server = server;
 
-    auto finalHandlers = executeOptions(argumentOptionCallbacks);
+    auto finalHandlers = executeOptions(argumentServerCallbacks);
     finalizeOptions(finalHandlers);
 }
 
