@@ -4,7 +4,7 @@
 
     autoscan_setting.h - this file is part of Gerbera.
 
-    Copyright (C) 2020-2024 Gerbera Contributors
+    Copyright (C) 2020-2025 Gerbera Contributors
 
     Gerbera is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License version 2
@@ -27,12 +27,13 @@
 #ifndef __AUTOSCANSETING_H__
 #define __AUTOSCANSETING_H__
 
+#include "util/grb_fs.h"
+
 #include <memory>
 #include <vector>
 
-#include "util/grb_fs.h"
-
 class AutoscanDirectory;
+class CdsObject;
 class Config;
 
 class AutoScanSetting {
@@ -43,9 +44,10 @@ public:
     bool rescanResource = true;
     bool async = true;
     std::shared_ptr<AutoscanDirectory> adir;
+    std::shared_ptr<CdsObject> changedObject;
     std::vector<std::string> resourcePatterns;
 
     void mergeOptions(const std::shared_ptr<Config>& config, const fs::path& location);
 };
 
-#endif
\ No newline at end of file
+#endif
