@@ -11,7 +11,7 @@
                             Sergey 'Jin' Bostandzhyan <jin@mediatomb.cc>,
                             Leonhard Wimmer <leo@mediatomb.cc>
 
-    Copyright (C) 2016-2024 Gerbera Contributors
+    Copyright (C) 2016-2025 Gerbera Contributors
 
     MediaTomb is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License version 2
@@ -54,6 +54,7 @@ enum class OnlineServiceType;
 
 class AutoscanList;
 class CdsItem;
+class ConverterManager;
 class CMAddFileTask;
 class GenericTask;
 class ImportService;
@@ -88,11 +89,9 @@ public:
 
     /// \brief Adds a file or directory to the database.
     /// \param dirEnt absolute path to the file
-    /// \param recursive recursive add (process subdirecotories)
-    /// \param async queue task or perform a blocking call
-    /// \param hidden true allows to import hidden files, false ignores them
-    /// \param rescanResource true allows to reload a directory containing a resource
-    /// \param queue for immediate processing or in normal order
+    /// \param asSetting Settings for import
+    /// \param lowPriority for immediate processing or in normal order
+    /// \param cancellable can be canceled
     /// \return object ID of the added file - only in blockign mode, when used in async mode this function will return INVALID_OBJECT_ID
     std::shared_ptr<CdsObject> addFile(const fs::directory_entry& dirEnt, AutoScanSetting& asSetting,
         bool lowPriority = false, bool cancellable = true) override;
@@ -100,15 +99,19 @@ public:
     /// \brief Adds a file or directory to the database.
     /// \param dirEnt absolute path to the file
     /// \param rootpath absolute path to the container root
-    /// \param recursive recursive add (process subdirecotories)
-    /// \param async queue task or perform a blocking call
-    /// \param hidden true allows to import hidden files, false ignores them
-    /// \param rescanResource true allows to reload a directory containing a resource
-    /// \param queue for immediate processing or in normal order
+    /// \param asSetting Settings for import
+    /// \param lowPriority for immediate processing or in normal order
+    /// \param cancellable can be canceled
     /// \return object ID of the added file - only in blockign mode, when used in async mode this function will return INVALID_OBJECT_ID
     std::shared_ptr<CdsObject> addFile(const fs::directory_entry& dirEnt, const fs::path& rootpath, AutoScanSetting& asSetting,
         bool lowPriority = false, bool cancellable = true) override;
 
+    /// \brief Ensures that a container given by it's location on disk is
+    /// present in the database. If it does not exist it will be created, but
+    /// it's content will not be added.
+    ///
+    /// \param path location of the container to handle
+    /// \return objectID of the container given by path
     int ensurePathExistence(const fs::path& path) const override;
     std::vector<int> removeObject(const std::shared_ptr<AutoscanDirectory>& adir, const std::shared_ptr<CdsObject>& obj, const fs::path& path, bool rescanResource, bool async = true, bool all = false) override;
 
@@ -122,7 +125,7 @@ public:
 
 #ifdef ONLINE_SERVICES
     /// \brief Creates a layout based from data that is obtained from an
-    /// online service (like AppleTrailers etc.)
+    /// online service
     void fetchOnlineContent(OnlineServiceType serviceType, bool lowPriority = true,
         bool cancellable = true,
         bool unscheduledRefresh = false);
@@ -133,7 +136,7 @@ public:
 
     /// \brief Adds a virtual item.
     /// \param obj item to add
-    /// \param allow_fifo flag to indicate that it is ok to add a fifo,
+    /// \param allowFifo flag to indicate that it is ok to add a fifo,
     /// otherwise only regular files or directories are allowed.
     ///
     /// This function makes sure that the file is first added to
@@ -150,6 +153,8 @@ public:
     void addObject(const std::shared_ptr<CdsObject>& obj, bool firstChild) override;
 
     /// \brief Adds a virtual container chain specified by path.
+    /// \param chain list of container objects to create
+    /// \param refItem object to take artwork from
     /// \return ID of the last container in the chain.
     std::pair<int, bool> addContainerTree(const std::vector<std::shared_ptr<CdsObject>>& chain, const std::shared_ptr<CdsObject>& refItem) override;
 
@@ -161,6 +166,7 @@ public:
 
     /// \brief Updates an object in the database.
     /// \param obj the object to update
+    /// \param sendUpdates send updates to subscribed clients
     void updateObject(const std::shared_ptr<CdsObject>& obj, bool sendUpdates = true) override;
 
     /// \brief Gets an AutocsanDirectrory from the watch list.
@@ -232,6 +238,7 @@ protected:
     std::shared_ptr<Database> database;
     std::shared_ptr<UpdateManager> update_manager;
     std::shared_ptr<Web::SessionManager> session_manager;
+    std::shared_ptr<ConverterManager> converterManager;
     std::shared_ptr<Context> context;
     std::shared_ptr<ImportService> importService;
 
