@@ -4,7 +4,7 @@
 
     import_service.cc - this file is part of Gerbera.
 
-    Copyright (C) 2023-2024 Gerbera Contributors
+    Copyright (C) 2023-2025 Gerbera Contributors
 
     Gerbera is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License version 2
@@ -32,6 +32,7 @@
 #include "config/config_val.h"
 #include "config/result/autoscan.h"
 #include "content_manager.h"
+#include "context.h"
 #include "database/database.h"
 #include "exceptions.h"
 #include "layout/builtin_layout.h"
@@ -114,16 +115,51 @@ void UpnpMap::initMap(std::vector<UpnpMap>& target, const std::map<std::string,
                 filters.emplace_back(match[1], match[2], match[3]);
             }
         }
-        log_debug("UpnpMap: {} -> {}", mt, cls);
+        log_vdebug("UpnpMap: {} -> {}", mt, cls);
         target.emplace_back(mt, cls, filters);
     }
 }
 
-ImportService::ImportService(std::shared_ptr<Context> context)
+ContentState::ContentState(fs::directory_entry dirEntry, ImportState state, std::chrono::seconds mtime, std::shared_ptr<CdsObject> cdsObject)
+    : state(state)
+    , dirEntry(std::move(dirEntry))
+    , mtime(mtime)
+    , cdsObject(std::move(cdsObject))
+{
+    itemCounter[ObjectType::Audio] = 0;
+    itemCounter[ObjectType::Video] = 0;
+    itemCounter[ObjectType::Image] = 0;
+    itemCounter[ObjectType::Playlist] = 0;
+    itemCounter[ObjectType::Folder] = 0;
+    itemCounter[ObjectType::Unknown] = 0;
+}
+
+AutoscanMediaMode ContentState::getMediaMode() const
+{
+    AutoscanMediaMode mediaMode = AutoscanMediaMode::Mixed;
+    std::size_t maxValue = 3; // at least 4 items are required to set upnp_class
+    if (itemCounter.at(ObjectType::Audio) > maxValue) {
+        mediaMode = AutoscanMediaMode::Audio;
+        maxValue = itemCounter.at(ObjectType::Audio);
+    }
+    if (itemCounter.at(ObjectType::Image) > maxValue) {
+        mediaMode = AutoscanMediaMode::Image;
+        maxValue = itemCounter.at(ObjectType::Image);
+    }
+    if (itemCounter.at(ObjectType::Video) > maxValue) {
+        mediaMode = AutoscanMediaMode::Video;
+        maxValue = itemCounter.at(ObjectType::Video);
+    }
+    return mediaMode;
+}
+
+ImportService::ImportService(std::shared_ptr<Context> context, std::shared_ptr<ConverterManager> converterManager)
     : context(std::move(context))
     , config(this->context->getConfig())
     , mime(this->context->getMime())
     , database(this->context->getDatabase())
+    , converterManager(std::move(converterManager))
+    , containerTypeMap(AutoscanDirectory::ContainerTypesDefaults)
 {
     hasReadableNames = config->getBoolOption(ConfigVal::IMPORT_READABLE_NAMES);
     hasCaseSensitiveNames = config->getBoolOption(ConfigVal::IMPORT_CASE_SENSITIVE_TAGS);
@@ -133,7 +169,7 @@ ImportService::ImportService(std::shared_ptr<Context> context)
     configLayoutMapping = config->getDictionaryOption(ConfigVal::IMPORT_LAYOUT_MAPPING);
     containerImageParentCount = config->getIntOption(ConfigVal::IMPORT_RESOURCES_CONTAINERART_PARENTCOUNT);
     containerImageMinDepth = config->getIntOption(ConfigVal::IMPORT_RESOURCES_CONTAINERART_MINDEPTH);
-    virtualDirKeys = config->getArrayOption(ConfigVal::IMPORT_VIRTUAL_DIRECTORY_KEYS);
+    virtualDirKeys = config->getVectorOption(ConfigVal::IMPORT_VIRTUAL_DIRECTORY_KEYS);
     noMediaName = config->getOption(ConfigVal::IMPORT_NOMEDIA_FILE);
     UpnpMap::initMap(upnpMap, mimetypeUpnpclassMap);
 }
@@ -144,7 +180,9 @@ void ImportService::run(std::shared_ptr<ContentManager> content, std::shared_ptr
     metadataService = std::make_shared<MetadataService>(context, this->content);
     if (autoScan) {
         this->autoscanDir = std::move(autoScan);
+        this->containerTypeMap = this->autoscanDir->getContainerTypes();
         this->rootPath = std::move(path);
+        this->pcDirTypes = this->autoscanDir->hasDirTypes();
     }
 }
 
@@ -153,7 +191,7 @@ void ImportService::initLayout(LayoutType layoutType)
     if (!layout) {
         log_debug("virtual layout Type {}", layoutType);
         try {
-            std::scoped_lock<decltype(layoutMutex)> lock(layoutMutex);
+            LayoutAutoLock lock(layoutMutex);
 
             if (layoutType == LayoutType::Js) {
 #ifdef HAVE_JS
@@ -205,20 +243,24 @@ std::string ImportService::mimeTypeToUpnpClass(const std::string& mimeType)
     if (parts.size() != 2)
         return {};
 
-    return getValueOrDefault(mimetypeUpnpclassMap, parts[0] + "/*");
+    return getValueOrDefault(mimetypeUpnpclassMap, parts.at(0) + "/*");
 }
 
 void ImportService::clearCache()
 {
+    log_debug("Clearing Cache '{}'", rootPath.c_str());
     containerMap.clear();
     containersWithFanArt.clear();
 }
 
 void ImportService::doImport(const fs::path& location, AutoScanSetting& settings, std::unordered_set<int>& currentContent, const std::shared_ptr<GenericTask>& task)
 {
-    log_debug("start {} root '{}'", location.string(), rootPath.string());
+    log_debug("start {} root '{}' update {}", location.string(), rootPath.string(), !!settings.changedObject);
     if (activeScan.empty()) {
+        auto cacheLock = CacheAutoLock(cacheMutex);
         contentStateCache.clear();
+        if (settings.changedObject)
+            clearCache();
         activeScan = location;
     } else {
         log_debug("Additional scan {}, already active {}", location.c_str(), activeScan.c_str());
@@ -228,7 +270,7 @@ void ImportService::doImport(const fs::path& location, AutoScanSetting& settings
         auto rootDirEntry = fs::directory_entry(rootPath);
         cacheState(rootPath, rootDirEntry, ImportState::New, toSeconds(rootDirEntry.last_write_time(ec)));
     }
-    auto rootEntry = fs::directory_entry(location);
+    auto rootEntry = fs::directory_entry(location, ec);
     if (ec) {
         log_error("Failed to start {}, {}", location.c_str(), ec.message());
         return;
@@ -239,7 +281,7 @@ void ImportService::doImport(const fs::path& location, AutoScanSetting& settings
         return;
     }
 
-    cacheState(location, rootEntry, ImportState::New, toSeconds(rootEntry.last_write_time(ec)));
+    cacheState(location, rootEntry, ImportState::New, toSeconds(rootEntry.last_write_time(ec)), settings.changedObject);
     if (isDir) {
         readDir(location, settings);
     } else {
@@ -248,7 +290,7 @@ void ImportService::doImport(const fs::path& location, AutoScanSetting& settings
     removeHidden(settings);
     createContainers(CDS_ID_FS_ROOT, settings);
     createItems(settings);
-    updateFanArt();
+    updateFanArt(isDir);
     fillLayout(task);
 
     // update currentContent
@@ -292,7 +334,7 @@ void ImportService::readDir(const fs::path& location, AutoScanSetting settings)
     settings.mergeOptions(config, location);
     for (auto&& dirEntry : dirIterator) {
         auto&& entryPath = dirEntry.path();
-        if (isHiddenFile(entryPath, true, dirEntry, settings)) {
+        if (entryPath.empty() || isHiddenFile(entryPath, true, dirEntry, settings)) {
             continue;
         }
         cacheState(entryPath, dirEntry, ImportState::New, toSeconds(dirEntry.last_write_time(ec)));
@@ -313,16 +355,22 @@ void ImportService::readDir(const fs::path& location, AutoScanSetting settings)
 
 void ImportService::cacheState(const fs::path& entryPath, const fs::directory_entry& dirEntry, ImportState state, std::chrono::seconds mtime, const std::shared_ptr<CdsObject>& cdsObject)
 {
+    auto cacheLock = CacheAutoLock(cacheMutex);
+    log_debug("cache '{}' , '{}' ({})", entryPath.string(), dirEntry.path().string(), state);
+
+    if (entryPath.empty())
+        return;
+
     if (contentStateCache.find(entryPath) == contentStateCache.end()) {
         contentStateCache[entryPath] = std::make_shared<ContentState>(dirEntry, state, mtime, cdsObject);
     } else {
-        state = contentStateCache[entryPath]->getState() < state ? state : contentStateCache[entryPath]->getState();
+        state = contentStateCache.at(entryPath)->getState() < state ? state : contentStateCache[entryPath]->getState();
         if (!cdsObject)
-            contentStateCache[entryPath]->setState(state);
+            contentStateCache.at(entryPath)->setState(state);
         else
-            contentStateCache[entryPath]->setObject(state, cdsObject);
+            contentStateCache.at(entryPath)->setObject(state, cdsObject);
         if (mtime > std::chrono::seconds::zero())
-            contentStateCache[entryPath]->setMTime(mtime);
+            contentStateCache.at(entryPath)->setMTime(mtime);
     }
 }
 
@@ -332,7 +380,7 @@ void ImportService::readFile(const fs::path& location)
     cacheState(location.parent_path(), dirEntry, ImportState::New, toSeconds(dirEntry.last_write_time(ec)));
 
     auto entryPath = dirEntry.path().parent_path();
-    while (entryPath != "/" && entryPath != rootPath) {
+    while (entryPath != "/" && !entryPath.empty() && entryPath != rootPath) {
         dirEntry.assign(entryPath, ec);
         if (ec) {
             cacheState(entryPath, dirEntry, ImportState::Broken);
@@ -356,12 +404,15 @@ void ImportService::removeHidden(const AutoScanSetting& settings)
         }
     }
 
-    for (auto&& hiddenPath : hiddenPaths) {
-        for (auto it = contentStateCache.begin(); it != contentStateCache.end();) {
-            if (startswith(it->first.string(), hiddenPath.string())) {
-                contentStateCache.erase(it++);
-            } else {
-                ++it;
+    {
+        auto cacheLock = CacheAutoLock(cacheMutex);
+        for (auto&& hiddenPath : hiddenPaths) {
+            for (auto it = contentStateCache.begin(); it != contentStateCache.end();) {
+                if (startswith(it->first.string(), hiddenPath.string())) {
+                    contentStateCache.erase(it++);
+                } else {
+                    ++it;
+                }
             }
         }
     }
@@ -370,24 +421,24 @@ void ImportService::removeHidden(const AutoScanSetting& settings)
 bool ImportService::isHiddenFile(const fs::path& entryPath, bool isDirectory, const fs::directory_entry& dirEntry, const AutoScanSetting& settings)
 {
     auto&& name = entryPath.filename().string();
-    if ((name[0] == '.' && !settings.hidden)
+    if (name.empty())
+        return true;
+    if ((name.at(0) == '.' && !settings.hidden)
         || (!settings.followSymlinks && dirEntry.is_symlink())
         || config->getConfigFilename() == entryPath) {
         cacheState(entryPath, dirEntry, ImportState::ToDelete);
+        log_vdebug("hidden {}", entryPath.string());
         return true;
     }
     if (!noMediaName.empty()) {
         auto noMediaFile = (isDirectory) ? entryPath / noMediaName : entryPath.parent_path() / noMediaName;
-        if (contentStateCache.find(noMediaFile) != contentStateCache.end()) {
-            return contentStateCache[noMediaFile]->getState() != ImportState::Broken; // broken means: file not found
-        }
-        auto noMediaEntry = fs::directory_entry(noMediaFile, ec);
-        if (!noMediaEntry.exists(ec) || ec) {
-            cacheState(noMediaEntry, noMediaEntry, ImportState::Broken, toSeconds(dirEntry.last_write_time(ec)));
-        } else {
-            // if file exists it will be automatically created
-            return true;
+        {
+            auto cacheLock = CacheAutoLock(cacheMutex);
+            if (contentStateCache.find(noMediaFile) != contentStateCache.end()) {
+                return !contentStateCache.at(noMediaFile) || contentStateCache.at(noMediaFile)->getState() != ImportState::Broken; // broken means: file not found
+            }
         }
+        // if file exists it will be automatically created
     }
     return false;
 }
@@ -400,8 +451,27 @@ void ImportService::createContainers(int parentContainerId, AutoScanSetting& set
         if (!stateEntry || stateEntry->getState() != ImportState::New)
             continue;
         auto dirEntry = stateEntry->getDirEntry();
+        bool doUpdate = false;
         if (dirEntry.exists(ec) && dirEntry.is_directory(ec)) {
-            auto cdsObj = database->findObjectByPath(contPath, DbFileType::Directory);
+            auto cdsObj = stateEntry->getObject();
+            if (cdsObj) {
+                auto oldLocation = cdsObj->getLocation();
+                cdsObj->setLocation(contPath);
+                log_debug("Container renamed {} {}", cdsObj->getTitle(), contPath.filename().string());
+                cdsObj->setTitle(contPath.filename().string());
+                doUpdate = true;
+                log_debug("Container moved {} {}", oldLocation.string(), contPath.string());
+                for (auto&& [childPath, childEntry] : contentStateCache) {
+                    // find direct folder entry with old name and rely on iteration to rename hierarchy
+                    if (childEntry && childPath.parent_path() == contPath) {
+                        auto childObj = database->findObjectByPath(oldLocation / childPath.filename(), UNUSED_CLIENT_GROUP, DbFileType::Any);
+                        if (childObj)
+                            childEntry->setObject(ImportState::New, childObj);
+                    }
+                }
+            }
+            if (!cdsObj)
+                cdsObj = database->findObjectByPath(contPath, UNUSED_CLIENT_GROUP, DbFileType::Directory);
 
             if (cdsObj) {
                 try {
@@ -409,20 +479,26 @@ void ImportService::createContainers(int parentContainerId, AutoScanSetting& set
                     if (!container || !cdsObj->isContainer()) {
                         throw_std_runtime_error("Object {} is not a container", cdsObj->getLocation().string());
                     }
-                    stateEntry->setObject(ImportState::Existing, container);
                     auto lastModified = toSeconds(dirEntry.last_write_time(ec));
                     if (lastModified > container->getMTime()) {
                         container->setMTime(lastModified);
+                        doUpdate = true;
+                    }
+                    if (doUpdate) {
+                        database->updateObject(cdsObj, nullptr);
+                        stateEntry->setObject(ImportState::Created, cdsObj);
+                        log_debug("Container updated {} {}", contPath.string(), container->getID());
+                    } else {
+                        stateEntry->setObject(ImportState::Existing, cdsObj);
+                        log_debug("Container found {} {}", contPath.string(), container->getID());
                     }
-                    log_debug("Container found {} {}", contPath.string(), container->getID());
-
                 } catch (const std::runtime_error& e) {
                     stateEntry->setObject(ImportState::Broken, cdsObj);
                     log_error("createContainers: Failed to load parent container {}, {}", contPath.c_str(), e.what());
                 }
             } else {
                 // Create container
-                stateEntry->setObject(ImportState::Created, createSingleContainer(parentContainerId, dirEntry, UPNP_CLASS_CONTAINER));
+                stateEntry->setObject(ImportState::Created, createSingleContainer(parentContainerId, dirEntry, UPNP_CLASS_CONTAINER_FOLDER));
             }
         }
     }
@@ -447,8 +523,8 @@ void ImportService::createItems(AutoScanSetting& settings)
         // cache containers as parent item for following item
         if (cdsObj && cdsObj->isContainer()) {
             std::shared_ptr<CdsContainer> container = std::dynamic_pointer_cast<CdsContainer>(cdsObj);
-            if (contPath != "") {
-                contentStateCache[contPath]->setMTime(lastModifiedNewMax);
+            if (!contPath.empty()) {
+                contentStateCache.at(contPath)->setMTime(lastModifiedNewMax);
                 if (autoscanDir) {
                     autoscanDir->setCurrentLMT(contPath, lastModifiedNewMax);
                 }
@@ -469,7 +545,7 @@ void ImportService::createItems(AutoScanSetting& settings)
         auto dirEntry = stateEntry->getDirEntry();
         if (isRegularFile(dirEntry, ec)) {
             // Start with cached item
-            auto contState = contentStateCache[itemPath.parent_path()];
+            auto contState = contentStateCache.at(itemPath.parent_path());
             if (contState)
                 parentContainer = std::dynamic_pointer_cast<CdsContainer>(contState->getObject());
             else
@@ -478,30 +554,36 @@ void ImportService::createItems(AutoScanSetting& settings)
             if (!cdsObj) {
                 // Search item in database
                 log_debug("Searching Item {} in database", itemPath.string());
-                cdsObj = database->findObjectByPath(itemPath, DbFileType::File);
+                cdsObj = database->findObjectByPath(itemPath, UNUSED_CLIENT_GROUP, DbFileType::File);
             }
-            if (cdsObj && cdsObj->isItem() && stateEntry->getMTime() != cdsObj->getMTime()) {
-                // Update changed item in database
-                log_debug("Updating Item {} in database {}", itemPath.string(), cdsObj->getID());
-                auto item = std::dynamic_pointer_cast<CdsItem>(cdsObj);
-                item->clearMetaData();
-                item->clearAuxData();
-                item->clearResources();
-                updateSingleItem(dirEntry, item, item->getMimeType());
-                if (lastModifiedNewMax < cdsObj->getMTime())
-                    lastModifiedNewMax = cdsObj->getMTime();
-                database->updateObject(cdsObj, nullptr);
-                stateEntry->setObject(ImportState::Created, cdsObj);
-                log_debug("Item changed {} {}", itemPath.string(), cdsObj->getID());
-            } else if (cdsObj) {
-                // Store local item
-                if (contState && contState->getMTime() < cdsObj->getMTime()) {
-                    contState->setMTime(cdsObj->getMTime());
+            if (cdsObj && cdsObj->isItem()) {
+                auto isChanged = stateEntry->getMTime() != cdsObj->getMTime() || cdsObj->getLocation().string() != dirEntry.path().string();
+                if (isChanged) {
+                    // Update changed item in database
+                    log_debug("Updating Item {} in database {}", itemPath.string(), cdsObj->getID());
+                    auto item = std::dynamic_pointer_cast<CdsItem>(cdsObj);
+                    item->clearMetaData();
+                    item->clearAuxData();
+                    item->clearResources();
+                    log_debug("Changing location {} to {}", item->getLocation().string(), itemPath.string());
+                    item->setLocation(itemPath);
+                    item->setTitle(makeTitle(itemPath, item->getClass()));
+                    updateSingleItem(dirEntry, item, item->getMimeType());
                     if (lastModifiedNewMax < cdsObj->getMTime())
                         lastModifiedNewMax = cdsObj->getMTime();
+                    database->updateObject(cdsObj, nullptr);
+                    stateEntry->setObject(ImportState::Created, cdsObj);
+                    log_debug("Item changed {} {}", itemPath.string(), cdsObj->getID());
+                } else {
+                    // Store local item with updated status
+                    if (contState && contState->getMTime() < cdsObj->getMTime()) {
+                        contState->setMTime(cdsObj->getMTime());
+                        if (lastModifiedNewMax < cdsObj->getMTime())
+                            lastModifiedNewMax = cdsObj->getMTime();
+                    }
+                    stateEntry->setObject(ImportState::Existing, cdsObj);
+                    log_debug("Item found {} {}", itemPath.string(), cdsObj->getID());
                 }
-                stateEntry->setObject(ImportState::Existing, cdsObj);
-                log_debug("Item found {} {}", itemPath.string(), cdsObj->getID());
             } else {
                 // Create item from scratch
                 log_debug("Creating Item {}", itemPath.string());
@@ -524,6 +606,7 @@ void ImportService::createItems(AutoScanSetting& settings)
                 }
             }
             if (contState && cdsObj) {
+                contState->increaseItemCounter(cdsObj->getMediaType());
                 contState->setFirstObject(cdsObj);
             }
             if (parentContainer) {
@@ -575,17 +658,22 @@ std::pair<bool, std::shared_ptr<CdsObject>> ImportService::createSingleItem(cons
         item->setClass(upnpClass);
     }
 
-    auto f2i = StringConverter::f2i(config);
-    auto title = objectPath.filename().string();
+    item->setTitle(makeTitle(objectPath, upnpClass));
+    updateSingleItem(dirEntry, item, mimetype);
+
+    return { skip, item };
+}
+
+std::string ImportService::makeTitle(const fs::path& objectPath, const std::string upnpClass)
+{
+    auto f2i = converterManager->f2i();
+    std::string title = objectPath.filename().string();
     if (hasReadableNames && upnpClass != UPNP_CLASS_ITEM) {
         title = objectPath.stem().string();
         if (title.length() > 1)
             std::replace(title.begin() + 1, title.end() - 1, '_', ' ');
     }
-    item->setTitle(f2i->convert(title));
-    updateSingleItem(dirEntry, item, mimetype);
-
-    return { skip, item };
+    return f2i->convert(title);
 }
 
 void ImportService::updateSingleItem(const fs::directory_entry& dirEntry, const std::shared_ptr<CdsItem>& item, const std::string& mimetype)
@@ -595,8 +683,12 @@ void ImportService::updateSingleItem(const fs::directory_entry& dirEntry, const
     item->setUTime(mTime);
     item->setSizeOnDisk(getFileSize(dirEntry));
 
-    metadataService->extractMetaData(item, dirEntry);
-    updateItemData(item, mimetype);
+    try {
+        metadataService->extractMetaData(item, dirEntry);
+        updateItemData(item, mimetype);
+    } catch (const std::runtime_error& ex) {
+        log_error("updateSingleItem '{}' failed: {}", dirEntry.path().string(), ex.what());
+    }
 }
 
 void ImportService::fillLayout(const std::shared_ptr<GenericTask>& task)
@@ -604,13 +696,16 @@ void ImportService::fillLayout(const std::shared_ptr<GenericTask>& task)
     for (auto&& [contPath, stateEntry] : contentStateCache) {
         if (!stateEntry || stateEntry->getState() != ImportState::Created)
             continue;
-        contentStateCache[contPath]->setObject(ImportState::Loaded, stateEntry->getObject());
+        contentStateCache.at(contPath)->setObject(ImportState::Loaded, stateEntry->getObject());
         fillSingleLayout(stateEntry, nullptr, stateEntry->getParentObject(), task);
     }
 }
 
 /// \param object used to make code compatible with legacy scan
-void ImportService::fillSingleLayout(const std::shared_ptr<ContentState>& state, std::shared_ptr<CdsObject> object, const std::shared_ptr<CdsContainer>& parent, const std::shared_ptr<GenericTask>& task)
+void ImportService::fillSingleLayout(const std::shared_ptr<ContentState>& state,
+    std::shared_ptr<CdsObject> object,
+    const std::shared_ptr<CdsContainer>& parent,
+    const std::shared_ptr<GenericTask>& task)
 {
     std::shared_ptr<CdsObject> cdsObject = state ? state->getObject() : std::move(object);
     log_debug("cds {}, layout {}, autoscanDir {}", !!cdsObject, !!layout, !!autoscanDir);
@@ -619,33 +714,34 @@ void ImportService::fillSingleLayout(const std::shared_ptr<ContentState>& state,
         try {
             std::string mimetype = std::static_pointer_cast<CdsItem>(cdsObject)->getMimeType();
             std::string contentType = getValueOrDefault(mimetypeContenttypeMap, mimetype);
+            log_vdebug("mimetype {}, contentype {}, autoscanDir {}", mimetype, contentType, (!autoscanDir || autoscanDir->hasContent(cdsObject->getClass())));
 
-            if (!autoscanDir || autoscanDir->hasContent(cdsObject->getClass())) {
+            if (contentType == CONTENT_TYPE_PLAYLIST) {
+#ifdef HAVE_JS
+                try {
+                    if (playlistParserScript)
+                        playlistParserScript->processPlaylistObject(cdsObject, task, rootPath);
+                } catch (const std::runtime_error& e) {
+                    log_error("{}", e.what());
+                }
+#else
+                log_warning("Playlist {} will not be parsed: Gerbera was compiled without JS support!", cdsObject->getLocation().c_str());
+#endif // HAVE_JS
+            } else if (!autoscanDir || autoscanDir->hasContent(cdsObject->getClass())) {
                 // only lock mutex while processing item layout
-                std::scoped_lock<decltype(layoutMutex)> lock(layoutMutex);
+                LayoutAutoLock lock(layoutMutex);
                 // get ref'd objects with last mod time
                 auto refObjects = state ? database->getRefObjects(cdsObject->getID()) : std::vector<int> {};
                 layout->processCdsObject(cdsObject, parent,
                     rootPath, contentType,
-                    autoscanDir ? autoscanDir->getContainerTypes() : AutoscanDirectory::ContainerTypesDefaults,
+                    containerTypeMap,
                     refObjects);
             } else {
-                log_debug("file ignored: {} autoscanDir={}, class={}, hasContent={}, mediaType={}", cdsObject->getLocation().string(), !!autoscanDir, cdsObject->getClass(), autoscanDir ? autoscanDir->hasContent(cdsObject->getClass()) : false, autoscanDir ? autoscanDir->getMediaType() : -2);
+                log_debug("File ignored: {} autoscanDir={}, class={}, hasContent={}, mediaType={}", cdsObject->getLocation().string(), !!autoscanDir, cdsObject->getClass(), autoscanDir ? autoscanDir->hasContent(cdsObject->getClass()) : false, autoscanDir ? autoscanDir->getMediaType() : -2);
             }
 
-#ifdef HAVE_JS
-            try {
-                if (playlistParserScript && contentType == CONTENT_TYPE_PLAYLIST)
-                    playlistParserScript->processPlaylistObject(cdsObject, task, rootPath);
-            } catch (const std::runtime_error& e) {
-                log_error("{}", e.what());
-            }
-#else
-            if (contentType == CONTENT_TYPE_PLAYLIST)
-                log_warning("Playlist {} will not be parsed: Gerbera was compiled without JS support!", cdsObject->getLocation().c_str());
-#endif // HAVE_JS
-        } catch (const std::runtime_error& e) {
-            log_error("{}", e.what());
+        } catch (const std::runtime_error& ex) {
+            log_error("{}", ex.what());
         }
     }
 }
@@ -688,23 +784,43 @@ void ImportService::finishScan(const fs::path& location, const std::shared_ptr<C
                 count = std::distance(objectLocation.begin(), objectLocation.end()) - std::distance(location.begin(), location.end());
             }
             database->updateObject(parent, nullptr);
-            assignFanArt(parent, firstObject, count);
+            assignFanArt(parent,
+                firstObject,
+                AutoscanMediaMode::Mixed,
+                false /* isDir */,
+                count,
+                false /* isNew */);
         }
     }
 }
 
-void ImportService::assignFanArt(const std::shared_ptr<CdsContainer>& container, const std::shared_ptr<CdsObject>& refObj, int count)
+void ImportService::assignFanArt(
+    const std::shared_ptr<CdsContainer>& container,
+    const std::shared_ptr<CdsObject>& refObj,
+    AutoscanMediaMode mediaMode,
+    bool isDir,
+    int count,
+    bool isNew)
 {
     if (!container)
         return;
 
-    if (refObj && refObj->getMTime() > container->getMTime()) {
-        container->setMTime(refObj->getMTime());
-        database->updateObject(container, nullptr);
+    bool doUpdate = false;
+    if (refObj) {
+        if (isDir && pcDirTypes && refObj->isItem() && container->getClass() != containerTypeMap.at(mediaMode)) {
+            container->setClass(containerTypeMap.at(mediaMode));
+            doUpdate = true;
+        }
+        if (refObj->getMTime() > container->getMTime()) {
+            container->setMTime(refObj->getMTime());
+            doUpdate = true;
+        }
     }
 
     if (containersWithFanArt.find(container->getID()) != containersWithFanArt.end()) {
-        log_debug("Already assigned fanart {}", container->getID());
+        log_debug("Already {} assigned fanart {}", container->getLocation().string(), container->getID());
+        if (doUpdate)
+            database->updateObject(container, nullptr);
         return;
     }
 
@@ -714,23 +830,29 @@ void ImportService::assignFanArt(const std::shared_ptr<CdsContainer>& container,
         auto fanartObjId = stoiString(fanart->getAttribute(ResourceAttribute::FANART_OBJ_ID));
         try {
             if (fanartObjId > CDS_ID_ROOT) {
+                log_debug("Object {} assigned fanart {}", container->getLocation().string(), container->getID());
                 database->loadObject(fanartObjId);
             }
         } catch (const ObjectNotFoundException&) {
+            log_warning("Object fanart {} broken {}", container->getLocation().string(), fanartObjId);
             container->removeResource(fanart->getHandlerType());
+            doUpdate = true;
             fanart = nullptr;
         }
     }
-    if (!fanart || fanart->getHandlerType() != ContentHandler::CONTAINERART) {
+    if (!fanart || isNew || fanart->getHandlerType() != ContentHandler::CONTAINERART) {
         if (fanart) {
             container->clearResources();
+            doUpdate = true;
         }
         metadataService->getHandler(ContentHandler::CONTAINERART)->fillMetadata(container);
         auto containerart = container->getResource(ResourcePurpose::Thumbnail);
         if (containerart) {
             fanart = containerart;
+        } else if (fanart) {
+            container->addResource(fanart); // restore if no image matches
         }
-        log_debug("fanart from dir {}", containerart != nullptr);
+        log_debug("fanart {} from dir {}", container->getLocation().string(), containerart != nullptr);
     }
 
     if (refObj && !fanart) {
@@ -762,24 +884,33 @@ void ImportService::assignFanArt(const std::shared_ptr<CdsContainer>& container,
                 } else {
                     fanart = refFanArt;
                 }
-                log_debug("fanart from ref {}", fanart != nullptr);
+                log_debug("fanart {} from ref {}", location.string(), fanart != nullptr);
             }
         }
     }
     if (fanart) {
         container->clearResources();
         container->addResource(fanart); // overwrite all other resources
-        database->updateObject(container, nullptr);
+        doUpdate = true;
         containersWithFanArt[container->getID()] = container;
     }
+    if (doUpdate)
+        database->updateObject(container, nullptr);
 }
 
-std::shared_ptr<CdsContainer> ImportService::getContainer(const fs::path& location) const
+std::shared_ptr<CdsContainer> ImportService::getContainer(const std::string& location) const
 {
+    if (!hasCaseSensitiveNames) {
+        auto llocation = toLower(location);
+        return containerMap.at(llocation);
+    }
     return containerMap.at(location);
 }
 
-std::shared_ptr<CdsContainer> ImportService::createSingleContainer(int parentContainerId, const fs::directory_entry& dirEntry, const std::string& upnpClass)
+std::shared_ptr<CdsContainer> ImportService::createSingleContainer(
+    int parentContainerId,
+    const fs::directory_entry& dirEntry,
+    const std::string& upnpClass)
 {
     std::vector<std::shared_ptr<CdsObject>> cVec;
     auto location = dirEntry.path();
@@ -805,6 +936,7 @@ std::pair<int, bool> ImportService::addContainerTree(
     const std::shared_ptr<CdsObject>& refItem,
     std::vector<int>& createdIds)
 {
+    log_debug("start '{}' {}", rootPath.string(), parentContainerId);
     std::string tree; // accumulate path to container here
     int result = parentContainerId;
     bool isNew = false;
@@ -823,18 +955,32 @@ std::pair<int, bool> ImportService::addContainerTree(
                 tree = std::regex_replace(tree, std::regex(key), val);
             }
             auto dirKeyValues = std::vector<std::string>();
-            for (auto&& field : virtualDirKeys) {
+            for (auto&& vdirSetting : virtualDirKeys) {
+                std::string field;
+                std::string upnpClass;
+                for (auto&& [key, vdirField] : vdirSetting) {
+                    if (key == "metadata")
+                        field = vdirField;
+                    if (key == "class")
+                        upnpClass = vdirField;
+                }
+                if (!item->isSubClass(upnpClass))
+                    continue;
                 if (field == "LOCATION") {
                     std::string location = item->getLocation().c_str();
                     if (!location.empty()) {
                         dirKeyValues.push_back(location);
                         item->setLocation("");
                     }
-                } else {
-                    auto metaField = MetaEnumMapper::remapMetaDataField(field);
-                    auto keyValue = item->getMetaData(metaField);
+                } else if (endswith(field, "_1")) {
+                    auto keyValue = item->getMetaData(field.replace(field.end() - 2, field.end(), ""));
                     if (!keyValue.empty())
                         dirKeyValues.push_back(keyValue);
+                } else if (!field.empty()) {
+                    auto keyValueGroup = item->getMetaGroup(field);
+                    if (!keyValueGroup.empty())
+                        for (auto&& keyValue : keyValueGroup)
+                            dirKeyValues.push_back(keyValue);
                 }
             }
             if (!dirKeyValues.empty()) {
@@ -845,8 +991,8 @@ std::pair<int, bool> ImportService::addContainerTree(
             if (!hasCaseSensitiveNames) {
                 subTree = toLower(subTree);
             }
-            if (containerMap.find(subTree) == containerMap.end() || !containerMap[subTree]) {
-                auto cont = database->findObjectByPath(subTree, DbFileType::Virtual);
+            if (containerMap.find(subTree) == containerMap.end() || !containerMap.at(subTree)) {
+                auto cont = database->findObjectByPath(subTree, UNUSED_CLIENT_GROUP, DbFileType::Virtual);
                 if (cont && cont->isContainer())
                     containerMap[subTree] = std::dynamic_pointer_cast<CdsContainer>(cont);
                 else
@@ -856,7 +1002,7 @@ std::pair<int, bool> ImportService::addContainerTree(
         } else if (subTree.empty()) {
             subTree = tree;
         }
-        if (containerMap.find(subTree) == containerMap.end() || !containerMap[subTree]) {
+        if (containerMap.find(subTree) == containerMap.end() || !containerMap.at(subTree)) {
             item->removeMetaData(MetadataFields::M_TITLE);
             item->addMetaData(MetadataFields::M_TITLE, item->getTitle());
             item->setParentID(result);
@@ -872,25 +1018,40 @@ std::pair<int, bool> ImportService::addContainerTree(
                 createdIds.push_back(result); // ensure update
             }
             isNew = true;
+            if (item->isContainer()) {
+                std::shared_ptr<CdsContainer> itemContainer = std::dynamic_pointer_cast<CdsContainer>(item);
+                container->setUpnpShortcut(itemContainer->getUpnpShortcut());
+            }
         } else {
-            result = containerMap[subTree]->getID();
-            if (item->getMTime() > containerMap[subTree]->getMTime()) {
+            result = containerMap.at(subTree)->getID();
+            if (item->getMTime() > containerMap.at(subTree)->getMTime()) {
                 createdIds.push_back(result);
             }
         }
         count++;
         if (isVirtual) // && chain.size() - count < containerImageParentCount
-            assignFanArt(containerMap[subTree], refItem && count > containerImageMinDepth ? refItem : item, chain.size() - count);
+            assignFanArt(containerMap.at(subTree),
+                refItem && count > containerImageMinDepth ? refItem : item,
+                AutoscanMediaMode::Mixed,
+                false /* isDir */,
+                chain.size() - count,
+                isNew);
     }
+    log_debug("end '{}' {} {}", tree, result, isNew);
     return { result, isNew };
 }
 
-void ImportService::updateFanArt()
+void ImportService::updateFanArt(bool isDir)
 {
     for (auto&& [contPath, stateEntry] : contentStateCache) {
         if (!stateEntry || !stateEntry->getObject() || !stateEntry->getObject()->isContainer())
             continue;
         std::shared_ptr<CdsContainer> container = std::dynamic_pointer_cast<CdsContainer>(stateEntry->getObject());
-        assignFanArt(container, stateEntry->getFirstObject(), 1);
+        assignFanArt(container,
+            stateEntry->getFirstObject(),
+            stateEntry->getMediaMode(),
+            isDir,
+            1,
+            false /* isNew */);
     }
 }
