@@ -4,7 +4,7 @@
 
     import_service.h - this file is part of Gerbera.
 
-    Copyright (C) 2023-2024 Gerbera Contributors
+    Copyright (C) 2023-2025 Gerbera Contributors
 
     Gerbera is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License version 2
@@ -32,14 +32,17 @@
 #include <mutex>
 #include <unordered_set>
 
-class AutoScanSetting;
+// forward declarations
 class AutoscanDirectory;
+enum class AutoscanMediaMode;
+class AutoScanSetting;
 class CdsContainer;
 class CdsItem;
 class CdsObject;
 class Config;
 class ContentManager;
 class Context;
+class ConverterManager;
 class Database;
 class GenericTask;
 class ImportService;
@@ -47,10 +50,10 @@ class Layout;
 enum class LayoutType;
 class MetadataService;
 class Mime;
+enum class ObjectType;
 class ScriptingRuntime;
 class UpnpMap;
 
-// forward declarations
 #ifdef HAVE_JS
 class PlaylistParserScript;
 class MetafileParserScript;
@@ -64,7 +67,7 @@ enum class ImportState {
     WithLayout,
     ToDelete,
     LayoutDeleted,
-    Broken,
+    Broken = 99,
 };
 
 class ContentState {
@@ -79,18 +82,17 @@ private:
     std::shared_ptr<CdsObject> cdsObject;
     /// \brief CdsObject associated with the container (if cdsObject is a container)
     std::shared_ptr<CdsObject> firstObject;
+    /// \brief counters of child object types for container type
+    std::map<ObjectType, std::size_t> itemCounter;
 
     /// \brief parent container (if cdsObject is a item)
     std::shared_ptr<CdsContainer> parentObject;
 
 public:
-    ContentState(fs::directory_entry dirEntry, ImportState state, std::chrono::seconds mtime = std::chrono::seconds::zero(), std::shared_ptr<CdsObject> cdsObject = nullptr)
-        : state(state)
-        , dirEntry(std::move(dirEntry))
-        , mtime(mtime)
-        , cdsObject(std::move(cdsObject))
-    {
-    }
+    ContentState(fs::directory_entry dirEntry,
+        ImportState state,
+        std::chrono::seconds mtime = std::chrono::seconds::zero(),
+        std::shared_ptr<CdsObject> cdsObject = nullptr);
 
     void setObject(ImportState state, std::shared_ptr<CdsObject> cdsObject)
     {
@@ -117,6 +119,8 @@ public:
 
     ImportState getState() const { return state; }
     void setState(ImportState newState) { state = newState; }
+    void increaseItemCounter(ObjectType mt) { itemCounter[mt]++; }
+    AutoscanMediaMode getMediaMode() const;
 };
 
 class UpnpMap {
@@ -149,6 +153,7 @@ private:
     std::shared_ptr<Database> database;
     std::shared_ptr<ContentManager> content;
     std::shared_ptr<MetadataService> metadataService;
+    std::shared_ptr<ConverterManager> converterManager;
 
     std::map<std::string, std::string> mimetypeContenttypeMap;
     std::map<std::string, std::string> mimetypeUpnpclassMap;
@@ -156,48 +161,73 @@ private:
     std::vector<UpnpMap> upnpMap {};
 
     std::shared_ptr<AutoscanDirectory> autoscanDir;
+    std::map<AutoscanMediaMode, std::string> containerTypeMap;
     fs::path rootPath;
     std::string noMediaName;
     bool hasReadableNames { false };
     bool hasCaseSensitiveNames { true };
     bool hasDefaultDate { true };
+    bool pcDirTypes { true };
     int containerImageParentCount { 2 };
     int containerImageMinDepth { 2 };
-    std::vector<std::string> virtualDirKeys {};
+    std::vector<std::vector<std::pair<std::string, std::string>>> virtualDirKeys {};
 
-    ///\brief cache for containers while creating new layout
-    std::map<std::string, std::shared_ptr<CdsContainer>> containerMap;
-    std::map<int, std::shared_ptr<CdsContainer>> containersWithFanArt;
+    /// \brief cache for containers while creating new layout
+    mutable std::map<std::string, std::shared_ptr<CdsContainer>> containerMap;
+    mutable std::map<int, std::shared_ptr<CdsContainer>> containersWithFanArt;
 
-    std::mutex layoutMutex;
-    std::shared_ptr<Layout> layout;
+    mutable std::mutex layoutMutex;
+    using LayoutAutoLock = std::scoped_lock<decltype(layoutMutex)>;
+    mutable std::shared_ptr<Layout> layout;
+
+    mutable std::mutex cacheMutex;
+    using CacheAutoLock = std::scoped_lock<decltype(cacheMutex)>;
 #ifdef HAVE_JS
     std::unique_ptr<PlaylistParserScript> playlistParserScript;
     std::unique_ptr<MetafileParserScript> metafileParserScript;
 #endif
 
-    std::map<fs::path, std::shared_ptr<ContentState>> contentStateCache = std::map<fs::path, std::shared_ptr<ContentState>>();
+    mutable std::map<fs::path, std::shared_ptr<ContentState>> contentStateCache = std::map<fs::path, std::shared_ptr<ContentState>>();
     std::error_code ec;
     fs::path activeScan {};
 
     std::string mimeTypeToUpnpClass(const std::string& mimeType);
+    std::string makeTitle(const fs::path& objectPath, const std::string upnpClass);
 
     void readDir(const fs::path& location, AutoScanSetting settings);
     void readFile(const fs::path& location);
-    ///\brief create containers for all discovered folders
+    /// \brief create containers for all discovered folders
     void createContainers(int parentContainerId, AutoScanSetting& settings);
-    ///\brief create items for all discovered files
+    /// \brief create items for all discovered files
     void createItems(AutoScanSetting& settings);
     void updateSingleItem(const fs::directory_entry& dirEntry, const std::shared_ptr<CdsItem>& item, const std::string& mimetype);
     void fillLayout(const std::shared_ptr<GenericTask>& task);
-    void updateFanArt();
-    void assignFanArt(const std::shared_ptr<CdsContainer>& container, const std::shared_ptr<CdsObject>& refObj, int count);
+    void updateFanArt(bool isDir);
+    /// @brief try to assign fanart to container
+    /// @param container target object
+    /// @param refObj object to point to for fanart
+    /// @param mediaMode media mode for physical folders
+    /// @param isDir target is physical folder
+    /// @param count current depth of folder path
+    /// @param isNew new virtual target
+    void assignFanArt(
+        const std::shared_ptr<CdsContainer>& container,
+        const std::shared_ptr<CdsObject>& refObj,
+        AutoscanMediaMode mediaMode,
+        bool isDir,
+        int count,
+        bool isNew);
     void removeHidden(const AutoScanSetting& settings);
 
-    void cacheState(const fs::path& entryPath, const fs::directory_entry& dirEntry, ImportState state, std::chrono::seconds mtime = std::chrono::seconds::zero(), const std::shared_ptr<CdsObject>& cdsObject = nullptr);
+    void cacheState(
+        const fs::path& entryPath,
+        const fs::directory_entry& dirEntry,
+        ImportState state,
+        std::chrono::seconds mtime = std::chrono::seconds::zero(),
+        const std::shared_ptr<CdsObject>& cdsObject = nullptr);
 
 public:
-    ImportService(std::shared_ptr<Context> context);
+    ImportService(std::shared_ptr<Context> context, std::shared_ptr<ConverterManager> converterManager);
 
     void run(std::shared_ptr<ContentManager> content, std::shared_ptr<AutoscanDirectory> autoScan = {}, fs::path path = "");
     void initLayout(LayoutType layoutType);
@@ -208,15 +238,41 @@ public:
 
     std::pair<bool, std::shared_ptr<CdsObject>> createSingleItem(const fs::directory_entry& dirEntry);
     std::shared_ptr<CdsContainer> createSingleContainer(int parentContainerId, const fs::directory_entry& dirEntry, const std::string& upnpClass);
-    void fillSingleLayout(const std::shared_ptr<ContentState>& state, std::shared_ptr<CdsObject> object, const std::shared_ptr<CdsContainer>& parent, const std::shared_ptr<GenericTask>& task);
+
+    /// \brief create layout of a single itme
+    /// \param state item state
+    /// \param object object to create layout
+    /// \param parent parent container
+    /// \param task import task associated
+    void fillSingleLayout(
+        const std::shared_ptr<ContentState>& state,
+        std::shared_ptr<CdsObject> object,
+        const std::shared_ptr<CdsContainer>& parent,
+        const std::shared_ptr<GenericTask>& task);
 
     bool isHiddenFile(const fs::path& entryPath, bool isDirectory, const fs::directory_entry& dirEntry, const AutoScanSetting& settings);
 
     void updateItemData(const std::shared_ptr<CdsItem>& item, const std::string& mimetype);
-    std::pair<int, bool> addContainerTree(int parentContainerId, const std::vector<std::shared_ptr<CdsObject>>& chain, const std::shared_ptr<CdsObject>& refItem, std::vector<int>& createdIds);
-    void finishScan(const fs::path& location, const std::shared_ptr<CdsContainer>& parent, std::chrono::seconds lmt, const std::shared_ptr<CdsObject>& firstObject = nullptr);
 
-    std::shared_ptr<CdsContainer> getContainer(const fs::path& location) const;
+    /// \brief Adds a virtual container chain specified by path.
+    /// \param parentContainerId id of the root container
+    /// \param chain list of container objects to create
+    /// \param refItem object to take artwork from
+    /// \param createdIds of the last container in the chain.
+    /// \return last id created
+    std::pair<int, bool> addContainerTree(
+        int parentContainerId,
+        const std::vector<std::shared_ptr<CdsObject>>& chain,
+        const std::shared_ptr<CdsObject>& refItem,
+        std::vector<int>& createdIds);
+
+    void finishScan(
+        const fs::path& location,
+        const std::shared_ptr<CdsContainer>& parent,
+        std::chrono::seconds lmt,
+        const std::shared_ptr<CdsObject>& firstObject = nullptr);
+
+    std::shared_ptr<CdsContainer> getContainer(const std::string& location) const;
     std::shared_ptr<CdsObject> getObject(const fs::path& location) const;
     std::shared_ptr<Layout> getLayout() const { return layout; }
     std::shared_ptr<MetadataService> getMetadataService() const { return metadataService; }
