@@ -11,7 +11,7 @@
                             Sergey 'Jin' Bostandzhyan <jin@mediatomb.cc>,
                             Leonhard Wimmer <leo@mediatomb.cc>
 
-    Copyright (C) 2016-2024 Gerbera Contributors
+    Copyright (C) 2016-2025 Gerbera Contributors
 
     MediaTomb is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License version 2
@@ -107,6 +107,7 @@ void AutoscanInotify::threadProc()
 {
     std::error_code ec;
     auto importMode = EnumOption<ImportMode>::getEnumOption(config, ConfigVal::IMPORT_LAYOUT_MODE);
+    AutoScanSetting asSetting;
     while (!shutdownFlag) {
         try {
             std::unique_lock<std::mutex> lock(mutex);
@@ -174,7 +175,7 @@ void AutoscanInotify::threadProc()
                     }
                     content->rescanDirectory(adir, adir->getObjectID(), location, false);
                 } else {
-                    log_error("Failed to read {}: {}", location.c_str(), ec.message());
+                    log_error("Failed to read autoscan directory {}: {}", location.c_str(), ec.message());
                 }
 
                 lock.lock();
@@ -186,9 +187,8 @@ void AutoscanInotify::threadProc()
             inotify_event* event = inotify->nextEvent();
             /* --- */
 
-            if (event) {
-                // lock.lock()
-                auto handler = InotifyHandler(this, event, events);
+            if (event && (event->mask & events)) {
+                auto handler = InotifyHandler(this, event, event->mask & events);
                 auto wdObj = getWatch(handler);
 
                 if (!wdObj)
@@ -199,20 +199,15 @@ void AutoscanInotify::threadProc()
 
                 handler.doMove(wdObj);
 
-                AutoScanSetting asSetting;
                 asSetting.adir = adir;
                 asSetting.followSymlinks = adir ? adir->getFollowSymlinks() : defFollowSymlinks;
                 asSetting.recursive = adir ? adir->getRecursive() : false;
                 asSetting.hidden = adir ? adir->getHidden() : defHidden;
                 asSetting.rescanResource = true;
-                asSetting.async = true;
+                asSetting.async = false;
+                asSetting.resourcePatterns.clear();
                 asSetting.mergeOptions(config, path);
 
-                // target is directory
-                if (isDir) {
-                    handler.doDirectory(asSetting, content, wdObj);
-                }
-
                 // changed
                 if (adir && handler.hasEvent()) {
                     // not new
@@ -222,8 +217,11 @@ void AutoscanInotify::threadProc()
                     // new file
                     handler.doNewFile(asSetting, content, isDir);
                 }
+                // target is directory
+                if (isDir) {
+                    handler.doDirectory(asSetting, content, wdObj);
+                }
                 handler.doIgnored();
-                // lock.unlock()
             }
         } catch (const std::runtime_error& e) {
             log_error("Inotify thread caught exception: {}", e.what());
@@ -366,7 +364,7 @@ void AutoscanInotify::checkMoveWatches(int wd, const std::shared_ptr<DirectoryWa
                         content->handlePeristentAutoscanRemove(adir);
                     }
 
-                    auto object = database->findObjectByPath(path, DbFileType::File);
+                    auto object = database->findObjectByPath(path, UNUSED_CLIENT_GROUP, DbFileType::File);
                     if (object)
                         content->removeObject(adir, object, path, false);
                 }
@@ -440,11 +438,11 @@ std::shared_ptr<DirectoryWatch> AutoscanInotify::monitorUnmonitorRecursive(const
 
         AutoScanSetting asSetting;
         asSetting.adir = adir;
-        asSetting.followSymlinks = adir ? adir->getFollowSymlinks() : defFollowSymlinks;
+        asSetting.followSymlinks = followSymlinks;
         asSetting.recursive = adir ? adir->getRecursive() : false;
         asSetting.hidden = adir ? adir->getHidden() : defHidden;
         asSetting.rescanResource = true;
-        asSetting.async = true;
+        asSetting.async = false;
         asSetting.mergeOptions(config, dirEnt.path());
 
         if (content->isHiddenFile(dirEnt, dirEnt.is_directory(ec), asSetting)) {
@@ -619,7 +617,6 @@ bool AutoscanInotify::removeFromWdObj(const std::shared_ptr<DirectoryWatch>& wdO
 
 void AutoscanInotify::addDescendant(int startPointWd, int addWd, const std::shared_ptr<AutoscanDirectory>& adir)
 {
-    // log_debug("called for {}, (adir->path={}); adding {}", startPointWd, adir->getLocation().c_str(), addWd);
     std::shared_ptr<DirectoryWatch> wdObj;
     try {
         wdObj = watches.at(startPointWd);
@@ -629,13 +626,10 @@ void AutoscanInotify::addDescendant(int startPointWd, int addWd, const std::shar
     if (!wdObj)
         return;
 
-    // log_debug("found wdObj");
     auto watch = getAppropriateAutoscan(wdObj, adir);
     if (!watch)
         return;
-    // log_debug("adding descendant");
     watch->addDescendant(addWd);
-    // log_debug("added descendant to {} (adir->path={}): {}; now: {}", startPointWd, adir->getLocation().c_str(), addWd, fmt::join(watch->getDescendants(), ","));
 }
 
 void AutoscanInotify::removeDescendants(int wd)
