@@ -11,7 +11,7 @@
                             Sergey 'Jin' Bostandzhyan <jin@mediatomb.cc>,
                             Leonhard Wimmer <leo@mediatomb.cc>
 
-    Copyright (C) 2016-2024 Gerbera Contributors
+    Copyright (C) 2016-2025 Gerbera Contributors
 
     MediaTomb is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License version 2
@@ -63,7 +63,7 @@ public:
         const fs::path& scriptPath,
         const std::map<AutoscanMediaMode, std::string>& containerMap);
 #ifdef ONLINE_SERVICES
-    std::vector<int> addTrailer(const std::shared_ptr<CdsObject>& obj,
+    std::vector<int> addOnlineItem(const std::shared_ptr<CdsObject>& obj,
         const fs::path& scriptPath,
         const std::map<AutoscanMediaMode, std::string>& containerMap);
 #endif
