@@ -11,7 +11,7 @@
                             Sergey 'Jin' Bostandzhyan <jin@mediatomb.cc>,
                             Leonhard Wimmer <leo@mediatomb.cc>
 
-    Copyright (C) 2016-2024 Gerbera Contributors
+    Copyright (C) 2016-2025 Gerbera Contributors
 
     MediaTomb is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License version 2
@@ -44,8 +44,6 @@
 #include "util/string_converter.h"
 #include "util/tools.h"
 
-// extern "C" {
-
 duk_ret_t js_print2(duk_context* ctx)
 {
     std::string mode = toUpper(duk_get_string(ctx, 0));
@@ -127,7 +125,7 @@ duk_ret_t js_addContainerTree(duk_context* ctx)
         } else
             log_debug("lastItem {}, resSize {}, refID {}", lastItem->getTitle(), lastItem->getResourceCount(), lastItem->getRefID());
         auto cm = self->getContent();
-        auto [containerId, containerStatus] = cm->addContainerTree(chain, lastItem);
+        auto containerId = std::get<0>(cm->addContainerTree(chain, lastItem));
         if (containerId != INVALID_OBJECT_ID) {
             /* setting last container ID as return value */
             log_debug("container {}", containerId);
@@ -183,7 +181,7 @@ duk_ret_t js_addCdsObject(duk_context* ctx)
             return 0;
         }
 
-        auto [parentId, parentStatus] = std::pair(stoiString(containerId), false);
+        auto parentId = stoiString(containerId);
 
         if (parentId <= 0) {
             log_error("Invalid parent id passed to addCdsObject: {}", parentId);
@@ -196,8 +194,12 @@ duk_ret_t js_addCdsObject(duk_context* ctx)
             return 0;
         }
 
+        if (self->isHiddenFile(cdsObj, rootPath)) {
+            log_debug("Hidden file {} cannot be added", cdsObj->getLocation().c_str());
+            return 0;
+        }
         cdsObj->setID(INVALID_OBJECT_ID);
-        self->getContent()->addObject(cdsObj, parentStatus);
+        self->getContent()->addObject(cdsObj, false);
 
         /* setting object ID as return value */
         duk_push_string(ctx, fmt::to_string(cdsObj->getID()).c_str());
@@ -254,6 +256,4 @@ duk_ret_t js_j2i(duk_context* ctx)
     return convertCharsetGeneric(ctx, J2I);
 }
 
-//} // extern "C"
-
 #endif // HAVE_JS
