@@ -11,7 +11,7 @@
                             Sergey 'Jin' Bostandzhyan <jin@mediatomb.cc>,
                             Leonhard Wimmer <leo@mediatomb.cc>
 
-    Copyright (C) 2016-2024 Gerbera Contributors
+    Copyright (C) 2016-2025 Gerbera Contributors
 
     MediaTomb is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License version 2
@@ -44,9 +44,11 @@
 #include "config/setup/config_setup_autoscan.h"
 #include "config/setup/config_setup_boxlayout.h"
 #include "config/setup/config_setup_dictionary.h"
+#include "content/autoscan_setting.h"
 #include "content/content.h"
 #include "context.h"
 #include "database/database.h"
+#include "duk_compat.h"
 #include "js_functions.h"
 #include "script_names.h"
 #include "script_property.h"
@@ -58,10 +60,6 @@
 #include "content/onlineservice/online_service.h"
 #endif
 
-#ifdef ATRAILERS
-#include "content/onlineservice/atrailers_content_handler.h"
-#endif
-
 #include <array>
 #include <fmt/chrono.h>
 
@@ -78,24 +76,41 @@ static constexpr std::array jsGlobalFunctions {
     duk_function_list_entry { nullptr, nullptr, 0 },
 };
 
-void Script::setProperty(const std::string& name, const std::string& value)
+void Script::setProperty(const std::string& name, const std::string& value, bool doEmpty)
 {
-    duk_push_string(ctx, value.c_str());
-    duk_put_prop_string(ctx, -2, name.c_str());
+    if (doEmpty || !value.empty()) {
+        duk_push_string(ctx, value.c_str());
+        duk_put_prop_string(ctx, -2, camelCaseString(name).c_str());
+    }
 }
 
 void Script::setIntProperty(const std::string& name, int value)
 {
     duk_push_int(ctx, value);
-    duk_put_prop_string(ctx, -2, name.c_str());
+    duk_put_prop_string(ctx, -2, camelCaseString(name).c_str());
+}
+
+void Script::setIntProperty(const std::string& name, int value, int checkValue)
+{
+    if (value != checkValue) {
+        duk_push_int(ctx, value);
+        duk_put_prop_string(ctx, -2, camelCaseString(name).c_str());
+    }
+}
+
+void Script::setBoolProperty(const std::string& name, bool value)
+{
+    duk_push_int(ctx, value ? 1 : 0);
+    duk_put_prop_string(ctx, -2, camelCaseString(name).c_str());
 }
 
 /* **************** */
 
 Script::Script(const std::shared_ptr<Content>& content, const std::string& parent,
-    const std::string& name, std::string objName, std::unique_ptr<StringConverter> sc)
+    const std::string& name, std::string objName, bool needResult, std::shared_ptr<StringConverter> sc)
     : config(content->getContext()->getConfig())
     , database(content->getContext()->getDatabase())
+    , converterManager(content->getContext()->getConverterManager())
     , content(content)
     , runtime(content->getScriptingRuntime())
     , sc(std::move(sc))
@@ -111,11 +126,11 @@ Script::Script(const std::shared_ptr<Content>& content, const std::string& paren
     if (!ctx)
         throw_std_runtime_error("Scripting: could not initialize js context");
 
-    _p2i = StringConverter::p2i(config);
-    _j2i = StringConverter::j2i(config);
-    _m2i = StringConverter::m2i(ConfigVal::IMPORT_METADATA_CHARSET, "", config);
-    _f2i = StringConverter::f2i(config);
-    _i2i = StringConverter::i2i(config);
+    _p2i = converterManager->p2i();
+    _j2i = converterManager->j2i();
+    _m2i = converterManager->m2i(ConfigVal::IMPORT_METADATA_CHARSET, "");
+    _f2i = converterManager->f2i();
+    _i2i = converterManager->i2i();
 
     duk_push_thread_stash(ctx, ctx);
     duk_push_pointer(ctx, this);
@@ -128,24 +143,14 @@ Script::Script(const std::shared_ptr<Content>& content, const std::string& paren
         duk_put_global_lstring(ctx, sym.data(), sym.size());
     }
 #ifdef ONLINE_SERVICES
-    duk_push_int(ctx, to_underlying(OnlineServiceType::OS_None));
+    duk_push_int(ctx, to_underlying(OnlineServiceType::None));
     duk_put_global_string(ctx, "ONLINE_SERVICE_NONE");
     duk_push_int(ctx, -1);
     duk_put_global_string(ctx, "ONLINE_SERVICE_YOUTUBE");
-
-#ifdef ATRAILERS
-    duk_push_int(ctx, to_underlying(OnlineServiceType::OS_ATrailers));
-    duk_put_global_string(ctx, "ONLINE_SERVICE_APPLE_TRAILERS");
-    duk_push_string(ctx, ATRAILERS_AUXDATA_POST_DATE);
-    duk_put_global_string(ctx, "APPLE_TRAILERS_AUXDATA_POST_DATE");
-#else
     duk_push_int(ctx, -1);
     duk_put_global_string(ctx, "ONLINE_SERVICE_APPLE_TRAILERS");
-#endif // ATRAILERS
-
     duk_push_int(ctx, -1);
     duk_put_global_string(ctx, "ONLINE_SERVICE_SOPCAST");
-
 #else // ONLINE SERVICES
     duk_push_int(ctx, 0);
     duk_put_global_string(ctx, "ONLINE_SERVICE_NONE");
@@ -188,10 +193,7 @@ Script::Script(const std::shared_ptr<Content>& content, const std::string& paren
         auto scs = ConfigDefinition::findConfigSetup(i, true);
         if (!scs)
             continue;
-        auto value = scs->getCurrentValue();
-        if (!value.empty()) {
-            setProperty(scs->getItemPath(ITEM_PATH_ROOT, {}), value);
-        }
+        setProperty(scs->getItemPathRoot(), scs->getCurrentValue(), false);
     }
 
     for (auto&& dcs : ConfigDefinition::getConfigSetupList<ConfigDictionarySetup>()) {
@@ -200,7 +202,7 @@ Script::Script(const std::shared_ptr<Content>& content, const std::string& paren
         for (auto&& [key, val] : dictionary) {
             setProperty(key.substr(5), val);
         }
-        duk_put_prop_string(ctx, -2, dcs->getItemPath(ITEM_PATH_ROOT, {}).c_str());
+        duk_put_prop_string(ctx, -2, dcs->getItemPathRoot().c_str());
     }
 
     for (auto&& acs : ConfigDefinition::getConfigSetupList<ConfigArraySetup>()) {
@@ -211,47 +213,50 @@ Script::Script(const std::shared_ptr<Content>& content, const std::string& paren
             duk_push_string(ctx, entry.c_str());
             duk_put_prop_index(ctx, dukArray, i);
         }
-        duk_put_prop_string(ctx, -2, acs->getItemPath(ITEM_PATH_ROOT, {}).c_str());
+        duk_put_prop_string(ctx, -2, acs->getItemPathRoot().c_str());
     }
 
-    duk_push_object(ctx); // autoscan
-    std::string autoscanItemPath;
     for (auto&& ascs : ConfigDefinition::getConfigSetupList<ConfigAutoscanSetup>()) {
+        duk_push_object(ctx); // autoscan
         auto autoscan = ascs->getValue()->getAutoscanListOption();
+
         for (const auto& adir : content->getAutoscanDirectories()) {
             duk_push_object(ctx);
+
             setProperty(ConfigDefinition::removeAttribute(ConfigVal::A_AUTOSCAN_DIRECTORY_LOCATION), adir->getLocation());
             setProperty(ConfigDefinition::removeAttribute(ConfigVal::A_AUTOSCAN_DIRECTORY_MODE), AutoscanDirectory::mapScanmode(adir->getScanMode()));
             setIntProperty(ConfigDefinition::removeAttribute(ConfigVal::A_AUTOSCAN_DIRECTORY_INTERVAL), adir->getInterval().count());
-            setIntProperty(ConfigDefinition::removeAttribute(ConfigVal::A_AUTOSCAN_DIRECTORY_RECURSIVE), adir->getRecursive());
+            setBoolProperty(ConfigDefinition::removeAttribute(ConfigVal::A_AUTOSCAN_DIRECTORY_RECURSIVE), adir->getRecursive());
             setIntProperty(ConfigDefinition::removeAttribute(ConfigVal::A_AUTOSCAN_DIRECTORY_MEDIATYPE), adir->getMediaType());
-            setIntProperty(ConfigDefinition::removeAttribute(ConfigVal::A_AUTOSCAN_DIRECTORY_HIDDENFILES), adir->getHidden());
+            setBoolProperty(ConfigDefinition::removeAttribute(ConfigVal::A_AUTOSCAN_DIRECTORY_HIDDENFILES), adir->getHidden());
             setIntProperty(ConfigDefinition::removeAttribute(ConfigVal::A_AUTOSCAN_DIRECTORY_SCANCOUNT), adir->getActiveScanCount());
             setIntProperty(ConfigDefinition::removeAttribute(ConfigVal::A_AUTOSCAN_DIRECTORY_TASKCOUNT), adir->getTaskCount());
             setProperty(ConfigDefinition::removeAttribute(ConfigVal::A_AUTOSCAN_DIRECTORY_LMT), fmt::format("{:%Y-%m-%d %H:%M:%S}", fmt::localtime(adir->getPreviousLMT().count())));
 
             duk_put_prop_string(ctx, -2, fmt::to_string(adir->getScanID()).c_str());
         }
-        autoscanItemPath = ascs->getItemPath(ITEM_PATH_PREFIX, {}); // prefix
+        std::string autoscanItemPath = ascs->getItemPathRoot(true); // prefix
+        duk_put_prop_string(ctx, -2, autoscanItemPath.c_str()); // autoscan
+        log_debug("Adding config[{}] {}", autoscanItemPath, content->getAutoscanDirectories().size());
     }
-    duk_put_prop_string(ctx, -2, autoscanItemPath.c_str()); // autoscan
 
     for (auto&& bcs : ConfigDefinition::getConfigSetupList<ConfigBoxLayoutSetup>()) {
         duk_push_object(ctx); // box-layout
-        std::string boxLayoutItemPath;
         auto boxLayoutList = bcs->getValue()->getBoxLayoutListOption();
         for (std::size_t i = 0; i < boxLayoutList->size(); i++) {
             duk_push_object(ctx);
             auto boxLayout = boxLayoutList->get(i);
             setIntProperty("id", boxLayout->getId());
             setIntProperty(ConfigDefinition::removeAttribute(ConfigVal::A_BOXLAYOUT_BOX_SIZE), boxLayout->getSize());
-            setIntProperty(ConfigDefinition::removeAttribute(ConfigVal::A_BOXLAYOUT_BOX_ENABLED), boxLayout->getEnabled());
+            setBoolProperty(ConfigDefinition::removeAttribute(ConfigVal::A_BOXLAYOUT_BOX_ENABLED), boxLayout->getEnabled());
             setProperty(ConfigDefinition::removeAttribute(ConfigVal::A_BOXLAYOUT_BOX_TITLE), boxLayout->getTitle());
             setProperty(ConfigDefinition::removeAttribute(ConfigVal::A_BOXLAYOUT_BOX_CLASS), boxLayout->getClass());
+            setProperty(ConfigDefinition::removeAttribute(ConfigVal::A_BOXLAYOUT_BOX_UPNP_SHORTCUT), boxLayout->getUpnpShortcut());
             duk_put_prop_string(ctx, -2, boxLayout->getKey().c_str());
         }
-        boxLayoutItemPath = bcs->getItemPath(ITEM_PATH_PREFIX, {}); // prefix
+        std::string boxLayoutItemPath = bcs->getItemPathRoot(true); // prefix
         duk_put_prop_string(ctx, -2, boxLayoutItemPath.c_str()); // box-layout
+        log_debug("Adding config[{}] {}", boxLayoutItemPath, boxLayoutList->size());
     }
 
     duk_put_global_string(ctx, "config");
@@ -325,7 +330,7 @@ void Script::_load(const fs::path& scriptPath)
     if (scriptText.empty())
         throw_std_runtime_error("empty script");
 
-    auto j2i = StringConverter::j2i(config);
+    auto j2i = converterManager->j2i();
     try {
         scriptText = j2i->convert(scriptText, true);
     } catch (const std::runtime_error& e) {
@@ -334,11 +339,7 @@ void Script::_load(const fs::path& scriptPath)
 
     duk_push_string(ctx, scriptPath.c_str());
     if (duk_pcompile_lstring_filename(ctx, 0, scriptText.c_str(), scriptText.length()) != 0) {
-#if DUK_VERSION > 20399
         log_error("Failed to load script {}: {}", scriptPath.c_str(), duk_safe_to_stacktrace(ctx, -1));
-#else
-        log_error("Failed to load script {}: {}", scriptPath.c_str(), duk_safe_to_string(ctx, -1));
-#endif
         throw_std_runtime_error("Scripting: failed to compile {}", scriptPath.c_str());
     }
 }
@@ -356,11 +357,7 @@ void Script::load(const fs::path& scriptPath)
 void Script::_execute()
 {
     if (duk_pcall(ctx, 0) != DUK_EXEC_SUCCESS) {
-#if DUK_VERSION > 20399
         log_error("Failed to execute script {}: {}", scriptPath.c_str(), duk_safe_to_stacktrace(ctx, -1));
-#else
-        log_error("Failed to execute script {}: {}", scriptPath.c_str(), duk_safe_to_string(ctx, -1));
-#endif
         throw_std_runtime_error("Script: failed to execute script");
     }
     duk_pop(ctx);
@@ -464,7 +461,11 @@ std::vector<int> Script::execute(const std::shared_ptr<CdsObject>& obj, const st
     return result;
 }
 
-std::vector<int> Script::call(const std::shared_ptr<CdsObject>& obj, const std::shared_ptr<CdsContainer>& cont, const std::string& functionName, const fs::path& rootPath, const std::string& containerType)
+std::vector<int> Script::call(const std::shared_ptr<CdsObject>& obj,
+    const std::shared_ptr<CdsContainer>& cont,
+    const std::string& functionName,
+    const fs::path& rootPath,
+    const std::string& containerType)
 {
     // write global object used in callback functionss
     cdsObject2dukObject(obj);
@@ -512,14 +513,15 @@ std::vector<int> Script::call(const std::shared_ptr<CdsObject>& obj, const std::
     if (duk_pcall(ctx, static_cast<duk_idx_t>(narg)) != DUK_EXEC_SUCCESS) {
         // Note: The invoked function will be blamed for execution errors, not the actual offending line of code
         // https://github.com/svaarala/duktape/blob/master/doc/error-objects.rst
-#if DUK_VERSION > 20399
         log_error("javascript {} runtime error: {}() - {}\n", contextName, functionName, duk_safe_to_stacktrace(ctx, -1));
-#else
-        log_error("javascript {} runtime error: {}() - {}\n", contextName, functionName, duk_safe_to_string(ctx, -1));
-#endif
         duk_pop(ctx);
         throw_std_runtime_error("javascript runtime error");
     }
+    if (duk_is_null_or_undefined(ctx, -1) && needResult) {
+        log_warning("Function '{}' did not return a value!", functionName);
+        duk_pop(ctx);
+        return {};
+    }
     std::vector<int> result = ScriptResultProperty(ctx).getIntArrayValue();
 
     duk_pop(ctx);
@@ -591,10 +593,12 @@ std::shared_ptr<CdsObject> Script::createObject(const std::shared_ptr<CdsObject>
         if (flags >= 0)
             obj->setFlags(flags);
 
+        // get resources
         ScriptNamedProperty(ctx, "res").getObject([&]() {
             auto keys = ScriptProperty(ctx).getPropertyNames();
 
             int resCount = 0;
+            // read resources
             for (auto&& sym : keys) {
                 if (sym.find("handlerType") != std::string::npos) {
                     int ht = ScriptNamedProperty(ctx, sym).getIntValue(-1);
@@ -608,6 +612,7 @@ std::shared_ptr<CdsObject> Script::createObject(const std::shared_ptr<CdsObject>
                     resCount++;
                 }
             }
+            // update resource attributes
             for (auto&& res : obj->getResources()) {
                 resCount = res->getResId();
                 // only attributes enumerated in res_names are allowed
@@ -637,6 +642,7 @@ std::shared_ptr<CdsObject> Script::createObject(const std::shared_ptr<CdsObject>
             }
         });
 
+        // update aux data
         ScriptNamedProperty(ctx, "aux").getObject([&]() {
             auto keys = ScriptProperty(ctx).getPropertyNames();
             for (auto&& sym : keys) {
@@ -663,6 +669,7 @@ std::shared_ptr<CdsObject> Script::dukObject2cdsObject(const std::shared_ptr<Cds
         obj->setMTime(std::chrono::seconds(mtime));
     }
 
+    // update title
     {
         auto val = ScriptNamedProperty(ctx, "title").getStringValue();
         if (!val.empty()) {
@@ -673,6 +680,7 @@ std::shared_ptr<CdsObject> Script::dukObject2cdsObject(const std::shared_ptr<Cds
         }
     }
 
+    // update upnpclass
     {
         auto val = ScriptNamedProperty(ctx, "upnpclass").getStringValue();
         if (!val.empty()) {
@@ -683,10 +691,12 @@ std::shared_ptr<CdsObject> Script::dukObject2cdsObject(const std::shared_ptr<Cds
         }
     }
 
+    // update restricted
     int restricted = ScriptNamedProperty(ctx, "restricted").getBoolValue();
     if (restricted >= 0)
         obj->setRestricted(restricted);
 
+    // update metaData
     ScriptNamedProperty(ctx, "metaData").getObject([&]() {
         auto item = std::static_pointer_cast<CdsItem>(obj);
         auto keys = ScriptProperty(ctx).getPropertyNames();
@@ -706,6 +716,7 @@ std::shared_ptr<CdsObject> Script::dukObject2cdsObject(const std::shared_ptr<Cds
         obj->setLocation(location);
     }
 
+    // update description
     auto description = ScriptNamedProperty(ctx, "description").getStringValue();
     if (!description.empty()) {
         description = sc->convert(description);
@@ -721,6 +732,7 @@ std::shared_ptr<CdsObject> Script::dukObject2cdsObject(const std::shared_ptr<Cds
         if (pcd)
             pcdItem = std::static_pointer_cast<CdsItem>(pcd);
 
+        // update mimetype
         auto mimetype = ScriptNamedProperty(ctx, "mimetype").getStringValue();
         if (!mimetype.empty()) {
             mimetype = sc->convert(mimetype);
@@ -729,12 +741,14 @@ std::shared_ptr<CdsObject> Script::dukObject2cdsObject(const std::shared_ptr<Cds
             item->setMimeType(pcdItem->getMimeType());
         }
 
+        // update serviceID for onlineservice
         auto serviceID = ScriptNamedProperty(ctx, "serviceID").getStringValue();
         if (!serviceID.empty()) {
             serviceID = sc->convert(serviceID);
             item->setServiceID(serviceID);
         }
 
+        // update description if not set in script
         {
             auto val = ScriptNamedProperty(ctx, "description").getStringValue();
             if (!val.empty()) {
@@ -746,15 +760,18 @@ std::shared_ptr<CdsObject> Script::dukObject2cdsObject(const std::shared_ptr<Cds
             }
         }
 
+        // update location if not set in script
         if (location.empty() && pcd) {
             obj->setLocation(pcd->getLocation());
         }
 
+        // CdsExternalItem (like links)
         if (obj->isExternalItem()) {
             std::string protocolInfo;
 
             obj->setRestricted(true);
 
+            // update protocol
             auto protocol = ScriptNamedProperty(ctx, "protocol").getStringValue();
             if (!protocol.empty()) {
                 protocol = sc->convert(protocol);
@@ -763,6 +780,7 @@ std::shared_ptr<CdsObject> Script::dukObject2cdsObject(const std::shared_ptr<Cds
                 protocolInfo = renderProtocolInfo(item->getMimeType(), PROTOCOL);
             }
 
+            // add resources
             std::shared_ptr<CdsResource> resource;
             if (item->getResourceCount() == 0) {
                 resource = std::make_shared<CdsResource>(ContentHandler::DEFAULT, ResourcePurpose::Content);
@@ -787,60 +805,55 @@ std::shared_ptr<CdsObject> Script::dukObject2cdsObject(const std::shared_ptr<Cds
         if (id >= CDS_ID_ROOT)
             cont->setUpdateID(id);
 
+        // update searchable
         int searchable = ScriptNamedProperty(ctx, "searchable").getBoolValue();
         log_debug("{} searchable {}", cont->getTitle(), searchable);
         if (searchable >= 0)
             cont->setSearchable(searchable);
 
+        // update upnpShortcut
+        auto upnpShortcut = ScriptNamedProperty(ctx, "upnpShortcut").getStringValue();
+        if (!upnpShortcut.empty()) {
+            upnpShortcut = sc->convert(upnpShortcut);
+            cont->setUpnpShortcut(upnpShortcut);
+        }
+
         handleObject2cdsContainer(ctx, pcd, cont);
     }
 
     return obj;
 }
 
+bool Script::isHiddenFile(const std::shared_ptr<CdsObject>& cdsObj, const std::string& rootPath)
+{
+    AutoScanSetting asSetting;
+    asSetting.recursive = true;
+    asSetting.followSymlinks = config->getBoolOption(ConfigVal::IMPORT_FOLLOW_SYMLINKS);
+    asSetting.hidden = config->getBoolOption(ConfigVal::IMPORT_HIDDEN_FILES);
+    asSetting.mergeOptions(config, rootPath);
+    return content->isHiddenFile(fs::directory_entry(cdsObj->getLocation()), false, asSetting);
+}
+
 void Script::cdsObject2dukObject(const std::shared_ptr<CdsObject>& obj)
 {
-    std::string val;
-
     duk_push_object(ctx);
 
     // CdsObject
     setIntProperty("objectType", obj->getObjectType());
+    setIntProperty("id", obj->getID(), INVALID_OBJECT_ID);
+    setIntProperty("parentID", obj->getParentID(), INVALID_OBJECT_ID);
 
-    int id = obj->getID();
-
-    if (id != INVALID_OBJECT_ID)
-        setIntProperty("id", id);
-
-    id = obj->getParentID();
-    if (id != INVALID_OBJECT_ID)
-        setIntProperty("parentID", id);
-
-    val = obj->getTitle();
-    if (!val.empty())
-        setProperty("title", val);
-
-    val = obj->getClass();
-    if (!val.empty())
-        setProperty("upnpclass", val);
-
-    val = obj->getLocation();
-    if (!val.empty())
-        setProperty("location", val);
+    setProperty("title", obj->getTitle(), false);
+    setProperty("upnpclass", obj->getClass(), false);
+    setProperty("location", obj->getLocation(), false);
 
     setIntProperty("mtime", static_cast<int>(obj->getMTime().count()));
     setIntProperty("utime", static_cast<int>(obj->getUTime().count()));
     setIntProperty("sizeOnDisk", static_cast<int>(obj->getSizeOnDisk()));
     setIntProperty("flags", obj->getFlags());
 
-    // TODO: boolean type
-    int restricted = obj->isRestricted();
-    setIntProperty("restricted", restricted);
-
-    if (obj->getFlag(OBJECT_FLAG_OGG_THEORA))
-        setIntProperty("theora", 1);
-    else
-        setIntProperty("theora", 0);
+    setBoolProperty("restricted", obj->isRestricted());
+    setBoolProperty("theora", obj->getFlag(OBJECT_FLAG_OGG_THEORA));
 
 #ifdef ONLINE_SERVICES
     if (obj->getFlag(OBJECT_FLAG_ONLINE_SERVICE)) {
@@ -900,12 +913,6 @@ void Script::cdsObject2dukObject(const std::shared_ptr<CdsObject>& obj)
 
         auto aux = obj->getAuxData();
 
-#ifdef HAVE_ATRAILERS
-        auto tmp = obj->getAuxData(ATRAILERS_AUXDATA_POST_DATE);
-        if (!tmp.empty())
-            aux[ATRAILERS_AUXDATA_POST_DATE] = tmp;
-#endif
-
         for (auto&& [key, attr] : aux) {
             setProperty(key, attr);
         }
@@ -948,23 +955,15 @@ void Script::cdsObject2dukObject(const std::shared_ptr<CdsObject>& obj)
     if (obj->isItem() && item) {
         setIntProperty("trackNumber", item->getTrackNumber());
         setIntProperty("partNumber", item->getPartNumber());
-        val = item->getMimeType();
-        if (!val.empty())
-            setProperty("mimetype", val);
-
-        val = item->getServiceID();
-        if (!val.empty())
-            setProperty("serviceID", val);
+        setProperty("mimetype", item->getMimeType(), false);
+        setProperty("serviceID", item->getServiceID(), false);
     }
 
     // CdsDirectory
     if (obj->isContainer()) {
         auto cont = std::static_pointer_cast<CdsContainer>(obj);
-        // TODO: boolean type, hide updateID
         setIntProperty("updateID", cont->getUpdateID());
-
-        int searchable = cont->isSearchable();
-        setIntProperty("searchable", searchable);
+        setBoolProperty("searchable", cont->isSearchable());
     }
 }
 
