@@ -11,7 +11,7 @@
                             Sergey 'Jin' Bostandzhyan <jin@mediatomb.cc>,
                             Leonhard Wimmer <leo@mediatomb.cc>
 
-    Copyright (C) 2016-2024 Gerbera Contributors
+    Copyright (C) 2016-2025 Gerbera Contributors
 
     MediaTomb is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License version 2
@@ -31,26 +31,30 @@
 
 /// \file database.h
 
-#ifndef __STORAGE_H__
-#define __STORAGE_H__
+#ifndef __GRB_DATABASE_H__
+#define __GRB_DATABASE_H__
+
+#include "util/grb_fs.h"
 
 #include <map>
 #include <unordered_set>
 #include <vector>
 
-#include "util/grb_fs.h"
-
-// forward declaration
-class AutoscanList;
+// forward declarations
 class AutoscanDirectory;
+class AutoscanList;
 enum class AutoscanScanMode;
+class BrowseParam;
 class CdsContainer;
 class CdsObject;
-struct ClientCacheEntry;
+struct ClientObservation;
 class ClientStatusDetail;
 class Config;
 class ConfigValue;
+class ConverterManager;
 class Mime;
+class SearchParam;
+class StatsParam;
 class Timer;
 
 #define BROWSE_DIRECT_CHILDREN 0x00000001
@@ -60,139 +64,12 @@ class Timer;
 #define BROWSE_TRACK_SORT 0x00000010
 #define BROWSE_HIDE_FS_ROOT 0x00000020
 
-class BrowseParam {
-protected:
-    unsigned int flags;
-    std::shared_ptr<CdsObject> object;
-
-    int startingIndex {};
-    int requestedCount {};
-    std::string sortCrit;
-    std::string group;
-    bool showDynamicContainers { true };
-
-    // output parameters
-    int totalMatches {};
-
-public:
-    BrowseParam(std::shared_ptr<CdsObject> object, unsigned int flags)
-        : flags(flags)
-        , object(std::move(object))
-    {
-    }
-
-    unsigned int getFlag(unsigned int mask) const { return flags & mask; }
-    void setFlag(unsigned int mask) { flags |= mask; }
-    void clearFlag(unsigned int mask) { flags &= ~mask; }
-
-    std::shared_ptr<CdsObject> getObject() const { return object; }
-
-    void setRange(int startingIndex, int requestedCount)
-    {
-        this->startingIndex = startingIndex;
-        this->requestedCount = requestedCount;
-    }
-    void setStartingIndex(int startingIndex)
-    {
-        this->startingIndex = startingIndex;
-    }
-
-    void setRequestedCount(int requestedCount)
-    {
-        this->requestedCount = requestedCount;
-    }
-
-    void setSortCriteria(const std::string& sortCrit)
-    {
-        this->sortCrit = sortCrit;
-    }
-
-    void setGroup(const std::string& group)
-    {
-        this->group = group;
-    }
-
-    void setDynamicContainers(bool showDynamicContainers)
-    {
-        this->showDynamicContainers = showDynamicContainers;
-    }
-
-    bool getDynamicContainers() const { return showDynamicContainers; }
-    int getStartingIndex() const { return startingIndex; }
-    int getRequestedCount() const { return requestedCount; }
-    int getTotalMatches() const { return totalMatches; }
-    const std::string& getSortCriteria() const { return sortCrit; }
-    const std::string& getGroup() const { return group; }
-
-    void setTotalMatches(int totalMatches)
-    {
-        this->totalMatches = totalMatches;
-    }
-};
-
-class SearchParam {
-protected:
-    std::string containerID;
-    std::string searchCrit;
-    std::string sortCrit;
-    int startingIndex;
-    int requestedCount;
-    bool searchableContainers;
-    std::string group;
-
-public:
-    SearchParam(std::string containerID, std::string searchCriteria, std::string sortCriteria, int startingIndex,
-        int requestedCount, bool searchableContainers, std::string group)
-        : containerID(std::move(containerID))
-        , searchCrit(std::move(searchCriteria))
-        , sortCrit(std::move(sortCriteria))
-        , startingIndex(startingIndex)
-        , requestedCount(requestedCount)
-        , searchableContainers(searchableContainers)
-        , group(std::move(group))
-    {
-    }
-    const std::string& getSearchCriteria() const { return searchCrit; }
-    const std::string& getContainerID() const { return containerID; }
-    bool getSearchableContainers() const { return searchableContainers; }
-    int getStartingIndex() const { return startingIndex; }
-    int getRequestedCount() const { return requestedCount; }
-    const std::string& getSortCriteria() const { return sortCrit; }
-    const std::string& getGroup() const { return group; }
-};
-
-class StatsParam {
-public:
-    enum class StatsMode {
-        Count,
-        Size,
-    };
-
-protected:
-    std::string mimeType;
-    std::string upnpClass;
-    StatsMode mode { StatsMode::Count };
-    bool isVirtual { false };
-
-public:
-    StatsParam(StatsMode mode, std::string mimeType, std::string upnpClass, bool isVirtual)
-        : mimeType(std::move(mimeType))
-        , upnpClass(std::move(upnpClass))
-        , mode(mode)
-        , isVirtual(isVirtual)
-    {
-    }
-    const std::string& getMimeType() const { return mimeType; }
-    const std::string& getUpnpClass() const { return upnpClass; }
-    StatsMode getMode() const { return mode; }
-    bool getVirtual() const { return isVirtual; }
-};
-
 enum class DbFileType {
     Auto,
     Directory,
     File,
     Virtual,
+    Any,
 };
 
 class Database {
@@ -207,15 +84,11 @@ public:
     virtual void addObject(const std::shared_ptr<CdsObject>& object, int* changedContainer) = 0;
 
     /// \brief Adds a virtual container chain specified by path.
-    /// \param path container path separated by '/'. Slashes in container
-    /// titles must be escaped.
-    /// \param lastClass upnp:class of the last container in the chain, it
-    /// is only set when the container is created for the first time.
-    /// \param lastRefID reference id of the last container in the chain,
-    /// INVALID_OBJECT_ID indicates that the id will not be set.
+    /// \param parentContainerId the id of the parent container
+    /// \param virtualPath container path separated by '/'
+    /// \param cont reference of the object to copy data from. Slashes in container
+    /// title must be escaped.
     /// \param containerID will be filled in by the function
-    /// \param updateID will be filled in by the function only if it is set to INVALID_OBJECT_ID
-    /// and it is necessary to update a container. Otherwise it will be left unchanged.
     ///
     /// The function gets a path (i.e. "/Audio/All Music/") and will create
     /// the container path if needed. The container ID will be filled in with
@@ -233,31 +106,42 @@ public:
 
     virtual void updateObject(const std::shared_ptr<CdsObject>& object, int* changedContainer) = 0;
 
+    /// \brief Perform upnp browse on the database
+    /// \param param browse parameters as received via request
+    /// \return list of CdsObject matching the browse criteria
     virtual std::vector<std::shared_ptr<CdsObject>> browse(BrowseParam& param) = 0;
-    virtual std::vector<std::shared_ptr<CdsObject>> search(const SearchParam& param, int* numMatches) = 0;
-    virtual std::vector<std::shared_ptr<CdsObject>> findObjectByContentClass(const std::string& contentClass) = 0;
+
+    /// \brief Perform upnp search on the database
+    /// \param param search parameters as received via request
+    /// \return list of CdsObject matching the search criteria
+    virtual std::vector<std::shared_ptr<CdsObject>> search(SearchParam& param) = 0;
+
+    /// \brief find container matching the content class
+    /// \param contentClass to search for
+    /// \param group user group name
+    /// \return list of CdsObject matching the content class
+    virtual std::vector<std::shared_ptr<CdsObject>> findObjectByContentClass(const std::string& contentClass, const std::string& group) = 0;
 
     virtual std::vector<std::string> getMimeTypes() = 0;
-
-    // virtual std::vector<std::shared_ptr<CdsObject>> selectObjects(const std::unique_ptr<SelectParam>& param) = 0;
+    virtual std::map<std::string, std::shared_ptr<CdsContainer>> getShortcuts() = 0;
 
     /// \brief Loads a given (pc directory) object, identified by the given path
     /// from the database
     /// \param path the path of the object; object is interpreted as directory
-    /// \param wasRegularFile was a regular file before file was moved, now fs::is_regular_file returns false (used for inotify events)
+    /// \param group user group name
+    /// \param fileType type of the database entry to search
     /// \return the CdsObject
-    virtual std::shared_ptr<CdsObject> findObjectByPath(const fs::path& path, DbFileType fileType = DbFileType::Auto) = 0;
+    virtual std::shared_ptr<CdsObject> findObjectByPath(const fs::path& path, const std::string& group, DbFileType fileType = DbFileType::Auto) = 0;
 
     /// \brief checks for a given (pc directory) object, identified by the given path
     /// from the database
-    /// \param path the path of the object; object is interpreted as directory
-    /// \param wasRegularFile was a regular file before file was moved, now fs::is_regular_file returns false (used for inotify events)
+    /// \param fullpath the path of the object; object is interpreted as directory
+    /// \param fileType type of the database entry to search
     /// \return the obejectID
     virtual int findObjectIDByPath(const fs::path& fullpath, DbFileType fileType = DbFileType::Auto) = 0;
 
     /// \brief increments the updateIDs for the given objectIDs
     /// \param ids pointer to the array of ids
-    /// \param size number of entries in the given array
     /// \return a String for UPnP: a CSV list; for every existing object:
     ///  "id,update_id"
     virtual std::string incrementUpdateIDs(const std::unordered_set<int>& ids) = 0;
@@ -280,16 +164,17 @@ public:
     /// the object is a reference to another object, the "all" flag
     /// determines, if the main object will be removed too.
     /// \param objectID the object id of the object to remove
+    /// \param path delete resource references to this path
     /// \param all if true and the object to be removed is a reference
-    /// \param objectType pointer to an int; will be filled with the objectType of
-    /// the removed object, if not NULL
     /// \return changed container ids
     virtual std::unique_ptr<ChangedContainers> removeObject(int objectID, const fs::path& path, bool all) = 0;
 
     /// \brief Get all objects under the given parentID.
     /// \param parentID parent container
     /// \param withoutContainer if false: all children are returned; if true: only items are returned
-    /// \return DBHash containing the objectID's - nullptr if there are none!
+    /// \param ret list of matching objects
+    /// \param full do full hierarchy search
+    /// \return number of objects found
     virtual std::size_t getObjects(int parentID, bool withoutContainer, std::unordered_set<int>& ret, bool full) = 0;
     virtual std::vector<int> getRefObjects(int objectId) = 0;
     virtual std::unordered_set<int> getUnreferencedObjects() = 0;
@@ -301,7 +186,7 @@ public:
     virtual std::unique_ptr<ChangedContainers> removeObjects(const std::unordered_set<int>& list, bool all = false) = 0;
 
     /// \brief Loads an object given by the online service ID.
-    virtual std::shared_ptr<CdsObject> loadObjectByServiceID(const std::string& serviceID) = 0;
+    virtual std::shared_ptr<CdsObject> loadObjectByServiceID(const std::string& serviceID, const std::string& group) = 0;
 
     /// \brief Return an array of object ID's for a particular service.
     ///
@@ -326,8 +211,8 @@ public:
     virtual void updateConfigValue(const std::string& key, const std::string& item, const std::string& value, const std::string& status = "unchanged") = 0;
 
     /* clients methods */
-    virtual std::vector<ClientCacheEntry> getClients() = 0;
-    virtual void saveClients(const std::vector<ClientCacheEntry>& cache) = 0;
+    virtual std::vector<ClientObservation> getClients() = 0;
+    virtual void saveClients(const std::vector<ClientObservation>& cache) = 0;
     virtual std::shared_ptr<ClientStatusDetail> getPlayStatus(const std::string& group, int objectId) = 0;
     virtual void savePlayStatus(const std::shared_ptr<ClientStatusDetail>& detail) = 0;
     virtual std::vector<std::shared_ptr<ClientStatusDetail>> getPlayStatusList(int objectId) = 0;
@@ -350,7 +235,8 @@ public:
     /// present in the database. If it does not exist it will be created, but
     /// it's content will not be added.
     ///
-    /// \param *changedContainer returns the ID for the UpdateManager
+    /// \param path location of the container to handle
+    /// \param changedContainer returns the ID for the UpdateManager
     /// \return objectID of the container given by path
     virtual int ensurePathExistence(const fs::path& path, int* changedContainer) = 0;
 
@@ -358,7 +244,10 @@ public:
     virtual bool threadCleanupRequired() const = 0;
 
 protected:
-    static std::shared_ptr<Database> createInstance(const std::shared_ptr<Config>& config, const std::shared_ptr<Mime>& mime, const std::shared_ptr<Timer>& timer);
+    static std::shared_ptr<Database> createInstance(const std::shared_ptr<Config>& config,
+        const std::shared_ptr<Mime>& mime,
+        const std::shared_ptr<ConverterManager>& converterManager,
+        const std::shared_ptr<Timer>& timer);
     friend class Server;
 
     virtual std::shared_ptr<Database> getSelf() = 0;
@@ -366,4 +255,4 @@ protected:
     std::shared_ptr<Config> config;
 };
 
-#endif // __STORAGE_H__
+#endif // __GRB_DATABASE_H__
