@@ -3,7 +3,7 @@
 
     sl_task.cc - this file is part of Gerbera.
 
-    Copyright (C) 2022-2023 Gerbera Contributors
+    Copyright (C) 2022-2025 Gerbera Contributors
 
     Gerbera is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License version 2
@@ -19,11 +19,13 @@
 */
 
 /// \file sl_task.cc
-#define LOG_FAC log_facility_t::sqlite3
+#define GRB_LOG_FAC GrbLogFacility::sqlite3
 
 #include "sl_task.h" // API
 
-#include "config/config_manager.h"
+#include "config/config.h"
+#include "config/config_val.h"
+#include "exceptions.h"
 #include "sqlite_database.h"
 #include "util/tools.h"
 
@@ -72,7 +74,7 @@ SLInitTask::SLInitTask(std::shared_ptr<Config> config, unsigned int hashie)
 void SLInitTask::run(sqlite3*& db, Sqlite3Database* sl, bool throwOnError)
 {
     log_debug("Running: init");
-    std::string dbFilePath = config->getOption(CFG_SERVER_STORAGE_SQLITE_DATABASE_FILE);
+    std::string dbFilePath = config->getOption(ConfigVal::SERVER_STORAGE_SQLITE_DATABASE_FILE);
 
     sqlite3_close(db);
 
@@ -80,7 +82,7 @@ void SLInitTask::run(sqlite3*& db, Sqlite3Database* sl, bool throwOnError)
     if (res != SQLITE_OK)
         throw DatabaseException("", "SQLite: Failed to create new database");
 
-    auto sqlFilePath = fs::path(config->getOption(CFG_SERVER_STORAGE_SQLITE_INIT_SQL_FILE));
+    auto sqlFilePath = fs::path(config->getOption(ConfigVal::SERVER_STORAGE_SQLITE_INIT_SQL_FILE));
     log_debug("Loading initialisation SQL from: {}", sqlFilePath.c_str());
     auto sql = GrbFile(std::move(sqlFilePath)).readTextFile();
     auto&& myHash = stringHash(sql);
@@ -151,10 +153,10 @@ SLExecTask::SLExecTask(const std::string& query, bool getLastInsertId, bool warn
 {
 }
 
-SLExecTask::SLExecTask(const std::string& query, const std::string& eKey)
+SLExecTask::SLExecTask(const std::string& query, std::string eKey)
     : query(query.c_str())
     , getLastInsertIdFlag(false)
-    , eKey(eKey)
+    , eKey(std::move(eKey))
 {
 }
 
@@ -187,8 +189,8 @@ void SLExecTask::run(sqlite3*& db, Sqlite3Database* sl, bool throwOnError)
 SLBackupTask::SLBackupTask(std::shared_ptr<Config> config, bool restore)
     : config(std::move(config))
     , restore(restore)
-    , dbFile(this->config->getOption(CFG_SERVER_STORAGE_SQLITE_DATABASE_FILE))
-    , dbBackupFile(fmt::format(SQLITE3_BACKUP_FORMAT, this->config->getOption(CFG_SERVER_STORAGE_SQLITE_DATABASE_FILE)))
+    , dbFile(this->config->getOption(ConfigVal::SERVER_STORAGE_SQLITE_DATABASE_FILE))
+    , dbBackupFile(fmt::format(SQLITE3_BACKUP_FORMAT, this->config->getOption(ConfigVal::SERVER_STORAGE_SQLITE_DATABASE_FILE)))
 {
 }
 
