@@ -2,7 +2,7 @@
 
     MediaTomb - http://www.mediatomb.cc/
 
-    sqlite3_database.cc - this file is part of MediaTomb.
+    sqlite_database.cc - this file is part of MediaTomb.
 
     Copyright (C) 2005 Gena Batyan <bgeradz@mediatomb.cc>,
                        Sergey 'Jin' Bostandzhyan <jin@mediatomb.cc>
@@ -11,7 +11,7 @@
                             Sergey 'Jin' Bostandzhyan <jin@mediatomb.cc>,
                             Leonhard Wimmer <leo@mediatomb.cc>
 
-    Copyright (C) 2016-2024 Gerbera Contributors
+    Copyright (C) 2016-2025 Gerbera Contributors
 
     MediaTomb is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License version 2
@@ -29,7 +29,7 @@
     $Id$
 */
 
-/// \file sqlite3_database.cc
+/// \file sqlite_database.cc
 #define GRB_LOG_FAC GrbLogFacility::sqlite3
 
 #include "sqlite_database.h" // API
@@ -45,8 +45,8 @@ static constexpr auto sqlite3AddResourceAttr = std::string_view(R"(ALTER TABLE "
 #define DELETE_CACHE_MAX_TIME 60 // drop cache if last delete was more than 60 secs ago
 #define DELETE_CACHE_RED_SIZE 0.2 // reduce cache to 80% of max entries
 
-Sqlite3Database::Sqlite3Database(const std::shared_ptr<Config>& config, const std::shared_ptr<Mime>& mime, std::shared_ptr<Timer> timer)
-    : SQLDatabase(config, mime)
+Sqlite3Database::Sqlite3Database(const std::shared_ptr<Config>& config, const std::shared_ptr<Mime>& mime, const std::shared_ptr<ConverterManager>& converterManager, std::shared_ptr<Timer> timer)
+    : SQLDatabase(config, mime, converterManager)
     , timer(std::move(timer))
 {
     table_quote_begin = '"';
@@ -67,42 +67,8 @@ void Sqlite3Database::prepare()
     exec(fmt::format("PRAGMA synchronous = {}", config->getIntOption(ConfigVal::SERVER_STORAGE_SQLITE_SYNCHRONOUS)));
 }
 
-void Sqlite3Database::init()
+std::string Sqlite3Database::prepareDatabase(const fs::path& dbFilePath, GrbFile& dbFile)
 {
-    dbInitDone = false;
-    SQLDatabase::init();
-
-    fs::path dbFilePath = config->getOption(ConfigVal::SERVER_STORAGE_SQLITE_DATABASE_FILE);
-    auto dbFile = GrbFile(dbFilePath);
-    log_debug("SQLite path: {}", dbFilePath.c_str());
-
-    // check for db-file
-    if (!dbFile.isWritable())
-        throw DatabaseException("", fmt::format("Error while accessing sqlite database file ({}): {}", dbFilePath.c_str(), std::strerror(errno)));
-
-    taskQueueOpen = true;
-    threadRunner = std::make_unique<StdThreadRunner>(
-        "SQLiteThread", [](void* arg) {
-            auto inst = static_cast<Sqlite3Database*>(arg);
-            inst->threadProc(); }, this);
-
-    if (!threadRunner->isAlive()) {
-        throw DatabaseException("", fmt::format("Could not start sqlite thread: {}", std::strerror(errno)));
-    }
-
-    // wait for sqlite3 thread to become ready
-    threadRunner->waitForReady();
-    if (!startupError.empty())
-        throw DatabaseException("", startupError);
-
-    // try to detect already active database client and terminate before doing any harm
-    try {
-        prepare();
-    } catch (const std::runtime_error&) {
-        shutdown();
-        throw_std_runtime_error("Sqlite3Database.init: could not open '{}' exclusively", dbFilePath.c_str());
-    }
-
     std::string dbVersion;
     fs::path dbFilePathbackup = fmt::format(SQLITE3_BACKUP_FORMAT, dbFilePath.c_str());
     auto dbBackupFile = GrbFile(dbFilePathbackup);
@@ -154,6 +120,47 @@ void Sqlite3Database::init()
         throw_std_runtime_error("sqlite3 database seems to be corrupt and restoring from backup failed");
     }
 
+    return dbVersion;
+}
+
+void Sqlite3Database::init()
+{
+    dbInitDone = false;
+    SQLDatabase::init();
+
+    fs::path dbFilePath = config->getOption(ConfigVal::SERVER_STORAGE_SQLITE_DATABASE_FILE);
+    auto dbFile = GrbFile(dbFilePath);
+    log_debug("SQLite path: {}", dbFilePath.c_str());
+
+    // check for db-file
+    if (!dbFile.isWritable())
+        throw DatabaseException("", fmt::format("Error while accessing sqlite database file ({}): {}", dbFilePath.c_str(), std::strerror(errno)));
+
+    taskQueueOpen = true;
+    threadRunner = std::make_unique<StdThreadRunner>(
+        "SQLiteThread", [](void* arg) {
+            auto inst = static_cast<Sqlite3Database*>(arg);
+            inst->threadProc(); }, this);
+
+    if (!threadRunner->isAlive()) {
+        throw DatabaseException("", fmt::format("Could not start sqlite thread: {}", std::strerror(errno)));
+    }
+
+    // wait for sqlite3 thread to become ready
+    threadRunner->waitForReady();
+    if (!startupError.empty())
+        throw DatabaseException("", startupError);
+
+    // try to detect already active database client and terminate before doing any harm
+    try {
+        prepare();
+    } catch (const std::runtime_error&) {
+        shutdown();
+        throw_std_runtime_error("Sqlite3Database.init: could not open '{}' exclusively", dbFilePath.c_str());
+    }
+
+    std::string dbVersion = prepareDatabase(dbFilePath, dbFile);
+
     try {
         upgradeDatabase(std::stoul(dbVersion), hashies, ConfigVal::SERVER_STORAGE_SQLITE_UPGRADE_FILE, sqlite3UpdateVersion, sqlite3AddResourceAttr);
         if (config->getBoolOption(ConfigVal::SERVER_STORAGE_SQLITE_BACKUP_ENABLED) && timer) {
@@ -173,6 +180,8 @@ void Sqlite3Database::init()
         shutdown();
         throw_std_runtime_error(e.what());
     }
+
+    initDynContainers();
 }
 
 std::shared_ptr<Database> Sqlite3Database::getSelf()
@@ -202,9 +211,9 @@ std::string Sqlite3Database::handleError(const std::string& query, const std::st
     return fmt::format("SQLITE3 ({}: {}): {}\n       Query: {}\n       Error: {}", sqlite3_errcode(db), sqlite3_extended_errcode(db), sqlite3_errmsg(db), query.empty() ? "unknown" : query, error.empty() ? "unknown" : error);
 }
 
-Sqlite3DatabaseWithTransactions::Sqlite3DatabaseWithTransactions(const std::shared_ptr<Config>& config, const std::shared_ptr<Mime>& mime, const std::shared_ptr<Timer>& timer)
+Sqlite3DatabaseWithTransactions::Sqlite3DatabaseWithTransactions(const std::shared_ptr<Config>& config, const std::shared_ptr<Mime>& mime, const std::shared_ptr<ConverterManager>& converterManager, const std::shared_ptr<Timer>& timer)
     : SqlWithTransactions(config)
-    , Sqlite3Database(config, mime, timer)
+    , Sqlite3Database(config, mime, converterManager, timer)
 {
 }
 
