@@ -11,7 +11,7 @@
                             Sergey 'Jin' Bostandzhyan <jin@mediatomb.cc>,
                             Leonhard Wimmer <leo@mediatomb.cc>
 
-    Copyright (C) 2016-2024 Gerbera Contributors
+    Copyright (C) 2016-2025 Gerbera Contributors
 
     MediaTomb is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License version 2
@@ -38,6 +38,7 @@
 #include <stdexcept>
 #include <string>
 
+#define LINE_MESSAGE fmt::format("[{}:{}] {}", __FILE__, __LINE__, __PRETTY_FUNCTION__)
 #define throw_std_runtime_error(...) throw std::runtime_error(fmt::format("[{}:{}] {} Error: {}", __FILE__, __LINE__, __PRETTY_FUNCTION__, fmt::format(__VA_ARGS__)))
 #define throw_fmt_system_error(...) throw fmt::system_error(errno, "[{}:{}] {} Error: {}", __FILE__, __LINE__, __PRETTY_FUNCTION__, fmt::format(__VA_ARGS__))
 
@@ -63,12 +64,16 @@ public:
     std::string getUserMessage() const { return (!userMessage.empty() ? userMessage : what()); }
 };
 
+class SearchParseException : public DatabaseException {
+    using DatabaseException::DatabaseException;
+};
+
 class ObjectNotFoundException : public DatabaseException {
 public:
     explicit ObjectNotFoundException(const std::string& message);
 };
 
-class SubtitlesNotFoundException : public std::runtime_error {
+class ResourceNotFoundException : public std::runtime_error {
     using std::runtime_error::runtime_error;
 };
 
