@@ -11,7 +11,7 @@
                             Sergey 'Jin' Bostandzhyan <jin@mediatomb.cc>,
                             Leonhard Wimmer <leo@mediatomb.cc>
 
-    Copyright (C) 2016-2024 Gerbera Contributors
+    Copyright (C) 2016-2025 Gerbera Contributors
 
     MediaTomb is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License version 2
@@ -30,12 +30,13 @@
 */
 
 /// \file curl_io_handler.h
-
-#ifdef HAVE_CURL
+/// \brief Definition of the CurlIOHandler class.
 
 #ifndef __CURL_IO_HANDLER_H__
 #define __CURL_IO_HANDLER_H__
 
+#ifdef HAVE_CURL
+
 #include <curl/curl.h>
 #include <upnp.h>
 
@@ -43,23 +44,27 @@
 
 class Config;
 
+/// \brief Allows the web server to read from a web site.
 class CurlIOHandler : public IOHandlerBufferHelper {
 public:
-    CurlIOHandler(const std::shared_ptr<Config>& config, const std::string& url, CURL* curlHandle, std::size_t bufSize, std::size_t initialFillSize);
+    CurlIOHandler(const std::shared_ptr<Config>& config, const std::string& url, std::size_t bufSize, std::size_t initialFillSize);
+    ~CurlIOHandler() noexcept override;
 
     void open(enum UpnpOpenFileMode mode) override;
     void close() override;
 
 private:
-    CURL* curl_handle;
-    bool external_curl_handle;
     std::string URL;
-    // off_t bytesCurl;
+    bool external_curl_handle;
+    CURL* curl_handle;
+#if 0
+    off_t bytesCurl { 0 };
+#endif
 
     static std::size_t curlCallback(void* ptr, std::size_t size, std::size_t nmemb, CurlIOHandler* ego);
     void threadProc() override;
 };
 
-#endif // __CURL_IO_HANDLER_H__
-
 #endif // HAVE_CURL
+
+#endif // __CURL_IO_HANDLER_H__
