@@ -11,7 +11,7 @@
                             Sergey 'Jin' Bostandzhyan <jin@mediatomb.cc>,
                             Leonhard Wimmer <leo@mediatomb.cc>
 
-    Copyright (C) 2016-2024 Gerbera Contributors
+    Copyright (C) 2016-2025 Gerbera Contributors
 
     MediaTomb is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License version 2
@@ -30,15 +30,17 @@
 */
 
 /// \file io_handler.h
-/// \brief Definitoin for the IOHandler class.
+/// \brief Definition for the IOHandler class.
+
 #ifndef __IO_HANDLER_H__
 #define __IO_HANDLER_H__
 
 #include <cstddef>
-
+#include <cstdint>
 #include <upnp.h>
 
-#define CHECK_SOCKET (-666)
+using grb_read_t = std::int32_t;
+static constexpr grb_read_t CHECK_SOCKET = -666;
 
 class IOHandler {
 public:
@@ -46,13 +48,12 @@ public:
 
     /// \brief Opens a data for the web server.
     /// \param mode in which the data will be opened (we only support UPNP_READ)
-    /// \todo Genych, ya tut che to zapamyatowal kak gawno rabotaet? kto filename poluchaet??
     virtual void open(enum UpnpOpenFileMode mode);
 
     /// \brief Reads previously opened/initialized data sequentially.
     /// \param buf This buffer will be filled by our read functions.
     /// \param length Number of bytes to read.
-    virtual std::size_t read(std::byte* buf, std::size_t length);
+    virtual grb_read_t read(std::byte* buf, std::size_t length);
 
     /// \brief Writes to previously opened/initialized data sequentially.
     /// \param buf Data to be written.
