@@ -11,7 +11,7 @@
                             Sergey 'Jin' Bostandzhyan <jin@mediatomb.cc>,
                             Leonhard Wimmer <leo@mediatomb.cc>
 
-    Copyright (C) 2016-2024 Gerbera Contributors
+    Copyright (C) 2016-2025 Gerbera Contributors
 
     MediaTomb is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License version 2
@@ -47,7 +47,7 @@ IOHandlerBufferHelper::IOHandlerBufferHelper(std::shared_ptr<Config> config, std
     if (bufSize == 0)
         throw_std_runtime_error("bufSize must be greater than 0");
     if (initialFillSize > bufSize)
-        throw_std_runtime_error("initialFillSize must be lesser than or equal to the size of the buffer");
+        throw_std_runtime_error("initialFillSize {} must be lesser than or equal to the size of the buffer {}", initialFillSize, bufSize);
 }
 
 void IOHandlerBufferHelper::open(enum UpnpOpenFileMode mode)
@@ -63,10 +63,10 @@ void IOHandlerBufferHelper::open(enum UpnpOpenFileMode mode)
 IOHandlerBufferHelper::~IOHandlerBufferHelper() noexcept
 {
     if (isOpen)
-        close();
+        IOHandlerBufferHelper::close();
 }
 
-std::size_t IOHandlerBufferHelper::read(std::byte* buf, std::size_t length)
+grb_read_t IOHandlerBufferHelper::read(std::byte* buf, std::size_t length)
 {
     // check read on closed BufferedIOHandler
     assert(isOpen);
