@@ -11,7 +11,7 @@
                             Sergey 'Jin' Bostandzhyan <jin@mediatomb.cc>,
                             Leonhard Wimmer <leo@mediatomb.cc>
 
-    Copyright (C) 2016-2024 Gerbera Contributors
+    Copyright (C) 2016-2025 Gerbera Contributors
 
     MediaTomb is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License version 2
@@ -34,11 +34,12 @@
 #ifndef __IO_HANDLER_BUFFER_HELPER_H__
 #define __IO_HANDLER_BUFFER_HELPER_H__
 
-#include <upnp.h>
+#include "io_handler.h" // Base
 
-#include "io_handler.h"
 #include "util/thread_runner.h"
 
+#include <upnp.h>
+
 class Config;
 
 /// \brief a IOHandler with buffer support
@@ -47,8 +48,8 @@ class Config;
 class IOHandlerBufferHelper : public IOHandler {
 public:
     /// \brief get an instance of a IOHandlerBufferHelper
+    /// \param config Access to the configuration
     /// \param bufSize the size of the buffer in bytes
-    /// \param maxChunkSize the maximum size of the chunks which are read by the buffer
     /// \param initialFillSize the number of bytes which have to be in the buffer
     /// before the first read at the very beginning or after a seek returns;
     /// 0 disables the delay
@@ -60,7 +61,7 @@ public:
 
     // inherited from IOHandler
     void open(enum UpnpOpenFileMode mode) override;
-    std::size_t read(std::byte* buf, std::size_t length) override;
+    grb_read_t read(std::byte* buf, std::size_t length) override;
     void seek(off_t offset, int whence) override;
     void close() override;
 
