@@ -4,7 +4,7 @@ Gerbera - https://gerbera.io/
 
     ffmpeg_thumbnailer_handler.cc - this file is part of Gerbera.
 
-    Copyright (C) 2022-2024 Gerbera Contributors
+    Copyright (C) 2022-2025 Gerbera Contributors
 
     Gerbera is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License version 2
@@ -27,6 +27,7 @@ Gerbera - https://gerbera.io/
 #include "ffmpeg_thumbnailer_handler.h" // API
 
 #include "cds/cds_item.h"
+#include "config/config.h"
 #include "config/config_val.h"
 #include "iohandler/mem_io_handler.h"
 #include "resolution.h"
@@ -35,14 +36,17 @@ Gerbera - https://gerbera.io/
 #include <libffmpegthumbnailer/filmstripfilter.h>
 #include <libffmpegthumbnailer/videothumbnailer.h>
 
-fs::path FfmpegThumbnailerHandler::getThumbnailCacheBasePath() const
+static void ffmpegThLogger(ThumbnailerLogLevel logLevel, const std::string message)
 {
-    auto configuredDir = config->getOption(ConfigVal::SERVER_EXTOPTS_FFMPEGTHUMBNAILER_CACHE_DIR);
-    if (!configuredDir.empty())
-        return configuredDir;
-
-    auto home = config->getOption(ConfigVal::SERVER_HOME);
-    return fs::path(home) / "cache-dir";
+    switch (logLevel) {
+    case ThumbnailerLogLevelError:
+        log_error("FfmpegThumbnailerHandler: {}", message);
+        break;
+    case ThumbnailerLogLevelInfo:
+    default:
+        log_debug("FfmpegThumbnailerHandler: {}", message);
+        break;
+    }
 }
 
 fs::path FfmpegThumbnailerHandler::getThumbnailCachePath(const fs::path& base, const fs::path& movie)
@@ -93,14 +97,15 @@ std::unique_ptr<IOHandler> FfmpegThumbnailerHandler::serveContent(const std::sha
         auto thumbLock = std::scoped_lock<std::mutex>(thumb_mutex);
 
         auto th = ffmpegthumbnailer::VideoThumbnailer(config->getIntOption(ConfigVal::SERVER_EXTOPTS_FFMPEGTHUMBNAILER_THUMBSIZE), false, true, config->getIntOption(ConfigVal::SERVER_EXTOPTS_FFMPEGTHUMBNAILER_IMAGE_QUALITY), false);
-        std::vector<uint8_t> img;
 
+        th.setLogCallback(ffmpegThLogger);
         th.setSeekPercentage(config->getIntOption(ConfigVal::SERVER_EXTOPTS_FFMPEGTHUMBNAILER_SEEK_PERCENTAGE));
         if (config->getBoolOption(ConfigVal::SERVER_EXTOPTS_FFMPEGTHUMBNAILER_FILMSTRIP_OVERLAY))
             th.addFilter(new ffmpegthumbnailer::FilmStripFilter());
 
         log_debug("Generating thumbnail for file: {}", item->getLocation().c_str());
 
+        std::vector<uint8_t> img;
         th.generateThumbnail(item->getLocation().c_str(), Jpeg, img);
         if (cacheEnabled) {
             writeThumbnailCacheFile(item->getLocation(), reinterpret_cast<std::byte*>(img.data()), img.size());
@@ -127,10 +132,7 @@ void FfmpegThumbnailerHandler::fillMetadata(const std::shared_ptr<CdsObject>& ob
         if (videoResolution.empty())
             return;
         auto resolution = Resolution(videoResolution);
-        auto mappings = config->getDictionaryOption(ConfigVal::IMPORT_MAPPINGS_MIMETYPE_TO_CONTENTTYPE_LIST);
-
-        auto it = mappings.find(CONTENT_TYPE_JPG);
-        std::string thumbMimetype = it != mappings.end() && !it->second.empty() ? it->second : "image/jpeg";
+        std::string thumbMimetype = getValueOrDefault(mimeContentTypeMappings, CONTENT_TYPE_JPG, "image/jpeg");
 
         auto thumbResource = std::make_shared<CdsResource>(ContentHandler::FFTH, ResourcePurpose::Thumbnail);
         thumbResource->addAttribute(ResourceAttribute::PROTOCOLINFO, renderProtocolInfo(thumbMimetype));
@@ -150,6 +152,15 @@ FfmpegThumbnailerHandler::FfmpegThumbnailerHandler(const std::shared_ptr<Context
     : MediaMetadataHandler(context, ConfigVal::SERVER_EXTOPTS_FFMPEGTHUMBNAILER_ENABLED)
 {
     isEnabled = this->isEnabled && config->getBoolOption(checkOption);
+    if (isEnabled) {
+        auto configuredDir = config->getOption(ConfigVal::SERVER_EXTOPTS_FFMPEGTHUMBNAILER_CACHE_DIR);
+        if (!configuredDir.empty()) {
+            cachePath = configuredDir;
+        } else {
+            auto home = config->getOption(ConfigVal::SERVER_HOME);
+            cachePath = fs::path(home) / "cache-dir";
+        }
+    }
 }
 
 #endif
