@@ -11,7 +11,7 @@
                             Sergey 'Jin' Bostandzhyan <jin@mediatomb.cc>,
                             Leonhard Wimmer <leo@mediatomb.cc>
 
-    Copyright (C) 2016-2024 Gerbera Contributors
+    Copyright (C) 2016-2025 Gerbera Contributors
 
     MediaTomb is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License version 2
@@ -51,7 +51,7 @@ class LibExifHandler : public MediaMetadataHandler {
 private:
     ExifLog* log = nullptr;
 
-    void process_ifd(const ExifContent* content, const std::shared_ptr<CdsItem>& item, const std::unique_ptr<StringConverter>& sc,
+    void process_ifd(const ExifContent* content, const std::shared_ptr<CdsItem>& item, const std::shared_ptr<StringConverter>& sc,
         std::string& imageX, std::string& imageY,
         const std::vector<std::string>& auxtags, const std::map<std::string, std::string>& metatags);
 
