@@ -4,7 +4,7 @@
 
     matroska_handler.cc - this file is part of Gerbera.
 
-    Copyright (C) 2019-2024 Gerbera Contributors
+    Copyright (C) 2019-2025 Gerbera Contributors
 
     Gerbera is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License version 2
@@ -267,7 +267,7 @@ void MatroskaHandler::parseInfo(const std::shared_ptr<CdsItem>& item, EbmlStream
     // master elements
     info->Read(ebmlStream, EBML_CONTEXT(info), iUpperLevel, dummyEl, true);
 
-    auto sc = StringConverter::m2i(ConfigVal::IMPORT_LIBOPTS_MKV_CHARSET, item->getLocation(), config);
+    auto sc = converterManager->m2i(ConfigVal::IMPORT_LIBOPTS_MKV_CHARSET, item->getLocation());
     for (auto&& el : *info) {
         if (EbmlId(*el) == EBML_ID(KaxTitle)) {
             auto titleEl = dynamic_cast<KaxTitle*>(el);
