@@ -4,7 +4,7 @@
 
     metacontent_handler.cc - this file is part of Gerbera.
 
-    Copyright (C) 2020-2024 Gerbera Contributors
+    Copyright (C) 2020-2025 Gerbera Contributors
 
     Gerbera is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License version 2
@@ -28,11 +28,14 @@
 
 #include "cds/cds_objects.h"
 #include "config/config.h"
+#include "config/config_definition.h"
 #include "config/config_val.h"
 #include "config/result/directory_tweak.h"
 #include "content/content.h"
+#include "context.h"
 #include "iohandler/file_io_handler.h"
 #include "util/mime.h"
+#include "util/string_converter.h"
 #include "util/tools.h"
 
 #include <array>
@@ -42,7 +45,7 @@
 ContentPathSetup::ContentPathSetup(std::shared_ptr<Config> config, ConfigVal fileListOption, ConfigVal dirListOption)
     : config(std::move(config))
     , names(this->config->getArrayOption(fileListOption))
-    , patterns(this->config->getDictionaryOption(dirListOption))
+    , patterns(this->config->getVectorOption(dirListOption))
     , allTweaks(this->config->getDirectoryTweakOption(ConfigVal::IMPORT_DIRECTORIES_LIST))
     , caseSensitive(this->config->getBoolOption(ConfigVal::IMPORT_RESOURCES_CASE_SENSITIVE))
 {
@@ -51,10 +54,14 @@ ContentPathSetup::ContentPathSetup(std::shared_ptr<Config> config, ConfigVal fil
 std::vector<fs::path> ContentPathSetup::getContentPath(const std::shared_ptr<CdsObject>& obj, const std::string& setting, fs::path folder) const
 {
     auto objLocation = obj->getLocation();
-    auto tweak = allTweaks->get(objLocation);
+    auto tweak = allTweaks->getKey(objLocation);
     auto files = !tweak || !tweak->hasSetting(setting) ? this->names : std::vector<std::string> { tweak->getSetting(setting) };
     auto isCaseSensitive = tweak && tweak->hasCaseSensitive() ? tweak->getCaseSensitive() : this->caseSensitive;
 
+    static auto nameOption = ConfigDefinition::removeAttribute(ConfigVal::A_IMPORT_RESOURCES_NAME);
+    static auto extOption = ConfigDefinition::removeAttribute(ConfigVal::A_IMPORT_RESOURCES_EXT);
+    static auto pttOption = ConfigDefinition::removeAttribute(ConfigVal::A_IMPORT_RESOURCES_PTT);
+
     std::vector<fs::path> result;
 
     if (!files.empty()) {
@@ -64,6 +71,7 @@ std::vector<fs::path> ContentPathSetup::getContentPath(const std::shared_ptr<Cds
         log_debug("Folder name: {}", folder.c_str());
 
         if (isCaseSensitive) {
+            // directly search files using name
             for (auto&& name : files) {
                 auto contentFile = folder / expandName(name, obj);
                 std::error_code ec;
@@ -76,10 +84,12 @@ std::vector<fs::path> ContentPathSetup::getContentPath(const std::shared_ptr<Cds
         } else {
             std::map<std::string, fs::path> fileNames;
             std::error_code ec;
+            // get all files in lowercase
             for (auto&& p : fs::directory_iterator(folder, ec))
                 if (isRegularFile(p, ec) && p.path() != objLocation)
                     fileNames[toLower(p.path().filename().string())] = p;
 
+            // filter files matching filenames
             for (auto&& name : files) {
                 auto fileName = toLower(expandName(name, obj));
                 for (auto&& [f, s] : fileNames) {
@@ -91,9 +101,22 @@ std::vector<fs::path> ContentPathSetup::getContentPath(const std::shared_ptr<Cds
             }
         }
         if (!patterns.empty()) {
-            for (auto&& [dir, ext] : patterns) {
+            // filter files matching patterns
+            for (auto&& pattern : patterns) {
+                std::string dir;
+                std::string ext;
+                std::string ptt;
+                for (auto&& [key, val] : pattern) {
+                    if (key == nameOption)
+                        dir = val;
+                    else if (key == extOption)
+                        ext = val;
+                    else if (key == pttOption)
+                        ptt = val;
+                }
                 auto contentPath = fs::path(expandName(dir, obj));
                 auto extn = fs::path(expandName(ext, obj));
+                ptt = expandName(ptt, obj);
                 auto stem = isCaseSensitive ? extn.stem().string() : toLower(extn.stem().string());
                 if (extn.has_extension()) {
                     extn = isCaseSensitive ? extn.extension().string() : toLower(extn.extension().string());
@@ -101,6 +124,9 @@ std::vector<fs::path> ContentPathSetup::getContentPath(const std::shared_ptr<Cds
                     extn = fmt::format(".{}", isCaseSensitive ? ext : toLower(ext));
                     stem.clear();
                 }
+                if (!ptt.empty()) {
+                    stem = fmt::format("{}{}", ptt, stem);
+                }
                 std::error_code ec;
                 if (contentPath.is_relative()) {
                     contentPath = fs::weakly_canonical(folder / contentPath);
@@ -109,14 +135,16 @@ std::vector<fs::path> ContentPathSetup::getContentPath(const std::shared_ptr<Cds
                     log_debug("{}: not a directory", contentPath.string());
                     continue;
                 }
+                // Check files using patterns
                 for (auto&& contentFile : fs::directory_iterator(contentPath, ec)) {
-                    if (isRegularFile(contentFile, ec) && ((isCaseSensitive && contentFile.path().extension() == extn) || (!isCaseSensitive && toLower(contentFile.path().extension().string()) == extn)) && contentFile.path() != objLocation) {
+                    if (isRegularFile(contentFile, ec)
+                        && (ext.empty() || (isCaseSensitive && contentFile.path().extension() == extn) || (!isCaseSensitive && toLower(contentFile.path().extension().string()) == extn))
+                        && contentFile.path() != objLocation) {
                         if (!stem.empty()) {
+                            replaceAllString(stem, "?", ".");
                             replaceAllString(stem, "*", ".*");
-                            replaceAllString(stem, ".", "?");
                             auto re = std::regex(fmt::format("^{}$", stem));
-                            std::cmatch m;
-                            if (std::regex_match(contentFile.path().stem().string().c_str(), m, re)) {
+                            if (std::regex_match(contentFile.path().stem().string(), re)) {
                                 log_debug("{}: found", contentFile.path().string());
                                 result.push_back(contentFile.path());
                             }
@@ -143,9 +171,15 @@ static constexpr std::array metaTags {
     std::pair("%composer%", MetadataFields::M_COMPOSER),
 };
 
-std::string ContentPathSetup::expandName(std::string_view name, const std::shared_ptr<CdsObject>& obj)
+std::string ContentPathSetup::expandName(const std::string& name, const std::shared_ptr<CdsObject>& obj)
 {
     std::string copy(name);
+    auto path = (obj->isItem()) ? obj->getLocation().parent_path().string() : obj->getLocation().string();
+    if (name.empty())
+        return path;
+    else if (name.at(0) == '.') {
+        return copy.replace(0, 1, path);
+    }
 
     for (auto&& [key, val] : metaTags)
         replaceString(copy, key, obj->getMetaData(val));
@@ -166,6 +200,12 @@ std::string ContentPathSetup::expandName(std::string_view name, const std::share
 
 std::unique_ptr<ContentPathSetup> FanArtHandler::setup {};
 
+MetacontentHandler::MetacontentHandler(const std::shared_ptr<Context>& context)
+    : MetadataHandler(context)
+    , f2i(context->getConverterManager()->f2i())
+{
+}
+
 FanArtHandler::FanArtHandler(const std::shared_ptr<Context>& context)
     : MetacontentHandler(context)
 {
@@ -186,7 +226,7 @@ void FanArtHandler::fillMetadata(const std::shared_ptr<CdsObject>& obj)
         if (!path.empty()) {
             auto resource = std::make_shared<CdsResource>(ContentHandler::FANART, ResourcePurpose::Thumbnail);
             std::string type = path.extension().string().substr(1);
-            auto [skip, mimeType] = mime->getMimeType(path, fmt::format("image/{}", type));
+            auto mimeType = std::get<1>(mime->getMimeType(path, fmt::format("image/{}", type)));
 
             if (!mimeType.empty()) {
                 resource->addAttribute(ResourceAttribute::PROTOCOLINFO, renderProtocolInfo(mimeType));
@@ -238,10 +278,10 @@ void ContainerArtHandler::fillMetadata(const std::shared_ptr<CdsObject>& obj)
             log_debug("Running ContainerArt handler on {}", !path.empty() ? path.c_str() : obj->getLocation().c_str());
             auto resource = std::make_shared<CdsResource>(ContentHandler::CONTAINERART, ResourcePurpose::Thumbnail);
             std::string type = path.extension().string().substr(1);
-            auto [skip, mimeType] = mime->getMimeType(path, fmt::format("image/{}", type));
+            auto mimeType = std::get<1>(mime->getMimeType(path, fmt::format("image/{}", type)));
             if (!mimeType.empty()) {
                 resource->addAttribute(ResourceAttribute::PROTOCOLINFO, renderProtocolInfo(mimeType));
-                resource->addAttribute(ResourceAttribute::RESOURCE_FILE, path.string());
+                resource->addAttribute(ResourceAttribute::RESOURCE_FILE, f2i->convert(path.string()));
             }
             obj->addResource(resource);
         }
@@ -291,14 +331,14 @@ void SubtitleHandler::fillMetadata(const std::shared_ptr<CdsObject>& obj)
             auto resource = std::make_shared<CdsResource>(ContentHandler::SUBTITLE, ResourcePurpose::Subtitle);
             std::string type = path.extension().string().substr(1);
 
-            auto [skip, mimeType] = mime->getMimeType(path, fmt::format("text/{}", type));
+            auto mimeType = std::get<1>(mime->getMimeType(path, fmt::format("text/{}", type)));
             auto pos = mimeType.find("plain");
             if (pos != std::string::npos) {
                 mimeType = fmt::format("{}{}", mimeType.substr(0, pos), type);
             }
 
             resource->addAttribute(ResourceAttribute::PROTOCOLINFO, renderProtocolInfo(mimeType));
-            resource->addAttribute(ResourceAttribute::RESOURCE_FILE, path.string());
+            resource->addAttribute(ResourceAttribute::RESOURCE_FILE, f2i->convert(path.string()));
             resource->addAttribute(ResourceAttribute::TYPE, type);
             auto lang = path.stem().string();
             if (startswith(lang, objFilename)) {
@@ -386,7 +426,7 @@ void ResourceHandler::fillMetadata(const std::shared_ptr<CdsObject>& obj)
             log_debug("Running resource handler check on {} -> {}", obj->getLocation().string(), path.string());
             auto resource = std::make_shared<CdsResource>(ContentHandler::RESOURCE, ResourcePurpose::Thumbnail);
             resource->addAttribute(ResourceAttribute::PROTOCOLINFO, renderProtocolInfo("res"));
-            resource->addAttribute(ResourceAttribute::RESOURCE_FILE, path.string());
+            resource->addAttribute(ResourceAttribute::RESOURCE_FILE, f2i->convert(path.string()));
             obj->addResource(resource);
         }
     }
