@@ -11,7 +11,7 @@
                             Sergey 'Jin' Bostandzhyan <jin@mediatomb.cc>,
                             Leonhard Wimmer <leo@mediatomb.cc>
 
-    Copyright (C) 2016-2024 Gerbera Contributors
+    Copyright (C) 2016-2025 Gerbera Contributors
 
     MediaTomb is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License version 2
@@ -103,7 +103,7 @@ void TagLibHandler::addField(MetadataFields field, const TagLib::File& file, con
     if (!tag || tag->isEmpty())
         return;
 
-    auto sc = StringConverter::i2i(config); // sure is sure
+    auto sc = converterManager->i2i(); // sure is sure
 
     std::vector<std::string> value;
 
@@ -187,7 +187,7 @@ void TagLibHandler::addSpecialFields(const TagLib::File& file, const TagLib::Tag
     if (!tag || tag->isEmpty())
         return;
 
-    auto sc = StringConverter::i2i(config); // sure is sure
+    auto sc = converterManager->i2i(); // sure is sure
 
     for (auto&& [key, meta] : metaTags) {
         auto list = file.properties()[key];
@@ -243,7 +243,7 @@ void TagLibHandler::populateGenericTags(const std::shared_ptr<CdsItem>& item, co
     }
 }
 
-void TagLibHandler::populateAuxTags(const std::shared_ptr<CdsItem>& item, const TagLib::PropertyMap& propertyMap, const std::unique_ptr<StringConverter>& sc) const
+void TagLibHandler::populateAuxTags(const std::shared_ptr<CdsItem>& item, const TagLib::PropertyMap& propertyMap, const std::shared_ptr<StringConverter>& sc) const
 {
     for (auto&& desiredTag : auxTags) {
         if (desiredTag.empty()) {
@@ -274,9 +274,9 @@ void TagLibHandler::fillMetadata(const std::shared_ptr<CdsObject>& obj)
     if (!item || !isEnabled)
         return;
 
-    auto mappings = config->getDictionaryOption(ConfigVal::IMPORT_MAPPINGS_MIMETYPE_TO_CONTENTTYPE_LIST);
-    std::string contentType = getValueOrDefault(mappings, item->getMimeType());
+    std::string contentType = getValueOrDefault(mimeContentTypeMappings, item->getMimeType());
 
+    log_debug("Reading {}, content type {}", item->getLocation().c_str(), contentType);
     auto fs = TagLib::FileStream(item->getLocation().c_str(), true); // true = Read only
 
     if (contentType == CONTENT_TYPE_MP3) {
@@ -296,9 +296,9 @@ void TagLibHandler::fillMetadata(const std::shared_ptr<CdsObject>& obj)
     } else if (contentType == CONTENT_TYPE_AIFF) {
         extractAiff(fs, item);
     } else {
-        log_warning("TagLibHandler {}: Does not handle the {} content type", item->getLocation().c_str(), contentType.c_str());
+        log_warning("TagLibHandler: File '{}' has unhandled content type '{}'", item->getLocation().c_str(), contentType.c_str());
     }
-    log_debug("TagLib handler done.");
+    log_debug("Done {}", item->getLocation().c_str());
 }
 
 bool TagLibHandler::isValidArtworkContentType(std::string_view artMimetype)
@@ -341,8 +341,7 @@ std::unique_ptr<IOHandler> TagLibHandler::serveContent(const std::shared_ptr<Cds
     if (!item) // not streamable
         return nullptr;
 
-    auto mappings = config->getDictionaryOption(ConfigVal::IMPORT_MAPPINGS_MIMETYPE_TO_CONTENTTYPE_LIST);
-    std::string contentType = getValueOrDefault(mappings, item->getMimeType());
+    std::string contentType = getValueOrDefault(mimeContentTypeMappings, item->getMimeType());
     auto itemLocation = item->getLocation().c_str();
 
     auto roStream = TagLib::FileStream(itemLocation, true); // Open read only
@@ -481,7 +480,7 @@ void TagLibHandler::extractMP3(TagLib::IOStream& roStream, const std::shared_ptr
         return;
     }
 
-    auto sc = StringConverter::i2i(config);
+    auto sc = converterManager->i2i();
 
     auto&& frameListMap = mp3.ID3v2Tag()->frameListMap();
     // http://id3.org/id3v2.4.0-frames "4.2.6. User defined text information frame"
@@ -517,7 +516,7 @@ void TagLibHandler::extractMP3(TagLib::IOStream& roStream, const std::shared_ptr
             }
         } else if (hasTXXXFrames && startswith(desiredFrame, "TXXX:")) {
             auto&& frameList = frameListMap["TXXX"];
-            // log_debug("TXXX Frame list has {} elements", frameList.size());
+            log_debug("TXXX Frame list has {} elements", frameList.size());
 
             std::string desiredSubTag = desiredFrame.substr(5);
             if (desiredSubTag.empty())
@@ -606,7 +605,7 @@ void TagLibHandler::extractOgg(TagLib::IOStream& roStream, const std::shared_ptr
     if (!oggFile->tag())
         return;
 
-    auto sc = StringConverter::i2i(config);
+    auto sc = converterManager->i2i();
     auto propertyMap = oggFile->properties();
     populateAuxTags(item, propertyMap, sc);
 
@@ -637,7 +636,7 @@ void TagLibHandler::extractASF(TagLib::IOStream& roStream, const std::shared_ptr
     }
     populateGenericTags(item, asf);
 
-    auto sc = StringConverter::i2i(config);
+    auto sc = converterManager->i2i();
     auto propertyMap = asf.properties();
     populateAuxTags(item, propertyMap, sc);
 
@@ -680,7 +679,7 @@ void TagLibHandler::extractFLAC(TagLib::IOStream& roStream, const std::shared_pt
     }
     populateGenericTags(item, flac);
 
-    auto sc = StringConverter::i2i(config);
+    auto sc = converterManager->i2i();
     auto propertyMap = flac.properties();
     populateAuxTags(item, propertyMap, sc);
 
@@ -715,7 +714,7 @@ void TagLibHandler::extractAPE(TagLib::IOStream& roStream, const std::shared_ptr
     }
     populateGenericTags(item, ape);
 
-    auto sc = StringConverter::i2i(config);
+    auto sc = converterManager->i2i();
     auto propertyMap = ape.properties();
     populateAuxTags(item, propertyMap, sc);
 
@@ -737,7 +736,7 @@ void TagLibHandler::extractWavPack(TagLib::IOStream& roStream, const std::shared
     }
     populateGenericTags(item, wavpack);
 
-    auto sc = StringConverter::i2i(config);
+    auto sc = converterManager->i2i();
     auto propertyMap = wavpack.properties();
     populateAuxTags(item, propertyMap, sc);
 
@@ -769,7 +768,7 @@ void TagLibHandler::extractMP4(TagLib::IOStream& roStream, const std::shared_ptr
         return;
     }
 
-    auto sc = StringConverter::i2i(config);
+    auto sc = converterManager->i2i();
     auto propertyMap = mp4.tag()->properties();
     populateAuxTags(item, propertyMap, sc);
 
@@ -810,7 +809,7 @@ void TagLibHandler::extractAiff(TagLib::IOStream& roStream, const std::shared_pt
     }
     populateGenericTags(item, aiff);
 
-    auto sc = StringConverter::i2i(config);
+    auto sc = converterManager->i2i();
     auto propertyMap = aiff.properties();
     populateAuxTags(item, propertyMap, sc);
 
