@@ -4,7 +4,7 @@
 
     wavpack_handler.h - this file is part of Gerbera.
 
-    Copyright (C) 2022-2024 Gerbera Contributors
+    Copyright (C) 2022-2025 Gerbera Contributors
 
     Gerbera is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License version 2
@@ -33,6 +33,9 @@
 
 #include <wavpack/wavpack.h>
 
+// forward declarations
+class CdsItem;
+
 /// \brief This class is responsible for reading wavpack tags metadata
 class WavPackHandler : public MediaMetadataHandler {
 public:
