@@ -11,7 +11,7 @@
                             Sergey 'Jin' Bostandzhyan <jin@mediatomb.cc>,
                             Leonhard Wimmer <leo@mediatomb.cc>
 
-    Copyright (C) 2016-2023 Gerbera Contributors
+    Copyright (C) 2016-2025 Gerbera Contributors
 
     MediaTomb is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License version 2
@@ -30,7 +30,7 @@
 */
 
 /// \file subscription_request.cc
-#define LOG_FAC log_facility_t::requests
+#define GRB_LOG_FAC GrbLogFacility::requests
 
 #include "subscription_request.h" // API
 
