@@ -2,9 +2,9 @@
 
     Gerbera - https://gerbera.io/
 
-    upnp_headers.h - this file is part of Gerbera.
+    headers.h - this file is part of Gerbera.
 
-    Copyright (C) 2016-2024 Gerbera Contributors
+    Copyright (C) 2016-2025 Gerbera Contributors
 
     Gerbera is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License version 2
@@ -21,7 +21,7 @@
     $Id$
 */
 
-/// \file upnp_headers.h
+/// \file headers.h
 
 #ifndef GERBERA_HEADERS_H
 #define GERBERA_HEADERS_H
@@ -40,8 +40,6 @@ public:
     static std::map<std::string, std::string> readHeaders(const UpnpFileInfo* fileInfo);
 
 private:
-    static std::string formatHeader(const std::pair<std::string, std::string>& header);
-    static std::pair<std::string, std::string> parseHeader(const std::string& header);
     static std::string stripInvalid(const std::string& value);
 
     std::map<std::string, std::string> headers;
