@@ -3,7 +3,7 @@ Gerbera - https://gerbera.io/
 
     grb_time.cc - this file is part of Gerbera.
 
-    Copyright (C) 2022-2024 Gerbera Contributors
+    Copyright (C) 2022-2025 Gerbera Contributors
 
     Gerbera is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License version 2
@@ -52,6 +52,21 @@ std::chrono::milliseconds getDeltaMillis(std::chrono::milliseconds first, std::c
     return second - first;
 }
 
+std::string millisecondsToString(long long milliseconds, bool all)
+{
+    auto ms = milliseconds % 1000;
+    milliseconds /= 1000;
+
+    auto seconds = milliseconds % 60;
+    milliseconds /= 60;
+
+    auto minutes = milliseconds % 60;
+    auto hours = milliseconds / 60;
+    auto fmtStr = hours > 0 ? "{0:01}:{1:02}:{2:02}" : "{1:02}:{2:02}";
+
+    return fmt::format(fmtStr, hours, minutes, seconds) + (all ? fmt::format(".{:03}", ms) : "");
+}
+
 std::string millisecondsToHMSF(long long milliseconds)
 {
     auto ms = milliseconds % 1000;
@@ -84,8 +99,11 @@ long long HMSFToMilliseconds(std::string_view time)
     return 0;
 }
 
-static const auto secondsFactors = std::vector { 1, 60, 3600, 24 * 3600 };
-static const auto minutesFactors = std::vector { 1, 60, 24 * 60 };
+static const auto timeFactors = std::map<GrbTimeType, std::vector<int>> {
+    { GrbTimeType::Seconds, { 1, 60, 3600, 24 * 3600 } },
+    { GrbTimeType::Minutes, { 1, 60, 24 * 60 } },
+    { GrbTimeType::Hours, { 1, 24 } },
+};
 
 std::string makeSimpleDate(std::string& s)
 {
@@ -104,21 +122,41 @@ std::string makeSimpleDate(std::string& s)
         log_debug("{} -> {:%FT%H:%M:%SZ}... {}-{}", s, dt, -tz / 100, -tz % 100);
         return fmt::format("{:%FT%H:%M:%SZ}", dt);
     }
-    log_debug("Failed to convert {}", s);
+    log_warning("Failed to convert {}", s);
     replaceAllString(s, "+0100", "Z");
     replaceAllString(s, "+0200", "Z");
     return s;
 }
 
-bool parseTime(int& value, std::string& timeValue, bool seconds)
+bool parseSimpleDate(const std::string& s, std::chrono::seconds& date)
+{
+    std::string_view date_time_format { "%Y-%m-%dT%H:%M:%S" };
+    std::istringstream ss { s };
+    std::tm dt {};
+
+    ss >> std::get_time(&dt, date_time_format.data());
+    if (!ss.fail()) {
+        auto t = std::mktime(&dt);
+        date = std::chrono::seconds(t);
+        log_debug("{} -> {:%FT%H:%M:%SZ}", s, dt);
+        return true;
+    }
+    log_warning("Failed to convert {}", s);
+    return false;
+}
+
+bool parseTime(int& value, std::string& timeValue, GrbTimeType type)
 {
     static auto re = std::regex("^([-0-9:]+)$");
-    auto factors = seconds ? secondsFactors : minutesFactors;
     value = 0;
+
     if (!std::regex_search(timeValue, re))
         return false;
+
     auto list = splitString(timeValue, ':');
     std::reverse(list.begin(), list.end());
+
+    auto factors = timeFactors.at(type);
     if (list.size() > factors.size())
         return false;
     int index = 0;
