@@ -3,7 +3,7 @@ Gerbera - https://gerbera.io/
 
     grb_time.h - this file is part of Gerbera.
 
-    Copyright (C) 2022-2023 Gerbera Contributors
+    Copyright (C) 2022-2025 Gerbera Contributors
 
     Gerbera is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License version 2
@@ -28,6 +28,12 @@ Gerbera - https://gerbera.io/
 #include <string>
 #include <string_view>
 
+enum class GrbTimeType {
+    Seconds,
+    Minutes,
+    Hours,
+};
+
 template <typename TP>
 std::chrono::seconds toSeconds(TP tp)
 {
@@ -41,6 +47,7 @@ std::string millisecondsToHMSF(long long milliseconds);
 
 /// \brief converts a "H*:MM:SS.F*" representation to milliseconds
 long long HMSFToMilliseconds(std::string_view time);
+std::string millisecondsToString(long long milliseconds, bool all = false);
 
 std::chrono::seconds currentTime();
 std::chrono::milliseconds currentTimeMS();
@@ -48,7 +55,8 @@ std::chrono::milliseconds currentTimeMS();
 std::chrono::milliseconds getDeltaMillis(std::chrono::milliseconds ms);
 std::chrono::milliseconds getDeltaMillis(std::chrono::milliseconds first, std::chrono::milliseconds second);
 
-bool parseTime(int& value, std::string& timeValue, bool seconds = true);
+bool parseSimpleDate(const std::string& s, std::chrono::seconds& date);
+bool parseTime(int& value, std::string& timeValue, GrbTimeType type = GrbTimeType::Seconds);
 std::string makeSimpleDate(std::string& s);
 
 #endif // __GRB_TIME_H__
