@@ -4,7 +4,7 @@
 
     mime.cc - this file is part of Gerbera.
 
-    Copyright (C) 2021-2024 Gerbera Contributors
+    Copyright (C) 2021-2025 Gerbera Contributors
 
     Gerbera is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License version 2
@@ -22,7 +22,7 @@
 */
 
 /// \file mime.cc
-#define GRB_LOG_FAC GrbLogFacility::content
+#define GRB_LOG_FAC GrbLogFacility::util
 #include "mime.h" // API
 
 #include "config/config.h"
@@ -52,6 +52,7 @@ Mime::Mime(const std::shared_ptr<Config>& config)
     }
 
     std::string optMagicFile = config->getOption(ConfigVal::IMPORT_MAGIC_FILE);
+    log_debug("magic '{}'", optMagicFile);
     const char* magicFile = !optMagicFile.empty() ? optMagicFile.c_str() : nullptr;
     if (magic_load(magicCookie, magicFile) == -1) {
         auto errMsg = magic_error(magicCookie);
@@ -92,14 +93,16 @@ std::string Mime::bufferToMimeType(const void* buffer, std::size_t length)
 
 std::pair<bool, std::string> Mime::getMimeType(const fs::path& path, const std::string& defval)
 {
-    std::string extension = path.extension();
-    if (!extension.empty())
+    auto extension = path.extension().string();
+    if (!extension.empty() && extension.at(0) == '.')
         extension.erase(0, 1); // remove leading .
 
-    if (!extension_map_case_sensitive)
+    if (!extension_map_case_sensitive) {
         extension = toLower(extension);
+    }
 
     if (std::find(ignoredExtensions.begin(), ignoredExtensions.end(), extension) != ignoredExtensions.end()) {
+        log_debug("Ignoring file {} because of extension", path.string());
         return { true, "" };
     }
     std::string mimeType = getValueOrDefault(extension_mimetype_map, extension, "");
