@@ -11,7 +11,7 @@
                             Sergey 'Jin' Bostandzhyan <jin@mediatomb.cc>,
                             Leonhard Wimmer <leo@mediatomb.cc>
 
-    Copyright (C) 2016-2024 Gerbera Contributors
+    Copyright (C) 2016-2025 Gerbera Contributors
 
     MediaTomb is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License version 2
@@ -76,6 +76,31 @@ std::vector<std::string> splitString(std::string_view str, char sep, bool empty)
     return ret;
 }
 
+std::string camelCaseString(const std::string_view& str)
+{
+    std::string ret;
+
+    std::size_t pos = 0;
+    std::size_t end = 0;
+    while (end < str.size()) {
+        if (str.at(end) == '-') {
+            if (pos < end) {
+                ret.append(str.substr(pos, end - pos));
+            }
+            ++end;
+            if (end < str.size())
+                ret.push_back(::toupper(str.at(end)));
+            pos = end + 1;
+        }
+        ++end;
+    }
+
+    if (pos < end)
+        ret.append(str.substr(pos, end));
+
+    return ret;
+}
+
 void trimStringInPlace(std::string& str)
 {
     str.erase(str.begin(), std::find_if_not(str.begin(), str.end(), ::isspace));
