@@ -11,7 +11,7 @@
                             Sergey 'Jin' Bostandzhyan <jin@mediatomb.cc>,
                             Leonhard Wimmer <leo@mediatomb.cc>
 
-    Copyright (C) 2016-2023 Gerbera Contributors
+    Copyright (C) 2016-2025 Gerbera Contributors
 
     MediaTomb is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License version 2
@@ -30,11 +30,15 @@
 */
 
 /// \file add.cc
-#define LOG_FAC log_facility_t::web
+#define GRB_LOG_FAC GrbLogFacility::web
 
 #include "pages.h" // API
 
-#include "content/content_manager.h"
+#include "common.h"
+#include "config/config_val.h"
+#include "content/autoscan_setting.h"
+#include "content/content.h"
+#include "exceptions.h"
 #include "util/tools.h"
 #include "util/xml_to_json.h"
 
@@ -51,6 +55,8 @@ void Web::Add::process()
 
     AutoScanSetting asSetting;
     asSetting.recursive = true;
+    asSetting.followSymlinks = config->getBoolOption(ConfigVal::IMPORT_FOLLOW_SYMLINKS);
+    asSetting.hidden = config->getBoolOption(ConfigVal::IMPORT_HIDDEN_FILES);
     asSetting.mergeOptions(config, path);
 
     std::error_code ec;
