@@ -2,9 +2,9 @@
 
     Gerbera - https://gerbera.io/
 
-    upnp_clients.cc - this file is part of Gerbera.
+    web/clients.cc - this file is part of Gerbera.
 
-    Copyright (C) 2020-2024 Gerbera Contributors
+    Copyright (C) 2020-2025 Gerbera Contributors
 
     Gerbera is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License version 2
@@ -21,7 +21,7 @@
     $Id$
 */
 
-/// \file clients.cc
+/// \file web/clients.cc
 #define GRB_LOG_FAC GrbLogFacility::web
 
 #include "pages.h" // API
@@ -30,6 +30,7 @@
 #include "content/content.h"
 #include "context.h"
 #include "database/database.h"
+#include "upnp/client_manager.h"
 #include "upnp/clients.h"
 #include "upnp/xml_builder.h"
 #include "util/grb_net.h"
@@ -47,6 +48,19 @@ void Web::Clients::process()
     checkRequest();
     auto root = xmlDoc->document_element();
 
+    // Delete client
+    std::string action = param("action");
+    if (action == "delete") {
+        std::string clientIp = param("client_id");
+        if (!clientIp.empty()) {
+            log_debug("Deleting client with {} IP address", clientIp);
+            content->getContext()->getClients()->removeClient(clientIp);
+        } else {
+            log_warning("Cannot delete client without IP address");
+        }
+    }
+
+    // Return current list of clients
     auto clients = root.append_child("clients");
     xml2Json->setArrayName(clients, "client");
 
@@ -70,6 +84,7 @@ void Web::Clients::process()
         item.append_attribute("clientType") = ClientConfig::mapClientType(obj.pInfo->type).data();
     }
 
+    // Return current list of groups
     auto groups = root.append_child("groups");
     xml2Json->setArrayName(groups, "group");
     auto&& groupArr = content->getContext()->getDatabase()->getClientGroupStats();
@@ -79,6 +94,6 @@ void Web::Clients::process()
         item.append_attribute("count") = obj.at("count").c_str();
         item.append_attribute("playCount") = obj.at("playCount").c_str();
         item.append_attribute("bookmarks") = obj.at("bookmarks").c_str();
-        item.append_attribute("last") = obj.at("last").c_str(); // obj.last).c_str();
+        item.append_attribute("last") = obj.at("last").c_str();
     }
 }
