@@ -2,7 +2,7 @@
 
     MediaTomb - http://www.mediatomb.cc/
 
-    containers.cc - this file is part of MediaTomb.
+    web/containers.cc - this file is part of MediaTomb.
 
     Copyright (C) 2005 Gena Batyan <bgeradz@mediatomb.cc>,
                        Sergey 'Jin' Bostandzhyan <jin@mediatomb.cc>
@@ -11,7 +11,7 @@
                             Sergey 'Jin' Bostandzhyan <jin@mediatomb.cc>,
                             Leonhard Wimmer <leo@mediatomb.cc>
 
-    Copyright (C) 2016-2024 Gerbera Contributors
+    Copyright (C) 2016-2025 Gerbera Contributors
 
     MediaTomb is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License version 2
@@ -29,7 +29,7 @@
     $Id$
 */
 
-/// \file containers.cc
+/// \file web/containers.cc
 #define GRB_LOG_FAC GrbLogFacility::web
 
 #include "pages.h" // API
@@ -38,23 +38,18 @@
 #include "config/config_val.h"
 #include "config/result/autoscan.h"
 #include "database/database.h"
+#include "database/db_param.h"
 #include "exceptions.h"
-#include "server.h"
 #include "upnp/xml_builder.h"
 #include "util/xml_to_json.h"
 
-Web::Containers::Containers(const std::shared_ptr<Content>& content, std::shared_ptr<UpnpXMLBuilder> xmlBuilder)
-    : WebRequestHandler(content)
-    , xmlBuilder(std::move(xmlBuilder))
-{
-}
-
 void Web::Containers::process()
 {
     log_debug("start process()");
     checkRequest();
 
     int parentID = intParam("parent_id", INVALID_OBJECT_ID);
+    std::string action = param("action");
     if (parentID == INVALID_OBJECT_ID)
         throw_std_runtime_error("no parent_id given");
 
@@ -64,11 +59,12 @@ void Web::Containers::process()
     xml2Json->setArrayName(containers, "container");
     xml2Json->setFieldType("title", FieldType::STRING);
     containers.append_attribute("parent_id") = parentID;
-    containers.append_attribute("type") = "database";
+    containers.append_attribute("type") = action == "browse" ? "database" : "search";
     if (!param("select_it").empty())
         containers.append_attribute("select_it") = param("select_it").c_str();
 
-    auto browseParam = BrowseParam(database->loadObject(DEFAULT_CLIENT_GROUP, parentID), BROWSE_DIRECT_CHILDREN | BROWSE_CONTAINERS);
+    log_debug("{} {}", action, parentID);
+    auto browseParam = BrowseParam(database->loadObject(getGroup(), parentID), BROWSE_DIRECT_CHILDREN | BROWSE_CONTAINERS);
     auto arr = database->browse(browseParam);
     for (auto&& obj : arr) {
         auto cont = std::static_pointer_cast<CdsContainer>(obj);
@@ -97,6 +93,9 @@ void Web::Containers::process()
         }
         ce.append_attribute("autoscan_mode") = autoscanMode.c_str();
         ce.append_attribute("title") = cont->getTitle().c_str();
+        ce.append_attribute("location") = cont->getLocation().c_str();
+        ce.append_attribute("upnp_shortcut") = cont->getUpnpShortcut().c_str();
+        ce.append_attribute("upnp_class") = cont->getClass().c_str();
     }
     log_debug("end process()");
 }
