@@ -2,7 +2,7 @@
 
     MediaTomb - http://www.mediatomb.cc/
 
-    web_request_handler.cc - this file is part of MediaTomb.
+    web/web_request_handler.cc - this file is part of MediaTomb.
 
     Copyright (C) 2005 Gena Batyan <bgeradz@mediatomb.cc>,
                        Sergey 'Jin' Bostandzhyan <jin@mediatomb.cc>
@@ -11,7 +11,7 @@
                             Sergey 'Jin' Bostandzhyan <jin@mediatomb.cc>,
                             Leonhard Wimmer <leo@mediatomb.cc>
 
-    Copyright (C) 2016-2024 Gerbera Contributors
+    Copyright (C) 2016-2025 Gerbera Contributors
 
     MediaTomb is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License version 2
@@ -29,7 +29,7 @@
     $Id$
 */
 
-/// \file web_request_handler.cc
+/// \file web/web_request_handler.cc
 #define GRB_LOG_FAC GrbLogFacility::web
 
 #include "web_request_handler.h" // API
@@ -41,7 +41,9 @@
 #include "context.h"
 #include "exceptions.h"
 #include "iohandler/mem_io_handler.h"
+#include "server.h"
 #include "session_manager.h"
+#include "upnp/compat.h"
 #include "upnp/headers.h"
 #include "upnp/quirks.h"
 #include "util/generic_task.h"
@@ -51,12 +53,21 @@
 
 namespace Web {
 
-WebRequestHandler::WebRequestHandler(const std::shared_ptr<Content>& content)
-    : RequestHandler(content, nullptr)
+WebRequestHandler::WebRequestHandler(const std::shared_ptr<Content>& content,
+    std::shared_ptr<Server> server,
+    const std::shared_ptr<UpnpXMLBuilder>& xmlBuilder,
+    const std::shared_ptr<Quirks>& quirks)
+    : RequestHandler(content, xmlBuilder, quirks)
     , sessionManager(this->content->getContext()->getSessionManager())
+    , server(std::move(server))
 {
 }
 
+std::string WebRequestHandler::getGroup() const
+{
+    return quirks ? quirks->getGroup() : DEFAULT_CLIENT_GROUP;
+}
+
 int WebRequestHandler::intParam(const std::string& name, int invalid) const
 {
     std::string value = param(name);
@@ -90,12 +101,10 @@ void WebRequestHandler::checkRequest(bool checkLogin)
     session->access();
 }
 
-const struct ClientInfo* WebRequestHandler::getInfo(const char* filename, UpnpFileInfo* info)
+bool WebRequestHandler::getInfo(const char* filename, UpnpFileInfo* info)
 {
     this->filename = filename;
-
-    auto&& [path, parameters] = URLUtils::splitUrl(filename, URL_UI_PARAM_SEPARATOR);
-
+    auto&& parameters = URLUtils::getQuery(this->filename);
     auto decodedParams = URLUtils::dictDecode(parameters);
     if (params.empty()) {
         params = std::move(decodedParams);
@@ -111,27 +120,24 @@ const struct ClientInfo* WebRequestHandler::getInfo(const char* filename, UpnpFi
 
     std::string contentType = "application/json; charset=UTF-8";
 
-#ifdef USING_NPUPNP
-    info->content_type = std::move(contentType);
-#else
-    UpnpFileInfo_set_ContentType(info, contentType.c_str());
-#endif
     Headers headers;
     headers.addHeader("Cache-Control", "no-cache, must-revalidate");
     headers.addHeader("SameSite", "Lax");
-    headers.addHeader("Access-Control-Allow-Origin", "*");
+    GrbUpnpFileInfoSetContentType(info, contentType);
+#ifdef UPNP_NEEDS_CORS
+    headers.addHeader("Access-Control-Allow-Origin", fmt::format("{}", fmt::join(server->getCorsHosts(), " ")));
+#endif
 
-    auto quirks = getQuirks(info);
     if (quirks)
         quirks->updateHeaders(headers);
     headers.writeHeaders(info);
-    return quirks ? quirks->getInfo() : nullptr;
+    return quirks && quirks->getClient();
 }
 
 std::unique_ptr<IOHandler> WebRequestHandler::open(const char* filename, const std::shared_ptr<Quirks>& quirks, enum UpnpOpenFileMode mode)
 {
     this->filename = filename;
-    auto&& [path, parameters] = URLUtils::splitUrl(filename, URL_UI_PARAM_SEPARATOR);
+    auto&& parameters = URLUtils::getQuery(this->filename);
     auto decodedParams = URLUtils::dictDecode(parameters);
     if (params.empty()) {
         params = std::move(decodedParams);
