@@ -1,9 +1,10 @@
 /*GRB*
+
     Gerbera - https://gerbera.io/
 
     test_autoscan_list.cc - this file is part of Gerbera.
 
-    Copyright (C) 2016-2024 Gerbera Contributors
+    Copyright (C) 2016-2025 Gerbera Contributors
 
     Gerbera is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License version 2
@@ -19,11 +20,12 @@
 
     $Id$
 */
-#include <gtest/gtest.h>
 
 #include "config/result/autoscan.h"
 #include "content/autoscan_list.h"
 
+#include <gtest/gtest.h>
+
 TEST(AutoscanListTest, create)
 {
     auto list = AutoscanList();
@@ -35,7 +37,7 @@ TEST(AutoscanListTest, create)
 
     EXPECT_EQ(list.size(), 1);
 
-    EXPECT_EQ(list.get({"/path/to/thing"}), adir);
+    EXPECT_EQ(list.getKey({"/path/to/thing"}), adir);
 
-    EXPECT_EQ(list.get({"/path/to/other"}), nullptr);
+    EXPECT_EQ(list.getKey({"/path/to/other"}), nullptr);
 }
