@@ -1,10 +1,10 @@
 /*GRB*
 
-Gerbera - https://gerbera.io/
+    Gerbera - https://gerbera.io/
 
     test_upnp_xml.cc - this file is part of Gerbera.
 
-    Copyright (C) 2016-2024 Gerbera Contributors
+    Copyright (C) 2016-2025 Gerbera Contributors
 
     Gerbera is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License version 2
@@ -17,9 +17,9 @@ Gerbera - https://gerbera.io/
 
     You should have received a copy of the GNU General Public License
     along with Gerbera.  If not, see <http://www.gnu.org/licenses/>.
-*/
 
-#include <gtest/gtest.h>
+    $Id$
+*/
 
 #include "cds/cds_container.h"
 #include "cds/cds_item.h"
@@ -27,14 +27,19 @@ Gerbera - https://gerbera.io/
 #include "config/result/client_config.h"
 #include "config/result/transcoding.h"
 #include "config/config_setup.h"
+#include "context.h"
 #include "metadata/metadata_handler.h"
+#include "upnp/client_manager.h"
 #include "upnp/xml_builder.h"
 #include "util/grb_net.h"
+#include "util/string_converter.h"
 #include "util/tools.h"
 
 #include "../mock/config_mock.h"
 #include "../mock/database_mock.h"
 
+#include <gtest/gtest.h>
+
 using ::testing::_;
 using ::testing::Return;
 
@@ -53,7 +58,8 @@ public:
         config = std::make_shared<ConfigMock>();
 
         database = std::make_shared<DatabaseMock>(config);
-        context = std::make_shared<Context>(config, nullptr, nullptr, database, nullptr);
+        converterManager = std::make_shared<ConverterManager>(config);
+        context = std::make_shared<Context>(config, nullptr, nullptr, database, nullptr, converterManager);
 
         std::string virtualDir = "http://server";
         std::string presentationURl = "http://someurl/";
@@ -69,6 +75,7 @@ public:
     std::shared_ptr<ConfigMock> config;
     std::shared_ptr<DatabaseMock> database;
     std::shared_ptr<Context> context;
+    std::shared_ptr<ConverterManager> converterManager;
 };
 
 TEST_F(UpnpXmlTest, RenderObjectContainer)
@@ -109,11 +116,12 @@ TEST_F(UpnpXmlTest, RenderObjectContainer)
     expectedXml << "<upnp:date>2001-01-01</upnp:date>\n";
     expectedXml << "<upnp:orchestra>Orchestra</upnp:orchestra>\n";
     expectedXml << "<upnp:albumArtURI>http://server/media/object_id/1/res_id/0/ext/file.jpg</upnp:albumArtURI>\n";
+    expectedXml << "<res id=\"1.0\" protocolInfo=\"http-get:*:jpg:DLNA.ORG_OP=01;DLNA.ORG_CI=0\">http://server/media/object_id/1/res_id/0/ext/file.jpg</res>\n";
     expectedXml << "</container>\n";
     expectedXml << "</DIDL-Lite>\n";
 
     // act
-    subject->renderObject(obj, std::string::npos, root);
+    subject->renderObject(obj, { "*" }, std::string::npos, root);
 
     // assert
     std::string didlLiteXml = UpnpXMLBuilder::printXml(didlLite, "");
@@ -155,7 +163,7 @@ TEST_F(UpnpXmlTest, RenderObjectItem)
         .WillRepeatedly(Return(std::make_shared<TranscodingProfileList>()));
 
     // act
-    subject->renderObject(obj, std::string::npos, root);
+    subject->renderObject(obj, { "*" }, std::string::npos, root);
 
     // assert
     std::string didlLiteXml = UpnpXMLBuilder::printXml(didlLite, "");
@@ -181,7 +189,7 @@ TEST_F(UpnpXmlTest, RenderObjectItemWithEscapes)
     auto clientConfig = std::make_shared<MyConfigMock>();
     auto clientManager = std::make_shared<ClientManager>(clientConfig, database);
     auto addr = std::make_shared<GrbNet>("192.168.99.100");
-    auto quirks = std::make_unique<Quirks>(subject, clientManager, addr, "DLNADOC/1.50");
+    auto quirks = std::make_shared<Quirks>(subject, clientManager, addr, "DLNADOC/1.50");
 
     std::ostringstream expectedXml;
     expectedXml << "<DIDL-Lite>\n";
@@ -202,7 +210,7 @@ TEST_F(UpnpXmlTest, RenderObjectItemWithEscapes)
         .WillRepeatedly(Return(std::make_shared<TranscodingProfileList>()));
 
     // act
-    subject->renderObject(obj, std::string::npos, root, quirks);
+    subject->renderObject(obj, { "*" }, std::string::npos, root, quirks);
 
     // assert
     std::string didlLiteXml = UpnpXMLBuilder::printXml(didlLite, "");
@@ -228,7 +236,7 @@ TEST_F(UpnpXmlTest, RenderObjectItemWithStrictXmlQuirks)
     auto clientConfig = std::make_shared<MyConfigMock>();
     auto clientManager = std::make_shared<ClientManager>(clientConfig, database);
     auto addr = std::make_shared<GrbNet>("192.168.99.100");
-    auto quirks = std::make_unique<Quirks>(subject, clientManager, addr, "Allegro-Software-WebClient/5.40b1 DLNADOC/1.50");
+    auto quirks = std::make_shared<Quirks>(subject, clientManager, addr, "Allegro-Software-WebClient/5.40b1 DLNADOC/1.50");
 
     std::ostringstream expectedXml;
     expectedXml << "<DIDL-Lite>\n";
@@ -249,7 +257,7 @@ TEST_F(UpnpXmlTest, RenderObjectItemWithStrictXmlQuirks)
         .WillRepeatedly(Return(std::make_shared<TranscodingProfileList>()));
 
     // act
-    subject->renderObject(obj, std::string::npos, root, quirks);
+    subject->renderObject(obj, { "*" }, std::string::npos, root, quirks);
 
     // assert
     std::string didlLiteXml = UpnpXMLBuilder::printXml(didlLite, "", pugi::format_no_escapes);
@@ -296,7 +304,7 @@ TEST_F(UpnpXmlTest, RenderObjectItemWithResources)
     obj->addResource(resource);
 
     resource = std::make_shared<CdsResource>(ContentHandler::FANART, ResourcePurpose::Thumbnail);
-    resource->addAttribute(ResourceAttribute::PROTOCOLINFO, renderProtocolInfo("jpg"));
+    resource->addAttribute(ResourceAttribute::PROTOCOLINFO, renderProtocolInfo("image/jpeg"));
     resource->addAttribute(ResourceAttribute::RESOURCE_FILE, "/home/resource/cover.jpg");
     resource->addAttribute(ResourceAttribute::RESOLUTION, "200x200");
     obj->addResource(resource);
@@ -313,10 +321,10 @@ TEST_F(UpnpXmlTest, RenderObjectItemWithResources)
     expectedXml << "<upnp:originalTrackNumber>7</upnp:originalTrackNumber>\n";
     expectedXml << "<upnp:albumArtURI xmlns:dlna=\"urn:schemas-dlna-org:metadata-1-0\" dlna:profileID=\"JPEG_TN\">http://server/media/object_id/42/res_id/3/ext/file.jpg</upnp:albumArtURI>\n";
     expectedXml << "<sec:CaptionInfoEx protocolInfo=\"http-get:*:text/srt:*\" sec:type=\"srt\">http://server/media/object_id/42/res_id/1/type/srt/ext/file.srt</sec:CaptionInfoEx>\n";
-    expectedXml << "<res size=\"4711\" duration=\"123456\" bitrate=\"16044\" nrAudioChannels=\"2\" protocolInfo=\"http-get:*:audio/mpeg:DLNA.ORG_PN=MP3;DLNA.ORG_OP=01;DLNA.ORG_CI=0;DLNA.ORG_FLAGS=01700000000000000000000000000000\">http://server/media/object_id/42/res_id/0/group/default/ext/file.mp3</res>\n";
-    expectedXml << "<res protocolInfo=\"http-get:*:text/srt:DLNA.ORG_OP=01;DLNA.ORG_CI=0;DLNA.ORG_FLAGS=00d00000000000000000000000000000\">http://server/media/object_id/42/res_id/1/type/srt/ext/file.srt</res>\n";
-    expectedXml << "<res protocolInfo=\"http-get:*:text/srt:DLNA.ORG_OP=01;DLNA.ORG_CI=0;DLNA.ORG_FLAGS=00d00000000000000000000000000000\" dc:language=\"fr\">http://server/media/object_id/42/res_id/2/type/srt/ext/file.fr.srt</res>\n";
-    expectedXml << "<res resolution=\"200x200\" protocolInfo=\"http-get:*:jpg:DLNA.ORG_OP=01;DLNA.ORG_CI=0\">http://server/media/object_id/42/res_id/3/ext/file.jpg</res>\n";
+    expectedXml << "<res id=\"42.0\" size=\"4711\" duration=\"123456\" bitrate=\"16044\" nrAudioChannels=\"2\" protocolInfo=\"http-get:*:audio/mpeg:DLNA.ORG_PN=MP3;DLNA.ORG_OP=01;DLNA.ORG_CI=0;DLNA.ORG_FLAGS=01700000000000000000000000000000\">http://server/media/object_id/42/res_id/0/group/default/ext/file.mp3</res>\n";
+    expectedXml << "<res id=\"42.1\" protocolInfo=\"http-get:*:text/srt:DLNA.ORG_OP=01;DLNA.ORG_CI=0;DLNA.ORG_FLAGS=00d00000000000000000000000000000\">http://server/media/object_id/42/res_id/1/type/srt/ext/file.srt</res>\n";
+    expectedXml << "<res id=\"42.2\" protocolInfo=\"http-get:*:text/srt:DLNA.ORG_OP=01;DLNA.ORG_CI=0;DLNA.ORG_FLAGS=00d00000000000000000000000000000\" dc:language=\"fr\">http://server/media/object_id/42/res_id/2/type/srt/ext/file.fr.srt</res>\n";
+    expectedXml << "<res id=\"42.3\" resolution=\"200x200\" protocolInfo=\"http-get:*:image/jpeg:DLNA.ORG_PN=JPEG_TN;DLNA.ORG_OP=01;DLNA.ORG_CI=0;DLNA.ORG_FLAGS=00800000000000000000000000000000\">http://server/media/object_id/42/res_id/3/ext/file.jpg</res>\n";
     expectedXml << "</item>\n";
     expectedXml << "</DIDL-Lite>\n";
 
@@ -326,7 +334,7 @@ TEST_F(UpnpXmlTest, RenderObjectItemWithResources)
         .WillRepeatedly(Return(std::make_shared<TranscodingProfileList>()));
 
     // act
-    subject->renderObject(obj, std::string::npos, root);
+    subject->renderObject(obj, { "*" }, std::string::npos, root);
 
     // assert
     std::string didlLiteXml = UpnpXMLBuilder::printXml(didlLite, "");
@@ -357,11 +365,29 @@ TEST_F(UpnpXmlTest, CreateResponse)
     EXPECT_STREQ(root.attribute("xmlns:u").value(), "urn:schemas-upnp-org:service:ContentDirectory:1");
 }
 
+TEST_F(UpnpXmlTest, FirstResourceRendersEmptyWhenNoResource)
+{
+    auto obj = std::make_shared<CdsItemExternalURL>();
+    obj->setLocation("http://localhost/external/url");
+
+    auto item = std::static_pointer_cast<CdsItem>(obj);
+
+    std::string result = subject->getFirstResourcePath(item);
+
+    EXPECT_EQ(result, "");
+}
+
 TEST_F(UpnpXmlTest, FirstResourceRendersPureWhenExternalUrl)
 {
     auto obj = std::make_shared<CdsItemExternalURL>();
     obj->setLocation("http://localhost/external/url");
 
+    auto resource = std::make_shared<CdsResource>(ContentHandler::DEFAULT, ResourcePurpose::Content);
+    resource->addAttribute(ResourceAttribute::PROTOCOLINFO, "http-get:*:audio/mpeg:*");
+    resource->addAttribute(ResourceAttribute::DURATION, "123456");
+    resource->addAttribute(ResourceAttribute::SIZE, "4711");
+    obj->addResource(resource);
+
     auto item = std::static_pointer_cast<CdsItem>(obj);
 
     std::string result = subject->getFirstResourcePath(item);
@@ -378,6 +404,11 @@ TEST_F(UpnpXmlTest, FirstResourceAddsLocalResourceIdToExternalUrlWhenOnlineWithP
     obj->setFlag(OBJECT_FLAG_ONLINE_SERVICE);
     obj->setFlag(OBJECT_FLAG_PROXY_URL);
 
+    auto resource = std::make_shared<CdsResource>(ContentHandler::DEFAULT, ResourcePurpose::Content);
+    resource->addAttribute(ResourceAttribute::DURATION, "123456");
+    resource->addAttribute(ResourceAttribute::SIZE, "4711");
+    obj->addResource(resource);
+
     auto item = std::static_pointer_cast<CdsItem>(obj);
 
     std::string result = subject->getFirstResourcePath(item);
@@ -392,6 +423,11 @@ TEST_F(UpnpXmlTest, FirstResourceAddsLocalResourceIdToItem)
     obj->setLocation("local/content");
     obj->setID(12345);
 
+    auto resource = std::make_shared<CdsResource>(ContentHandler::DEFAULT, ResourcePurpose::Content);
+    resource->addAttribute(ResourceAttribute::DURATION, "123456");
+    resource->addAttribute(ResourceAttribute::SIZE, "4711");
+    obj->addResource(resource);
+
     auto item = std::static_pointer_cast<CdsItem>(obj);
 
     std::string result = subject->getFirstResourcePath(item);
