@@ -1,10 +1,10 @@
 /*GRB*
 
-Gerbera - https://gerbera.io/
+    Gerbera - https://gerbera.io/
 
     test_database.cc - this file is part of Gerbera.
 
-    Copyright (C) 2020-2024 Gerbera Contributors
+    Copyright (C) 2020-2025 Gerbera Contributors
 
     Gerbera is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License version 2
@@ -17,12 +17,11 @@ Gerbera - https://gerbera.io/
 
     You should have received a copy of the GNU General Public License
     along with Gerbera.  If not, see <http://www.gnu.org/licenses/>.
+
+    $Id$
 */
 
 /// \file test_database.cc
-#include <gtest/gtest.h>
-#include <pugixml.hpp>
-
 #include "cds/cds_objects.h"
 #include "config/result/autoscan.h"
 #include "database/sqlite3/sqlite_database.h"
@@ -36,6 +35,9 @@ Gerbera - https://gerbera.io/
 #include "mysql_config_fake.h"
 #endif
 
+#include <gtest/gtest.h>
+#include <pugixml.hpp>
+
 class TestSqliteDatabase : public Sqlite3Database {
     friend class Sqlite3DatabaseTest;
 };
@@ -77,7 +79,7 @@ public:
     void SetUp() override
     {
         config = std::make_shared<SqliteConfigFake>();
-        subject = std::make_shared<Sqlite3Database>(config, nullptr, nullptr);
+        subject = std::make_shared<Sqlite3Database>(config, nullptr, nullptr, nullptr);
     }
 
     void TearDown() override
@@ -145,7 +147,7 @@ public:
     void SetUp() override
     {
         config = std::make_shared<MySQLConfigFake>();
-        subject = std::make_shared<MySQLDatabase>(config, nullptr);
+        subject = std::make_shared<MySQLDatabase>(config, nullptr, nullptr);
     }
 
     void TearDown() override
