@@ -1,10 +1,10 @@
 /*GRB*
 
-Gerbera - https://gerbera.io/
+    Gerbera - https://gerbera.io/
 
     test_sql_generators.cc - this file is part of Gerbera.
 
-    Copyright (C) 2021-2024 Gerbera Contributors
+    Copyright (C) 2021-2025 Gerbera Contributors
 
     Gerbera is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License version 2
@@ -17,20 +17,24 @@ Gerbera - https://gerbera.io/
 
     You should have received a copy of the GNU General Public License
     along with Gerbera.  If not, see <http://www.gnu.org/licenses/>.
+
+    $Id$
 */
 
 /// \file test_sql_generators.cc
+#include "database/sql_database.h"
+
+#include "sqlite_config_fake.h"
+
 #include <fmt/core.h>
 #include <gtest/gtest.h>
 
-#include "database/sql_database.h"
-
 class TestDatabase : public SQLDatabase, public std::enable_shared_from_this<SQLDatabase> {
 public:
     using SQLDatabase::identifier;
 
-    TestDatabase(const std::shared_ptr<Config>& config, const std::shared_ptr<Mime>& mime)
-        : SQLDatabase(config, mime)
+    TestDatabase(const std::shared_ptr<Config>& config, const std::shared_ptr<Mime>& mime, const std::shared_ptr<ConverterManager>& converterManager)
+        : SQLDatabase(config, mime, converterManager)
     {
         table_quote_begin = '[';
         table_quote_end = ']';
@@ -93,7 +97,8 @@ class DatabaseTest : public ::testing::Test {
 public:
     void SetUp() override
     {
-        database = std::make_shared<TestDatabase>(config, mime);
+        config = std::make_shared<SqliteConfigFake>();
+        database = std::make_shared<TestDatabase>(config, mime, converterManager);
     }
 
     void TearDown() override
@@ -104,6 +109,7 @@ public:
 protected:
     std::shared_ptr<Config> config;
     std::shared_ptr<Mime> mime;
+    std::shared_ptr<ConverterManager> converterManager;
     std::shared_ptr<TestDatabase> database;
 };
 
