@@ -3,7 +3,7 @@
 
     database_mock.h - this file is part of Gerbera.
 
-    Copyright (C) 2016-2023 Gerbera Contributors
+    Copyright (C) 2016-2025 Gerbera Contributors
 
     Gerbera is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License version 2
@@ -22,10 +22,10 @@
 #ifndef __DATABASE_MOCK_H__
 #define __DATABASE_MOCK_H__
 
-#include <gtest/gtest.h>
-
 #include "database/database.h"
 
+#include <gtest/gtest.h>
+
 class DatabaseMock : public Database {
 public:
     DatabaseMock(std::shared_ptr<Config> config)
@@ -43,11 +43,12 @@ public:
     void updateObject(const std::shared_ptr<CdsObject>& object, int* changedContainer) override { }
 
     std::vector<std::shared_ptr<CdsObject>> browse(BrowseParam& param) override { return {}; }
-    std::vector<std::shared_ptr<CdsObject>> search(const SearchParam& param, int* numMatches) override { return {}; }
+    std::vector<std::shared_ptr<CdsObject>> search(SearchParam& param) override { return {}; }
 
     std::vector<std::string> getMimeTypes() override { return {}; }
-    std::vector<std::shared_ptr<CdsObject>> findObjectByContentClass(const std::string& contentClass) override { return {}; }
-    std::shared_ptr<CdsObject> findObjectByPath(const fs::path& path, DbFileType fileType = DbFileType::Auto) override { return {}; }
+    std::map<std::string, std::shared_ptr<CdsContainer>> getShortcuts() override { return {}; }
+    std::vector<std::shared_ptr<CdsObject>> findObjectByContentClass(const std::string& contentClass, const std::string& group) override { return {}; }
+    std::shared_ptr<CdsObject> findObjectByPath(const fs::path& path, const std::string& group, DbFileType fileType = DbFileType::Auto) override { return {}; }
     int findObjectIDByPath(const fs::path& fullpath, DbFileType fileType = DbFileType::Auto) override { return INVALID_OBJECT_ID; }
     std::string incrementUpdateIDs(const std::unordered_set<int>& ids) override { return {}; }
 
@@ -58,12 +59,12 @@ public:
 
     std::unique_ptr<ChangedContainers> removeObject(int objectID, const fs::path& path, bool all) override { return {}; }
     std::size_t getObjects(int parentID, bool withoutContainer, std::unordered_set<int>& ret, bool full) override { return 0; }
-    std::vector<std::pair<int, std::chrono::seconds>> getRefObjects(int objectId) override { return {}; }
+    std::vector<int> getRefObjects(int objectId) override { return {}; }
     std::unordered_set<int> getUnreferencedObjects() override { return {}; }
 
     std::unique_ptr<ChangedContainers> removeObjects(const std::unordered_set<int>& list, bool all = false) override { return {}; }
 
-    std::shared_ptr<CdsObject> loadObjectByServiceID(const std::string& serviceID) override { return {}; }
+    std::shared_ptr<CdsObject> loadObjectByServiceID(const std::string& serviceID, const std::string& group) override { return {}; }
     std::vector<int> getServiceObjectIDs(char servicePrefix) override { return {}; }
 
     long long getFileStats(const StatsParam& stats) override { return 0; }
@@ -77,8 +78,8 @@ public:
     void updateConfigValue(const std::string& key, const std::string& item, const std::string& value, const std::string& status = "unchanged") override { }
 
     /* clients methods */
-    std::vector<ClientCacheEntry> getClients() override { return {}; }
-    void saveClients(const std::vector<ClientCacheEntry>& cache) override { }
+    std::vector<ClientObservation> getClients() override { return {}; }
+    void saveClients(const std::vector<ClientObservation>& cache) override { }
     std::shared_ptr<ClientStatusDetail> getPlayStatus(const std::string& group, int objectId) override { return {}; };
     void savePlayStatus(const std::shared_ptr<ClientStatusDetail>& detail) override { };
     std::vector<std::shared_ptr<ClientStatusDetail>> getPlayStatusList(int objectId) override { return {}; }
