@@ -1,9 +1,10 @@
 /*GRB*
+
     Gerbera - https://gerbera.io/
 
     test_external_pls_playlist.cc - this file is part of Gerbera.
 
-    Copyright (C) 2016-2024 Gerbera Contributors
+    Copyright (C) 2016-2025 Gerbera Contributors
 
     Gerbera is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License version 2
@@ -21,11 +22,6 @@
 */
 #ifdef HAVE_JS
 
-#include <duktape.h>
-#include <gmock/gmock.h>
-#include <gtest/gtest.h>
-#include <memory>
-
 #include "cds/cds_objects.h"
 #include "upnp/upnp_common.h"
 #include "util/string_converter.h"
@@ -34,6 +30,9 @@
 #include "mock/duk_helper.h"
 #include "mock/script_test_fixture.h"
 
+#include <duktape.h>
+#include <memory>
+
 // Extends ScriptTestFixture to allow
 // for unique testing of the External URL Playlist
 // processing
